@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -71,10 +71,10 @@ int main(int argc, char **argv)
     }
 
     ClientConnectionManager conMan;
-    QObject::connect(&conMan, SIGNAL(ready()), &conMan, SLOT(createMainWindow()));
-    QObject::connect(&conMan, SIGNAL(disconnected()), QApplication::instance(), SLOT(quit()));
-    QObject::connect(&conMan, SIGNAL(persistentConnectionError(QString)), &conMan,
-                     SLOT(handlePersistentConnectionError(QString)));
+    QObject::connect(&conMan, &ClientConnectionManager::ready, &conMan, &ClientConnectionManager::createMainWindow);
+    QObject::connect(&conMan, &ClientConnectionManager::disconnected, QApplication::instance(), &QCoreApplication::quit);
+    QObject::connect(&conMan, &ClientConnectionManager::persistentConnectionError, &conMan,
+                     &ClientConnectionManager::handlePersistentConnectionError);
     conMan.connectToHost(serverUrl);
     return app.exec();
 }
