@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,8 @@
 #include "remotemodel.h"
 #include "client.h"
 
+#include <compat/qasconst.h>
+
 #include <common/message.h>
 
 #include <QApplication>
@@ -74,8 +76,7 @@ void RemoteModel::Node::allocateColumns()
     data.resize(parent->columnCount);
     flags.resize(parent->columnCount);
     flags.fill(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-    state.resize(parent->columnCount);
-    state.fill(RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated);
+    state.resize(parent->columnCount, RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated);
 }
 
 bool RemoteModel::Node::hasColumnData() const
@@ -83,7 +84,7 @@ bool RemoteModel::Node::hasColumnData() const
     if (!parent)
         return false;
     Q_ASSERT(data.size() == flags.size());
-    Q_ASSERT(data.size() == state.size());
+    Q_ASSERT(data.size() == (int)state.size());
     Q_ASSERT(data.isEmpty() || data.size() == parent->columnCount || parent->columnCount < 0);
 
     return data.size() == parent->columnCount && parent->columnCount > 0;
@@ -105,13 +106,8 @@ RemoteModel::RemoteModel(const QString &serverObject, QObject *parent)
 {
     if (s_emptyDisplayValue.isNull()) {
         s_emptyDisplayValue = tr("Loading...");
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        QStyleOptionViewItemV4 opt;
-        opt.features |= QStyleOptionViewItemV4::HasDisplay;
-#else
         QStyleOptionViewItem opt;
         opt.features |= QStyleOptionViewItem::HasDisplay;
-#endif
         opt.text = s_emptyDisplayValue.toString();
         s_emptySizeHintValue = QApplication::style()->sizeFromContents(QStyle::CT_ItemViewItem,
                                                                        &opt, QSize(), nullptr);
@@ -121,7 +117,7 @@ RemoteModel::RemoteModel(const QString &serverObject, QObject *parent)
 
     m_pendingRequestsTimer->setInterval(0);
     m_pendingRequestsTimer->setSingleShot(true);
-    connect(m_pendingRequestsTimer, SIGNAL(timeout()), SLOT(doRequests()));
+    connect(m_pendingRequestsTimer, &QTimer::timeout, this, &RemoteModel::doRequests);
 
     registerClient(serverObject);
     connectToServer();
@@ -140,7 +136,7 @@ bool RemoteModel::isConnected() const
 QModelIndex RemoteModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (!isConnected() || row < 0 || column < 0)
-        return QModelIndex();
+        return {};
 
     Node *parentNode = nodeForIndex(parent);
     Q_ASSERT(parentNode->children.size() >= parentNode->rowCount);
@@ -156,12 +152,12 @@ QModelIndex RemoteModel::parent(const QModelIndex &index) const
     Node *currentNode = nodeForIndex(index);
     Q_ASSERT(currentNode);
     if (currentNode == m_root || currentNode->parent == m_root)
-        return QModelIndex();
+        return {};
     Q_ASSERT(currentNode->parent && currentNode->parent->parent);
     Q_ASSERT(currentNode->parent->children.contains(currentNode));
     Q_ASSERT(currentNode->parent->parent->children.contains(currentNode->parent));
-    return createIndex(currentNode->parent->parent->children.indexOf(
-                           currentNode->parent), 0, currentNode->parent);
+
+    return modelIndexForNode(currentNode->parent, 0);
 }
 
 int RemoteModel::rowCount(const QModelIndex &index) const
@@ -375,12 +371,10 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
                 node->flags[column] = static_cast<Qt::ItemFlags>(flags);
                 node->state[column] = state & ~(RemoteModelNodeState::Loading | RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
                 if ((flags & Qt::ItemNeverHasChildren) && column == 0) {
                     node->rowCount = 0;
                     node->columnCount = node->data.size();
                 }
-#endif
 
                 // group by parent, and emit dataChange for the bounding rect per hierarchy level
                 // as an approximiation of perfect range batching
@@ -394,7 +388,7 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
             Q_ASSERT(!indexes.isEmpty());
             int r1 = std::numeric_limits<int>::max(), r2 = 0, c1 = std::numeric_limits<int>::max(),
                 c2 = 0;
-            foreach (const auto &index, indexes) {
+            for (const auto &index : indexes) {
                 r1 = std::min(r1, index.row());
                 r2 = std::max(r2, index.row());
                 c1 = std::min(c1, index.column());
@@ -445,7 +439,7 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
             for (int col = beginIndex.last().column; col <= endIndex.last().column; ++col) {
                 const auto state = stateForColumn(currentRow, col);
                 if ((state & RemoteModelNodeState::Outdated) == 0) {
-                    Q_ASSERT(currentRow->state.size() > col);
+                    Q_ASSERT((int)currentRow->state.size() > col);
                     currentRow->state[col] = state | RemoteModelNodeState::Outdated;
                 }
             }
@@ -454,11 +448,7 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
         const QModelIndex qmiBegin = modelIndexForNode(node, beginIndex.last().column);
         const QModelIndex qmiEnd = qmiBegin.sibling(endIndex.last().row, endIndex.last().column);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        emit dataChanged(qmiBegin, qmiEnd);
-#else
         emit dataChanged(qmiBegin, qmiEnd, roles);
-#endif
         break;
     }
 
@@ -602,7 +592,7 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
 
         QVector<Node *> parentNodes;
         parentNodes.reserve(parents.size());
-        foreach (const auto &p, parents) {
+        for (const auto &p : qAsConst(parents)) {
             auto node = nodeForIndex(p);
             if (!node)
                 continue;
@@ -615,14 +605,14 @@ void RemoteModel::newMessage(const GammaRay::Message &msg)
         foreach (const auto &persistentIndex, persistentIndexList()) {
             auto persistentNode = nodeForIndex(persistentIndex);
             Q_ASSERT(persistentNode);
-            foreach (auto node, parentNodes) {
+            for (auto node : qAsConst(parentNodes)) {
                 if (!isAncestor(node, persistentNode))
                     continue;
                 changePersistentIndex(persistentIndex, QModelIndex());
                 break;
             }
         }
-        foreach (auto node, parentNodes) {
+        for (auto node : qAsConst(parentNodes)) {
             if (hint == 0)
                 node->clearChildrenStructure();
             else
@@ -666,10 +656,11 @@ RemoteModel::Node *RemoteModel::nodeForIndex(const QModelIndex &index) const
 RemoteModel::Node *RemoteModel::nodeForIndex(const Protocol::ModelIndex &index) const
 {
     Node *node = m_root;
-    for (int i = 0; i < index.size(); ++i) {
-        if (node->children.size() <= index[i].row)
+    for (auto i : index) {
+        if (node->children.size() <= i.row)
             return nullptr;
-        node = node->children.at(index[i].row);
+        node = node->children.at(i.row);
+        node->rowHint = i.row;
     }
     return node;
 }
@@ -678,8 +669,18 @@ QModelIndex RemoteModel::modelIndexForNode(Node *node, int column) const
 {
     Q_ASSERT(node);
     if (node == m_root)
-        return QModelIndex();
-    return createIndex(node->parent->children.indexOf(node), column, node);
+        return {};
+
+    int row = -1;
+    if (node->rowHint > 0 && node->rowHint < node->parent->children.size()) {
+        if (node->parent->children.at(node->rowHint) == node)
+            row = node->rowHint;
+    }
+    if (row < 0) {
+        row = node->parent->children.indexOf(node);
+    }
+
+    return createIndex(row, column, node);
 }
 
 bool RemoteModel::isAncestor(RemoteModel::Node *ancestor, RemoteModel::Node *child) const
@@ -701,8 +702,8 @@ RemoteModelNodeState::NodeStates RemoteModel::stateForColumn(RemoteModel::Node *
     Q_ASSERT(node);
     if (!node->hasColumnData())
         return RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated;
-    Q_ASSERT(node->state.size() > columnIndex);
-    return node->state.at(columnIndex);
+    Q_ASSERT((int)node->state.size() > columnIndex);
+    return node->state[columnIndex];
 }
 
 void RemoteModel::requestRowColumnCount(const QModelIndex &index) const
@@ -734,7 +735,7 @@ void RemoteModel::requestDataAndFlags(const QModelIndex &index) const
     Q_ASSERT((state & RemoteModelNodeState::Loading) == 0);
 
     node->allocateColumns();
-    Q_ASSERT(node->state.size() > index.column());
+    Q_ASSERT((int)node->state.size() > index.column());
     node->state[index.column()] = state | RemoteModelNodeState::Loading; // mark pending request
 
     auto &indexes = m_pendingRequests[DataAndFlags];
@@ -761,7 +762,7 @@ void RemoteModel::doRequests() const
         case RowColumnCount: {
             Message msg(m_myAddress, Protocol::ModelRowColumnCountRequest);
             msg << quint32(indexes.size());
-            foreach (const auto &index, indexes)
+            for (const auto &index : indexes)
                 msg << index;
             sendMessage(msg);
             break;
@@ -770,7 +771,7 @@ void RemoteModel::doRequests() const
         case DataAndFlags: {
             Message msg(m_myAddress, Protocol::ModelContentRequest);
             msg << quint32(indexes.size());
-            foreach (const auto &index, indexes)
+            for (const auto &index : indexes)
                 msg << index;
             sendMessage(msg);
             break;
@@ -956,14 +957,14 @@ void RemoteModel::doInsertColumns(RemoteModel::Node *parentNode, int first, int
         m_horizontalHeaders.insert(first, newColCount, QHash<int, QVariant>());
 
     // adjust column data in all child nodes, if available
-    foreach (auto node, parentNode->children) {
+    for (auto node : qAsConst(parentNode->children)) {
         if (!node->hasColumnData())
             continue;
 
         // allocate new columns
         node->data.insert(first, newColCount, QHash<int, QVariant>());
         node->flags.insert(first, newColCount, Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-        node->state.insert(first, newColCount, RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated);
+        node->state.insert(node->state.begin() + first, newColCount, RemoteModelNodeState::Empty | RemoteModelNodeState::Outdated);
     }
 
     // adjust column count
@@ -983,12 +984,12 @@ void RemoteModel::doRemoveColumns(RemoteModel::Node *parentNode, int first, int
         m_horizontalHeaders.remove(first, delColCount);
 
     // adjust column data in all child nodes, if available
-    foreach (auto node, parentNode->children) {
+    for (auto node : qAsConst(parentNode->children)) {
         if (!node->hasColumnData())
             continue;
         node->data.remove(first, delColCount);
         node->flags.remove(first, delColCount);
-        node->state.remove(first, delColCount);
+        node->state.erase(node->state.begin() + first, node->state.begin() + last);
     }
 
     // adjust column count
@@ -1004,10 +1005,10 @@ void RemoteModel::registerClient(const QString &serverObject)
         return;
     }
     m_myAddress = Endpoint::instance()->objectAddress(serverObject);
-    connect(Endpoint::instance(), SIGNAL(objectRegistered(QString,Protocol::ObjectAddress)),
-            SLOT(serverRegistered(QString,Protocol::ObjectAddress)));
-    connect(Endpoint::instance(), SIGNAL(objectUnregistered(QString,Protocol::ObjectAddress)),
-            SLOT(serverUnregistered(QString,Protocol::ObjectAddress)));
+    connect(Endpoint::instance(), &Endpoint::objectRegistered,
+            this, &RemoteModel::serverRegistered);
+    connect(Endpoint::instance(), &Endpoint::objectUnregistered,
+            this, &RemoteModel::serverUnregistered);
 }
 
 void RemoteModel::sendMessage(const Message &msg) const
