@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -58,7 +58,7 @@ class GAMMARAY_CLIENT_EXPORT RemoteModel : public QAbstractItemModel
 
 public:
     explicit RemoteModel(const QString &serverObject, QObject *parent = nullptr);
-    ~RemoteModel();
+    ~RemoteModel() override;
 
     bool isConnected() const;
 
@@ -88,10 +88,7 @@ signals:
 
 private:
     struct Node { // represents one row
-        Node()
-            : parent(nullptr)
-            , rowCount(-1)
-            , columnCount(-1) {}
+        Node() = default;
         ~Node();
         Q_DISABLE_COPY(Node)
         // delete all cached children data, but assume row/column count on this level is still accurate
@@ -104,13 +101,15 @@ private:
         // returns whether columns are allocated
         bool hasColumnData() const;
 
-        Node *parent;
+        Node *parent = nullptr;
         QVector<Node *> children;
-        qint32 rowCount;
-        qint32 columnCount;
+        qint32 rowCount = -1;
+        qint32 columnCount = -1;
         QVector<QHash<int, QVariant> > data; // column -> role -> data
         QVector<Qt::ItemFlags> flags;      // column -> flags
-        QVector<RemoteModelNodeState::NodeStates> state;         // column -> state (cache outdated, waiting for data, etc)
+        std::vector<RemoteModelNodeState::NodeStates> state;         // column -> state (cache outdated, waiting for data, etc)
+
+        int rowHint = -1; // for internal use by modelIndexForNode
     };
 
     void clear();
