@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,8 +36,9 @@ TcpClientDevice::TcpClientDevice(QObject *parent)
     : ClientDeviceImpl<QTcpSocket>(parent)
 {
     m_socket = new QTcpSocket(this);
-    connect(m_socket, SIGNAL(connected()), this, SIGNAL(connected()));
-    connect(m_socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(socketError()));
+    connect(m_socket, &QAbstractSocket::connected, this, &ClientDevice::connected);
+    connect(m_socket, static_cast<void(QAbstractSocket::*)(QAbstractSocket::SocketError)>(&QAbstractSocket::error),
+            this, &TcpClientDevice::socketError);
 }
 
 void TcpClientDevice::connectToHost()
