@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -94,7 +94,7 @@ public:
         scratchSpace.reserve(32);
     }
 
-    ~MessageBuffer() {}
+    ~MessageBuffer() = default;
 
     void clear()
     {
@@ -134,16 +134,14 @@ Message::Message(Protocol::ObjectAddress objectAddress, Protocol::MessageType ty
     m_buffer->stream.setVersion(s_streamVersion);
 }
 
-Message::Message(Message &&other)
+Message::Message(Message &&other) Q_DECL_NOEXCEPT
     : m_objectAddress(other.m_objectAddress)
     , m_messageType(other.m_messageType)
     , m_buffer(std::move(other.m_buffer))
 {
 }
 
-Message::~Message()
-{
-}
+Message::~Message() = default;
 
 Protocol::ObjectAddress Message::address() const
 {
@@ -213,22 +211,12 @@ Message Message::readMessage(QIODevice *device)
 
 quint8 Message::lowestSupportedDataVersion()
 {
-    return QDataStream::Qt_4_8;
+    return QDataStream::Qt_5_5;
 }
 
 quint8 Message::highestSupportedDataVersion()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     return QDataStream::Qt_DefaultCompiledVersion;
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
-    return QDataStream::Qt_5_2;
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
-    return QDataStream::Qt_5_1;
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    return QDataStream::Qt_5_0;
-#else
-    return lowestSupportedDataVersion();
-#endif
 }
 
 quint8 Message::negotiatedDataVersion()
