@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,23 +47,20 @@
 #include <QMatrix4x4>
 #include <QPainter>
 #include <QPaintEngine>
+#include <QValidator>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QGuiApplication>
 #include <QOpenGLShader>
 #include <QSurfaceFormat>
 #endif
-#endif
 
 Q_DECLARE_METATYPE(Qt::ConnectionType)
 Q_DECLARE_METATYPE(QMetaMethod::Access)
 Q_DECLARE_METATYPE(QMetaMethod::MethodType)
 Q_DECLARE_METATYPE(const QMetaObject *)
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
 #include <QTimeZone>
 Q_DECLARE_METATYPE(QTimeZone)
-#endif
 
 #ifdef QT_GUI_LIB // TODO move all this to the GUI support plug-in
 Q_DECLARE_METATYPE(Qt::FillRule)
@@ -75,7 +72,8 @@ Q_DECLARE_METATYPE(QPolygonF)
 Q_DECLARE_METATYPE(QMargins)
 Q_DECLARE_METATYPE(Qt::WindowType)
 Q_DECLARE_METATYPE(Qt::WindowState)
-Q_DECLARE_METATYPE(const QMatrix4x4 *)
+Q_DECLARE_METATYPE(const QMatrix4x4*)
+Q_DECLARE_METATYPE(const QValidator*)
 
 Q_DECLARE_METATYPE(QPainter::CompositionMode)
 #if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
@@ -83,16 +81,10 @@ Q_DECLARE_METATYPE(QPainter::RenderHints)
 #endif
 Q_DECLARE_METATYPE(QPaintEngine::PolygonDrawMode)
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #ifndef QT_NO_OPENGL
 Q_DECLARE_METATYPE(QOpenGLShader::ShaderType)
 #endif
 Q_DECLARE_METATYPE(QSurfaceFormat)
 #endif
-#endif
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0) && QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-Q_DECLARE_METATYPE(Qt::ApplicationState)
-#endif
 
 #endif
