@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -54,7 +54,7 @@ QDataStream &operator>>(QDataStream &in, QItemSelectionModel::SelectionFlags &co
 static void writeSelection(Message *msg, const QItemSelection &selection)
 {
     *msg << qint32(selection.size());
-    foreach (const QItemSelectionRange &range, selection)
+    for (const QItemSelectionRange &range : selection)
         *msg << Protocol::fromQModelIndex(range.topLeft()) << Protocol::fromQModelIndex(
             range.bottomRight());
 }
@@ -82,13 +82,11 @@ NetworkSelectionModel::NetworkSelectionModel(const QString &objectName, QAbstrac
     , m_handlingRemoteMessage(false)
 {
     setObjectName(m_objectName + QLatin1String("Network"));
-    connect(this, SIGNAL(currentChanged(QModelIndex,QModelIndex)), this,
-            SLOT(slotCurrentChanged(QModelIndex,QModelIndex)));
+    connect(this, &QItemSelectionModel::currentChanged, this,
+            &NetworkSelectionModel::slotCurrentChanged);
 }
 
-NetworkSelectionModel::~NetworkSelectionModel()
-{
-}
+NetworkSelectionModel::~NetworkSelectionModel() = default;
 
 void NetworkSelectionModel::requestSelection()
 {
@@ -112,12 +110,7 @@ void NetworkSelectionModel::sendSelection()
                   |QItemSelectionModel::Rows
                   | QItemSelectionModel::Current;
             const Qt::MatchFlags matchFlags = Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
             QAbstractItemModel *sourceModel = findSourceModel(model());
-#else
-            QAbstractItemModel *sourceModel
-                = findSourceModel(const_cast<QAbstractItemModel *>(model()));
-#endif
             QModelIndex index = model()->index(0, 0);
 
             // Query the model to get its default selected index
@@ -174,7 +167,7 @@ bool GammaRay::NetworkSelectionModel::translateSelection(const Protocol::ItemSel
                                                          QItemSelection &qselection) const
 {
     qselection.clear();
-    foreach (const auto &range, selection) {
+    for (const auto &range : selection) {
         const QModelIndex qmiTopLeft = Protocol::toQModelIndex(model(), range.topLeft);
         const QModelIndex qmiBottomRight = Protocol::toQModelIndex(model(), range.bottomRight);
         if (!qmiTopLeft.isValid() && !qmiBottomRight.isValid())
