@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,7 +40,7 @@ class NetworkSelectionModel : public QItemSelectionModel
 {
     Q_OBJECT
 public:
-    ~NetworkSelectionModel();
+    ~NetworkSelectionModel() override;
 
     void select(const QItemSelection &selection,
                 QItemSelectionModel::SelectionFlags command) override;
@@ -69,6 +69,7 @@ private slots:
 
     void slotCurrentChanged(const QModelIndex &current, const QModelIndex &previous);
 
+protected slots:
     void clearPendingSelection();
 
 private:
