@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,15 +42,13 @@
 
 namespace GammaRay {
 struct ObjectlBrokerData {
-    ObjectlBrokerData()
-        : modelCallback(nullptr)
-        , selectionCallback(nullptr) {}
+    ObjectlBrokerData() = default;
     QHash<QString, QObject *> objects;
     QHash<QString, QAbstractItemModel *> models;
     QHash<QAbstractItemModel *, QItemSelectionModel *> selectionModels;
     QHash<QByteArray, ObjectBroker::ClientObjectFactoryCallback> clientObjectFactories;
-    ObjectBroker::ModelFactoryCallback modelCallback;
-    ObjectBroker::selectionModelFactoryCallback selectionCallback;
+    ObjectBroker::ModelFactoryCallback modelCallback = nullptr;
+    ObjectBroker::selectionModelFactoryCallback selectionCallback = nullptr;
     QVector<QObject *> ownedObjects;
 };
 
