@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -138,6 +138,28 @@ QStringList pluginPaths(const QString &probeABI)
     return l;
 }
 
+QStringList targetPluginPaths(const QString& probeABI)
+{
+    QStringList l;
+
+    // based on rootPath()
+    addPluginPath(l, rootPath() + QLatin1String("/" GAMMARAY_TARGET_PLUGIN_INSTALL_DIR "/" GAMMARAY_PLUGIN_VERSION "/") + probeABI);
+    addPluginPath(l, rootPath() + QLatin1String("/" GAMMARAY_TARGET_PLUGIN_INSTALL_DIR));
+
+    // based on Qt plugin search paths
+    foreach (const auto &path, QCoreApplication::libraryPaths()) {
+        addPluginPath(l, path + QLatin1String("/gammaray/" GAMMARAY_PLUGIN_VERSION "/") + probeABI + QLatin1String("/target"));
+        addPluginPath(l, path + QLatin1String("/gammaray-target"));
+    }
+
+    // based on Qt's own install layout and/or qt.conf
+    const auto path = QLibraryInfo::location(QLibraryInfo::PluginsPath);
+    addPluginPath(l, path + QLatin1String("/gammaray/" GAMMARAY_PLUGIN_VERSION "/") + probeABI + QLatin1String("/target"));
+    addPluginPath(l, path + QLatin1String("/gammaray-target"));
+
+    return l;
+}
+
 QString currentPluginsPath()
 {
 #ifndef GAMMARAY_INSTALL_QT_LAYOUT
