@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -71,7 +71,7 @@ GAMMARAY_COMMON_EXPORT QString libexecPath();
  */
 GAMMARAY_COMMON_DEPRECATED_EXPORT QString currentProbePath();
 
-/*! Returns a list of plugin search paths for the given ABI.
+/*! Returns a list of probe plugin search paths for the given ABI.
  *  This includes candidates based on Qt's plugin search paths, and GammaRay's
  *  install layout.
  *  @param probeABI The ABI identifier we are looking for plugins for. If you
@@ -79,6 +79,14 @@ GAMMARAY_COMMON_DEPRECATED_EXPORT QString currentProbePath();
  */
 GAMMARAY_COMMON_EXPORT QStringList pluginPaths(const QString &probeABI);
 
+/*! Returns a list of target plugin search paths for the given ABI.
+ *  This includes candidates based on Qt's plugin search paths, and GammaRay's
+ *  install layout.
+ *  @param probeABI The ABI identifier we are looking for plugins for. If you
+ *   are actually loading plugins, this must be GAMMARAY_PROBE_ABI.
+ */
+GAMMARAY_COMMON_EXPORT QStringList targetPluginPaths(const QString &probeABI);
+
 /*! Returns the path to the current plugins location.
  *  This is the same as currentProbePath() when using the GammaRay installation layout,
  *  but differs with e.g. the Android installation layout.
