@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,20 +29,18 @@
 #include "plugininfo.h"
 #include "paths.h"
 
+#include <compat/qasconst.h>
+
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
 #include <QLibrary>
 #include <QLocale>
-#include <QSettings>
 #include <QCoreApplication>
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QJsonValue>
 #include <QPluginLoader>
-#endif
 
 using namespace GammaRay;
 
@@ -57,29 +55,21 @@ PluginInfo::PluginInfo(const QString& path)
     // OSX has broken QLibrary::isLibrary() - QTBUG-50446
     if (QLibrary::isLibrary(path) || path.endsWith(Paths::pluginExtension(), Qt::CaseInsensitive))
         initFromJSON(path);
-    else if (path.endsWith(QLatin1String(".desktop")))
-        initFromDesktopFile(path);
-    else
-        qDebug("%s: %s not a library, nor a .desktop file.", Q_FUNC_INFO, qPrintable(path));
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
 PluginInfo::PluginInfo(const QStaticPlugin &staticPlugin)
 {
     init();
     m_staticPlugin = staticPlugin;
     initFromJSON(staticPlugin.metaData());
 }
-#endif
 
 void PluginInfo::init()
 {
     m_remoteSupport = true;
     m_hidden = false;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     m_staticPlugin.instance = nullptr;
     m_staticPlugin.rawMetaData = nullptr;
-#endif
 }
 
 QString PluginInfo::path() const
@@ -127,7 +117,6 @@ bool PluginInfo::isValid() const
     return !m_id.isEmpty() && (isStatic() || !m_path.isEmpty()) && !m_interface.isEmpty();
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 static QString readLocalized(const QLocale &locale, const QJsonObject &obj, const QString &baseKey)
 {
     const QString qtcLanguage = qApp->property("qtc_locale").toString();
@@ -135,7 +124,7 @@ static QString readLocalized(const QLocale &locale, const QJsonObject &obj, cons
     if (!qtcLanguage.isEmpty())
         names.prepend(qtcLanguage);
 
-    foreach (auto name, names) {
+    for (auto name : qAsConst(names)) {
         const QLocale uiLocale(name);
 
         // We are natively English, skip...
@@ -164,40 +153,26 @@ static QString readLocalized(const QLocale &locale, const QJsonObject &obj, cons
 
     return obj.value(baseKey).toString();
 }
-#endif
 
 bool PluginInfo::isStatic() const
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     return m_staticPlugin.instance && m_staticPlugin.rawMetaData;
-#else
-    return false;
-#endif
 }
 
 QObject* PluginInfo::staticInstance() const
 {
     Q_ASSERT(isStatic());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     return m_staticPlugin.instance();
-#else
-    return nullptr;
-#endif
 }
 
 void PluginInfo::initFromJSON(const QString &path)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     const QPluginLoader loader(path);
     const QJsonObject metaData = loader.metaData();
     initFromJSON(metaData);
     m_path = path;
-#else
-    Q_UNUSED(path);
-#endif
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 void PluginInfo::initFromJSON(const QJsonObject &metaData)
 {
     m_interface = metaData.value(QStringLiteral("IID")).toString();
@@ -213,47 +188,8 @@ void PluginInfo::initFromJSON(const QJsonObject &metaData)
     for (auto it = types.constBegin(); it != types.constEnd(); ++it)
         m_supportedTypes.push_back((*it).toString());
 
-    const auto selectable = customData.value(QStringLiteral("selectableTypes")).toArray();
-    m_selectableTypes.reserve(selectable.size());
-    for (auto it = selectable.begin(); it != selectable.end(); ++it)
-        m_selectableTypes.push_back((*it).toString().toUtf8());
-}
-#endif
-
-void PluginInfo::initFromDesktopFile(const QString &path)
-{
-    const QFileInfo fi(path);
-    QSettings desktopFile(path, QSettings::IniFormat);
-    desktopFile.beginGroup(QStringLiteral("Desktop Entry"));
-
-    m_id = desktopFile.value(QStringLiteral("X-GammaRay-Id")).toString();
-    m_interface
-        = desktopFile.value(QStringLiteral("X-GammaRay-ServiceTypes"), QString()).toString();
-    m_supportedTypes = desktopFile.value(QStringLiteral("X-GammaRay-Types")).toString().split(QLatin1Char(
-                                                                                                  ';'),
-                                                                                              QString::SkipEmptyParts);
-    m_name = desktopFile.value(QStringLiteral("Name")).toString();
-    m_remoteSupport = desktopFile.value(QStringLiteral("X-GammaRay-Remote"), true).toBool();
-    m_hidden = desktopFile.value(QStringLiteral("Hidden"), false).toBool();
-
-    const auto selectable
-        = desktopFile.value(QStringLiteral("X-GammaRay-SelectableTypes")).toString().split(QLatin1Char(
-                                                                                               ';'),
-                                                                                           QString::SkipEmptyParts);
-    m_selectableTypes.reserve(selectable.size());
-    foreach (const auto &t, selectable)
-        m_selectableTypes.push_back(t.toUtf8());
-
-    const QString dllBaseName = desktopFile.value(QStringLiteral("Exec")).toString();
-    if (dllBaseName.isEmpty())
-        return;
-
-    foreach (const QString &entry,
-             fi.dir().entryList(QStringList(dllBaseName + QLatin1Char('*')), QDir::Files)) {
-        const QString pluginPath = fi.dir().absoluteFilePath(entry);
-        if (QLibrary::isLibrary(pluginPath)) {
-            m_path = pluginPath;
-            break;
-        }
-    }
+    const auto selectableTypes = customData.value(QStringLiteral("selectableTypes")).toArray();
+    m_selectableTypes.reserve(selectableTypes.size());
+    for (auto &&selectable : selectableTypes)
+        m_selectableTypes.push_back(selectable.toString().toUtf8());
 }
