@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,9 +47,7 @@ class PluginInfo
 public:
     PluginInfo();
     explicit PluginInfo(const QString &path);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     explicit PluginInfo(const QStaticPlugin &staticPlugin);
-#endif
 
     QString path() const;
     QString id() const;
@@ -68,15 +66,10 @@ public:
 private:
     void init();
     void initFromJSON(const QString &path);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     void initFromJSON(const QJsonObject& metaData);
-#endif
-    void initFromDesktopFile(const QString &path);
 
     QString m_path;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     QStaticPlugin m_staticPlugin;
-#endif
     QString m_id;
     QString m_interface;
     QStringList m_supportedTypes;
