@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,9 +48,7 @@ PluginManagerBase::PluginManagerBase(QObject *parent)
 {
 }
 
-PluginManagerBase::~PluginManagerBase()
-{
-}
+PluginManagerBase::~PluginManagerBase() = default;
 
 QStringList PluginManagerBase::pluginPaths() const
 {
@@ -64,22 +62,11 @@ QStringList PluginManagerBase::pluginPaths() const
 QStringList PluginManagerBase::pluginFilter() const
 {
     QStringList filter;
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-#if defined(GAMMARAY_INSTALL_QT_LAYOUT)
-    filter.push_back(QStringLiteral("*") + QStringLiteral(GAMMARAY_PROBE_ABI)
-                     + QStringLiteral(".desktop"));
-#else
-    filter.push_back(QStringLiteral("*.desktop"));
-#endif
-#elif defined(Q_OS_ANDROID)
-    filter.push_back(QStringLiteral("libplugins_gammaray_gammaray_*") + Paths::pluginExtension());
-#else
 #if defined(GAMMARAY_INSTALL_QT_LAYOUT)
     filter.push_back(QStringLiteral("*") + QStringLiteral(
                          GAMMARAY_PROBE_ABI) + Paths::pluginExtension());
 #else
     filter.push_back(QStringLiteral("*") + Paths::pluginExtension());
-#endif
 #endif
     return filter;
 }
@@ -89,7 +76,6 @@ void PluginManagerBase::scan(const QString &serviceType)
     m_errors.clear();
     QStringList loadedPluginNames;
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     foreach (const auto &staticPlugin, QPluginLoader::staticPlugins()) {
         PluginInfo pluginInfo(staticPlugin);
 
@@ -101,7 +87,6 @@ void PluginManagerBase::scan(const QString &serviceType)
         if (createProxyFactory(pluginInfo, m_parent))
             loadedPluginNames.push_back(pluginInfo.id());
     }
-#endif
 
     foreach (const QString &pluginPath, pluginPaths()) {
         const QDir dir(pluginPath);
