@@ -4,11 +4,11 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
-  acuordance with GammaRay Commercial License Agreement provided with the Software.
+  accordance with GammaRay Commercial License Agreement provided with the Software.
 
   Contact info@kdab.com if any conditions of this licensing are not clear to you.
 
@@ -30,6 +30,9 @@
 
 using namespace GammaRay;
 
-ProbeControllerInterface::~ProbeControllerInterface()
+ProbeControllerInterface::ProbeControllerInterface(QObject *parent)
+    : QObject(parent)
 {
 }
+
+ProbeControllerInterface::~ProbeControllerInterface() = default;
