@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,6 +27,11 @@
 #ifndef GAMMARAY_PROPERTYMODEL_H
 #define GAMMARAY_PROPERTYMODEL_H
 
+#include "modelroles.h"
+
+#include <QMetaType>
+#include <QFlags>
+
 namespace GammaRay {
 /**
  * @brief GammaRay property model roles.
@@ -37,11 +42,13 @@ namespace GammaRay {
 namespace PropertyModel {
 /** Role enum, to be used with the property models. */
 enum Role {
-    // Qt4 uses 32, Qt5 256, for Qt::UserRole - use the latter globally to allow combining Qt4/5 client/servers.
-    ActionRole = 256 + 1,   /**< the property action role */
-    UserRole,                /**< the UserRole, as defined by Qt */
+    ActionRole = GammaRay::UserRole + 1, /**< the property action role */
+    DeprecatedRole,                /**< @deprecated do not use */
     ObjectIdRole,
-    ResetActionRole
+    ResetActionRole,
+    PropertyFlagsRole,
+    PropertyRevisionRole,
+    NotifySignalRole
 };
 
 /** Available property actions. */
@@ -59,7 +66,27 @@ enum Column {
     TypeColumn,
     ClassColumn
 };
+
+/** Property flags.
+ *  @see QMetaProperty
+ */
+enum PropertyFlag {
+    None = 0,
+    Constant = 1,
+    Designable = 2,
+    Final = 4,
+    Resetable = 8,
+    Scriptable = 16,
+    Stored = 32,
+    User = 64,
+    Writable = 128
+};
+Q_DECLARE_FLAGS(PropertyFlags, PropertyFlag)
+
 }
 }
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(GammaRay::PropertyModel::PropertyFlags)
+Q_DECLARE_METATYPE(GammaRay::PropertyModel::PropertyFlags)
+
 #endif
