@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class GAMMARAY_COMMON_EXPORT PropertySyncer : public QObject
     Q_OBJECT
 public:
     explicit PropertySyncer(QObject *parent = nullptr);
-    ~PropertySyncer();
+    ~PropertySyncer() override;
 
     /** Add an object that should be monitored for to be synced property changes. */
     void addObject(Protocol::ObjectAddress addr, QObject *obj);
