@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ QModelIndex toQModelIndex(const QAbstractItemModel *model, const Protocol::Model
     for (auto it = index.constBegin(), end = index.constEnd(); it != end; ++it) {
         qmi = model->index(it->row, it->column, qmi);
         if (!qmi.isValid())
-            return QModelIndex(); // model isn't loaded to the full depth, so don't restart from the top
+            return {}; // model isn't loaded to the full depth, so don't restart from the top
     }
 
     return qmi;
