@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class ProxyFactoryBase : public QObject
     Q_OBJECT
 public:
     explicit ProxyFactoryBase(const PluginInfo &pluginInfo, QObject *parent = nullptr);
-    ~ProxyFactoryBase();
+    ~ProxyFactoryBase() override;
 
     PluginInfo pluginInfo() const;
     QString errorString() const;
@@ -63,7 +63,7 @@ class ProxyFactory : public ProxyFactoryBase, public IFace
 public:
     explicit inline ProxyFactory(const PluginInfo &pluginInfo, QObject *parent = nullptr)
         : ProxyFactoryBase(pluginInfo, parent) {}
-    inline ~ProxyFactory() {}
+    inline ~ProxyFactory() override = default;
 
     QString id() const override
     {
