@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,9 +39,7 @@ ConnectionsExtensionInterface::ConnectionsExtensionInterface(const QString &name
     ObjectBroker::registerObject(name, this);
 }
 
-ConnectionsExtensionInterface::~ConnectionsExtensionInterface()
-{
-}
+ConnectionsExtensionInterface::~ConnectionsExtensionInterface() = default;
 
 QString ConnectionsExtensionInterface::name() const
 {
