@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,6 +37,7 @@
 #include "varianthandler.h"
 #include "enumrepositoryserver.h"
 #include "enumutil.h"
+#include "util.h"
 
 #include <common/objectid.h>
 #include <common/propertymodel.h>
@@ -46,18 +47,28 @@
 
 using namespace GammaRay;
 
+
+Q_DECLARE_METATYPE(const QObject*)
+
+/*!
+ * Checks if it is dangerous to unpack a QVariant because it stores an invalid pointer.
+ * Returns true if the value is an invalid pointer to a QObject.
+ * Returns false either if it is a valid pointer or not a QObject*.
+ */
+bool isInvalidPointer(const QVariant& value) {
+    if (!value.canConvert<QObject *>() && !value.canConvert<const QObject *>())
+        return false;
+    return !Probe::instance()->isValidObject(Util::uncheckedQObjectCast(value));
+}
+
+
 AggregatedPropertyModel::AggregatedPropertyModel(QObject *parent)
     : QAbstractItemModel(parent)
-    , m_rootAdaptor(nullptr)
-    , m_inhibitAdaptorCreation(false)
-    , m_readOnly(false)
 {
     qRegisterMetaType<GammaRay::PropertyAdaptor *>();
 }
 
-AggregatedPropertyModel::~AggregatedPropertyModel()
-{
-}
+AggregatedPropertyModel::~AggregatedPropertyModel() = default;
 
 void AggregatedPropertyModel::setObject(const ObjectInstance &oi)
 {
@@ -135,12 +146,21 @@ QMap<int, QVariant> AggregatedPropertyModel::itemData(const QModelIndex &index)
     const auto d = adaptor->propertyData(index.row());
 
     res.insert(Qt::DisplayRole, data(adaptor, d, index.column(), Qt::DisplayRole));
-    res.insert(Qt::ToolTipRole, data(adaptor, d, index.column(), Qt::ToolTipRole));
     res.insert(PropertyModel::ActionRole, data(adaptor, d,
                                                index.column(), PropertyModel::ActionRole));
     res.insert(PropertyModel::ObjectIdRole,
                data(adaptor, d, index.column(), PropertyModel::ObjectIdRole));
-    if (index.column() == 1) {
+    if (index.column() == 0) {
+        auto v = data(adaptor, d, index.column(), PropertyModel::PropertyFlagsRole);
+        if (!v.isNull())
+            res.insert(PropertyModel::PropertyFlagsRole, v);
+        v = data(adaptor, d, index.column(), PropertyModel::PropertyRevisionRole);
+        if (!v.isNull())
+            res.insert(PropertyModel::PropertyRevisionRole, v);
+        v = data(adaptor, d, index.column(), PropertyModel::NotifySignalRole);
+        if (!v.isNull())
+            res.insert(PropertyModel::NotifySignalRole, v);
+    } else if (index.column() == 1) {
         res.insert(Qt::EditRole, data(adaptor, d, index.column(), Qt::EditRole));
         res.insert(Qt::DecorationRole, data(adaptor, d, index.column(), Qt::DecorationRole));
         if (d.value().type() == QVariant::Bool)
@@ -164,8 +184,10 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
             const QString enumStr = EnumUtil::enumToString(d.value(), d.typeName().toLatin1(), adaptor->object().metaObject());
             if (!enumStr.isEmpty())
                 return enumStr;
-            if (d.value().type() == QVariant::Bool && (d.flags() & PropertyData::Writable))
+            if (d.value().type() == QVariant::Bool && (d.accessFlags() & PropertyData::Writable))
                 return QVariant();
+            if (isInvalidPointer(d.value()) && Util::uncheckedQObjectCast(d.value()) != nullptr)
+                return "[invalid]";
             return VariantHandler::displayString(d.value());
         }
         case 2:
@@ -184,22 +206,20 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
             return VariantHandler::serializableVariant(d.value());
         }
         break;
-    case Qt::ToolTipRole:
-        return d.details();
     case Qt::DecorationRole:
         if (column == 1)
             return VariantHandler::decoration(d.value());
         break;
     case Qt::CheckStateRole:
-        if (column == 1 && d.value().type() == QVariant::Bool && (d.flags() & PropertyData::Writable))
+        if (column == 1 && d.value().type() == QVariant::Bool && (d.accessFlags() & PropertyData::Writable))
             return d.value().toBool() ? Qt::Checked : Qt::Unchecked;
         break;
     case PropertyModel::ActionRole:
     {
         int actions = PropertyModel::NoAction;
-        if (d.flags() & PropertyData::Resettable)
+        if (d.accessFlags() & PropertyData::Resettable)
             actions |= PropertyModel::Reset;
-        if (d.flags() & PropertyData::Deletable)
+        if (d.accessFlags() & PropertyData::Deletable)
             actions |= PropertyModel::Delete;
         if ((MetaObjectRepository::instance()->metaObject(d.typeName())
              && *reinterpret_cast<void * const *>(d.value().data()))
@@ -209,6 +229,8 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
     }
     case PropertyModel::ObjectIdRole:
         if (d.value().canConvert<QObject *>()) {
+            if (isInvalidPointer(d.value()))
+                return QVariant();
             return QVariant::fromValue(ObjectId(d.value().value<QObject *>()));
         } else if (d.value().isValid()) {
             const auto &v = d.value();
@@ -216,8 +238,19 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
                                                 v.typeName()));
         }
         return QVariant();
+    case PropertyModel::PropertyFlagsRole:
+        if (column == 0 && d.propertyFlags() != PropertyModel::None)
+            return QVariant::fromValue(d.propertyFlags());
+        return QVariant();
+    case PropertyModel::PropertyRevisionRole:
+        if (column == 0 && d.revision() >= 0)
+            return d.revision();
+        return QVariant();
+    case PropertyModel::NotifySignalRole:
+        if (column == 0 && !d.notifySignal().isEmpty())
+            return d.notifySignal();
+        return QVariant();
     }
-
     return QVariant();
 }
 
@@ -275,7 +308,7 @@ int AggregatedPropertyModel::rowCount(const QModelIndex &parent) const
     if (!m_inhibitAdaptorCreation && !siblings.at(parent.row())) {
         // TODO: remember we tried any of this
         auto pd = adaptor->propertyData(parent.row());
-        if (!hasLoop(adaptor, pd.value())) {
+        if (!isInvalidPointer(pd.value()) && !hasLoop(adaptor, pd.value())) {
             auto a = PropertyAdaptorFactory::create(pd.value(), adaptor);
             siblings[parent.row()] = a;
             addPropertyAdaptor(a);
@@ -295,36 +328,18 @@ Qt::ItemFlags AggregatedPropertyModel::flags(const QModelIndex &index) const
 
     auto adaptor = adaptorForIndex(index);
     auto data = adaptor->propertyData(index.row());
-    const auto editable = (data.flags() & PropertyData::Writable) && isParentEditable(adaptor);
+    const auto editable = (data.accessFlags() & PropertyData::Writable) && isParentEditable(adaptor);
     const auto booleanEditable = editable && data.value().type() == QVariant::Bool;
     if (booleanEditable)
         return baseFlags | Qt::ItemIsUserCheckable;
     return editable ? (baseFlags | Qt::ItemIsEditable) : baseFlags;
 }
 
-QVariant AggregatedPropertyModel::headerData(int section, Qt::Orientation orientation,
-                                             int role) const
-{
-    if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
-        switch (section) {
-        case 0:
-            return tr("Property");
-        case 1:
-            return tr("Value");
-        case 2:
-            return tr("Type");
-        case 3:
-            return tr("Class");
-        }
-    }
-    return QAbstractItemModel::headerData(section, orientation, role);
-}
-
 QModelIndex AggregatedPropertyModel::parent(const QModelIndex &child) const
 {
     auto childAdaptor = adaptorForIndex(child);
     if (childAdaptor == m_rootAdaptor)
-        return QModelIndex();
+        return {};
 
     auto parentAdaptor = childAdaptor->parentAdaptor();
     return createIndex(m_parentChildrenMap.value(parentAdaptor).indexOf(
@@ -334,7 +349,7 @@ QModelIndex AggregatedPropertyModel::parent(const QModelIndex &child) const
 QModelIndex AggregatedPropertyModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (!hasIndex(row, column, parent) || !m_rootAdaptor)
-        return QModelIndex();
+        return {};
 
     if (!parent.isValid())
         return createIndex(row, column, m_rootAdaptor);
@@ -356,9 +371,9 @@ void AggregatedPropertyModel::addPropertyAdaptor(PropertyAdaptor *adaptor) const
     QVector<PropertyAdaptor *> children;
     children.resize(adaptor->count());
     m_parentChildrenMap.insert(adaptor, children);
-    connect(adaptor, SIGNAL(propertyChanged(int,int)), this, SLOT(propertyChanged(int,int)));
-    connect(adaptor, SIGNAL(propertyAdded(int,int)), this, SLOT(propertyAdded(int,int)));
-    connect(adaptor, SIGNAL(propertyRemoved(int,int)), this, SLOT(propertyRemoved(int,int)));
+    connect(adaptor, &PropertyAdaptor::propertyChanged, this, &AggregatedPropertyModel::propertyChanged);
+    connect(adaptor, &PropertyAdaptor::propertyAdded, this, &AggregatedPropertyModel::propertyAdded);
+    connect(adaptor, &PropertyAdaptor::propertyRemoved, this, &AggregatedPropertyModel::propertyRemoved);
 }
 
 void AggregatedPropertyModel::propertyChanged(int first, int last)
@@ -477,7 +492,8 @@ void AggregatedPropertyModel::reloadSubTree(PropertyAdaptor *parentAdaptor, int
     // re-add the sub-tree
     // TODO consolidate with code in rowCount()
     auto pd = parentAdaptor->propertyData(index);
-    if (hasLoop(parentAdaptor, pd.value())) {
+
+    if (isInvalidPointer(pd.value()) || hasLoop(parentAdaptor, pd.value())) {
         m_inhibitAdaptorCreation = false;
         return;
     }
@@ -509,7 +525,7 @@ bool AggregatedPropertyModel::isParentEditable(PropertyAdaptor *adaptor) const
         Q_ASSERT(row >= 0);
 
         const auto pd = parentAdaptor->propertyData(row);
-        if ((pd.flags() & PropertyData::Writable) == 0)
+        if ((pd.accessFlags() & PropertyData::Writable) == 0)
             return false;
     }
 
