@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ class GAMMARAY_CORE_EXPORT AggregatedPropertyModel : public QAbstractItemModel
     Q_OBJECT
 public:
     explicit AggregatedPropertyModel(QObject *parent = nullptr);
-    ~AggregatedPropertyModel();
+    ~AggregatedPropertyModel() override;
 
     void setObject(const ObjectInstance &oi);
     void setReadOnly(bool readOnly);
@@ -60,8 +60,6 @@ public:
     QModelIndex index(int row, int column,
                       const QModelIndex &parent = QModelIndex()) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
-    QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const override;
     QMap<int, QVariant> itemData(const QModelIndex &index) const override;
 
 private:
@@ -82,10 +80,10 @@ private slots:
     void objectInvalidated(GammaRay::PropertyAdaptor *adaptor);
 
 private:
-    PropertyAdaptor *m_rootAdaptor;
+    PropertyAdaptor *m_rootAdaptor = nullptr;
     mutable QHash<PropertyAdaptor *, QVector<PropertyAdaptor *> > m_parentChildrenMap;
-    bool m_inhibitAdaptorCreation;
-    bool m_readOnly;
+    bool m_inhibitAdaptorCreation = false;
+    bool m_readOnly = false;
 };
 }
 
