@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,9 +30,7 @@
 
 using namespace GammaRay;
 
-MetaObject::MetaObject()
-{
-}
+MetaObject::MetaObject() = default;
 
 MetaObject::~MetaObject()
 {
@@ -42,14 +40,14 @@ MetaObject::~MetaObject()
 int MetaObject::propertyCount() const
 {
     int count = 0;
-    foreach (MetaObject *mo, m_baseClasses)
+    for (MetaObject *mo : m_baseClasses)
         count += mo->propertyCount();
     return count + m_properties.size();
 }
 
 MetaProperty *MetaObject::propertyAt(int index) const
 {
-    foreach (MetaObject *mo, m_baseClasses) {
+    for (MetaObject *mo : m_baseClasses) {
         if (index >= mo->propertyCount())
             index -= mo->propertyCount();
         else
@@ -114,7 +112,7 @@ bool MetaObject::isPolymorphic() const
 {
     if (isClassPolymorphic())
         return true;
-    foreach (const auto &baseClass, m_baseClasses) {
+    for (const auto &baseClass : m_baseClasses) {
         if (baseClass->isPolymorphic())
             return true;
     }
@@ -140,7 +138,7 @@ bool MetaObject::inherits(const QString &className) const
 {
     if (className == m_className)
         return true;
-    foreach (MetaObject *metaObject, m_baseClasses) {
+    for (MetaObject *metaObject : m_baseClasses) {
         if (metaObject->inherits(className))
             return true;
     }
