@@ -1,10 +1,10 @@
-/*
+﻿/*
   metaobjectrepository.h
 
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -95,18 +95,19 @@ public:
     void clear();
 
 protected:
-    MetaObjectRepository();
+    MetaObjectRepository() = default;
 
 private:
     Q_DISABLE_COPY(MetaObjectRepository)
     void initBuiltInTypes();
     void initQObjectTypes();
     void initIOTypes();
+    void initQEventTypes();
 
 private:
     QHash<QString, MetaObject*> m_metaObjects;
     std::unordered_map<MetaObject*, std::vector<MetaObject*> > m_derivedTypes;
-    bool m_initialized;
+    bool m_initialized = false;
 };
 }
 ///@cond internal
@@ -155,6 +156,13 @@ private:
     mo->addProperty(GammaRay::MetaPropertyFactory::makePropertyNonConst(#Getter, &Class::Getter));
 
 #if !defined(Q_CC_MSVC) || _MSC_VER >= 1900 //krazy:exclude=cpp
+/** Register a lamda property getter for class @p Class. */
+#define MO_ADD_PROPERTY_LD(Class, Name, Func) \
+{ \
+    const auto ld = Func; \
+    mo->addProperty(GammaRay::MetaPropertyFactory::makeProperty<Class, decltype(ld(std::declval<Class*>()))>(#Name, ld)); \
+}
+
 /** Register a read/write property for class @p Class.
  *  Use this for overloaded getters or setters that would confuse older MSVC versions.
  */
@@ -168,6 +176,7 @@ private:
     mo->addProperty(GammaRay::MetaPropertyFactory::makeProperty(#Getter, &Class::Getter));
 
 #else
+#define MO_ADD_PROPERTY_LD(Class, Name, Func)
 #define MO_ADD_PROPERTY_O2(Class, Getter, Setter)
 #define MO_ADD_PROPERTY_O1(Class, Getter)
 #endif
