@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,9 +39,7 @@ MetaProperty::MetaProperty(const char *name)
 {
 }
 
-MetaProperty::~MetaProperty()
-{
-}
+MetaProperty::~MetaProperty() = default;
 
 const char *MetaProperty::name() const
 {
