@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -51,12 +51,8 @@ void MethodArgumentModel::setMethod(const QMetaMethod &method)
 
 QVariant MethodArgumentModel::data(const QModelIndex &index, int role) const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    if (!m_method.signature() ||
-#else
-    if (m_method.methodSignature().isEmpty() ||
-#endif
-        m_arguments.isEmpty()
+    if (m_method.methodSignature().isEmpty()
+        || m_arguments.isEmpty()
         || index.row() < 0
         || index.row() >= m_arguments.size())
         return QVariant();
