@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,7 +40,7 @@ public:
     explicit MultiSignalMapperPrivate(MultiSignalMapper *parent)
         : QObject(parent)
         , q(parent) {}
-    ~MultiSignalMapperPrivate() {}
+    ~MultiSignalMapperPrivate() override = default;
 
     int qt_metacall(QMetaObject::Call call, int methodId, void **args) override
     {
@@ -69,7 +69,7 @@ public:
         const QList<QByteArray> paramTypes = signal.parameterTypes();
         for (int i = 0; i < paramTypes.size(); ++i) {
             int type = QMetaType::type(paramTypes[i]);
-            if (type == QMetaType::Void || !type) {
+            if (type == QMetaType::Void || type == QMetaType::UnknownType) {
                 qWarning() << Q_FUNC_INFO << "unknown metatype for signal argument type"
                            << paramTypes[i];
                 continue;
@@ -93,9 +93,7 @@ MultiSignalMapper::MultiSignalMapper(QObject *parent)
 {
 }
 
-MultiSignalMapper::~MultiSignalMapper()
-{
-}
+MultiSignalMapper::~MultiSignalMapper() = default;
 
 void MultiSignalMapper::connectToSignal(QObject *sender, const QMetaMethod &signal)
 {
