@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -60,6 +60,14 @@ public:
 
     Q_INVOKABLE QPair<int, QVariant> defaultSelectedItem() const;
 
+    /*!
+     * Returns a list of all objects.
+     *
+     * FIXME: This is a dirty hack. Instead of offering a getter to the internal data
+     * here, we should move it out and only give the model a view of the data.
+     */
+    const QVector<QObject*> &objects() const;
+
 private slots:
     void objectAdded(QObject *obj);
     void objectRemoved(QObject *obj);
