@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,12 +48,12 @@ using namespace GammaRay;
 ObjectTreeModel::ObjectTreeModel(Probe *probe)
     : ObjectModelBase< QAbstractItemModel >(probe)
 {
-    connect(probe, SIGNAL(objectCreated(QObject*)),
-            this, SLOT(objectAdded(QObject*)));
-    connect(probe, SIGNAL(objectDestroyed(QObject*)),
-            this, SLOT(objectRemoved(QObject*)));
-    connect(probe, SIGNAL(objectReparented(QObject*)),
-            this, SLOT(objectReparented(QObject*)));
+    connect(probe, &Probe::objectCreated,
+            this, &ObjectTreeModel::objectAdded);
+    connect(probe, &Probe::objectDestroyed,
+            this, &ObjectTreeModel::objectRemoved);
+    connect(probe, &Probe::objectReparented,
+            this, &ObjectTreeModel::objectReparented);
 }
 
 QPair<int, QVariant> ObjectTreeModel::defaultSelectedItem() const
@@ -242,14 +242,14 @@ QModelIndex ObjectTreeModel::index(int row, int column, const QModelIndex &paren
     QObject *parentObj = reinterpret_cast<QObject *>(parent.internalPointer());
     const QVector<QObject *> children = m_parentChildMap.value(parentObj);
     if (row < 0 || column < 0 || row >= children.size() || column >= columnCount())
-        return QModelIndex();
+        return {};
     return createIndex(row, column, children.at(row));
 }
 
 QModelIndex ObjectTreeModel::indexForObject(QObject *object) const
 {
     if (!object)
-        return QModelIndex();
+        return {};
     QObject *parent = m_childParentMap.value(object);
     const QModelIndex parentIndex = indexForObject(parent);
     if (!parentIndex.isValid() && parent)
