@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,12 +39,6 @@
 #include <limits>
 #include <vector>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-Q_DECLARE_METATYPE(Qt::BGMode)
-Q_DECLARE_METATYPE(Qt::ClipOperation)
-#endif
-
-#ifdef HAVE_PRIVATE_QT_HEADERS
 #include <private/qvectorpath_p.h>
 #include <private/qpainterpath_p.h>
 
@@ -432,6 +426,8 @@ QVariant PaintBufferModel::data(const QModelIndex &index, int role) const
                 if (index.column() == 2 && index.row() == 0)
                     return m_maxCost;
                 break;
+            case PaintBufferModelRoles::ObjectIdRole:
+                return QVariant::fromValue(m_buffer.origin(index.row()));
         }
     } else {
         const auto cmd = m_privateBuffer->commands.at(index.internalId());
@@ -450,14 +446,18 @@ QVariant PaintBufferModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
+QMap<int, QVariant> PaintBufferModel::itemData(const QModelIndex &index) const
+{
+    QMap<int, QVariant> d = QAbstractItemModel::itemData(index);
+    d.insert(PaintBufferModelRoles::MaxCostRole, data(index, PaintBufferModelRoles::MaxCostRole));
+    d.insert(PaintBufferModelRoles::ObjectIdRole, data(index, PaintBufferModelRoles::ObjectIdRole));
+    return d;
+}
+
 int PaintBufferModel::columnCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
-#ifdef USE_GAMMARAY_PAINTBUFFER
     return 3;
-#else
-    return 2;
-#endif
 }
 
 int PaintBufferModel::rowCount(const QModelIndex &parent) const
@@ -481,7 +481,7 @@ QModelIndex PaintBufferModel::index(int row, int column, const QModelIndex& pare
 QModelIndex PaintBufferModel::parent(const QModelIndex& child) const
 {
     if (child.internalId() == TopLevelId)
-        return QModelIndex();
+        return {};
     return createIndex(child.internalId(), 0, TopLevelId);
 }
 
@@ -561,5 +561,3 @@ QPainterPath PaintBufferModel::clipPath(int row) const
     }
     return clip;
 }
-
-#endif
