@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -59,7 +59,7 @@ class RemoteModelServer : public QObject
 public:
     /** Registers a new model server object with name @p objectName (must be unique). */
     explicit RemoteModelServer(const QString &objectName, QObject *parent = nullptr);
-    ~RemoteModelServer();
+    ~RemoteModelServer() override;
 
     /** Returns the source model. */
     QAbstractItemModel *model() const;
@@ -118,12 +118,8 @@ private slots:
     void columnsMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd,
                       const QModelIndex &destinationParent, int destinationColumn);
     void columnsRemoved(const QModelIndex &parent, int start, int end);
-#ifdef QT4_MOC_WORKAROUND // Qt4 moc doesn't understand QT_VERSION preprocessor conditionals
-    void layoutChanged();
-#else
     void layoutChanged(const QList<QPersistentModelIndex> &parents,
                        QAbstractItemModel::LayoutChangeHint hint);
-#endif
 
     void modelReset();
 
