@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class SelectionModelServer : public NetworkSelectionModel
 public:
     explicit SelectionModelServer(const QString &objectName, QAbstractItemModel *model,
                                   QObject *parent);
-    ~SelectionModelServer();
+    ~SelectionModelServer() override;
 
 protected:
     bool isConnected() const override;
