@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -66,18 +66,18 @@ Server::Server(QObject *parent)
     if (!m_serverDevice)
         return;
 
-    connect(m_serverDevice, SIGNAL(newConnection()), this, SLOT(newConnection()));
+    connect(m_serverDevice, &ServerDevice::newConnection, this, &Server::newConnection);
 
     m_broadcastTimer->setInterval(5 * 1000);
     m_broadcastTimer->setSingleShot(false);
 #ifndef Q_OS_ANDROID
     m_broadcastTimer->start();
 #endif
-    connect(m_broadcastTimer, SIGNAL(timeout()), SLOT(broadcast()));
-    connect(this, SIGNAL(disconnected()), m_broadcastTimer, SLOT(start()));
+    connect(m_broadcastTimer, &QTimer::timeout, this, &Server::broadcast);
+    connect(this, &Server::disconnected, m_broadcastTimer, [this]{ m_broadcastTimer->start(); });
 
-    connect(m_signalMapper, SIGNAL(signalEmitted(QObject*,int,QVector<QVariant>)),
-            this, SLOT(forwardSignal(QObject*,int,QVector<QVariant>)));
+    connect(m_signalMapper, &MultiSignalMapper::signalEmitted,
+            this, &Server::forwardSignal);
 
     Endpoint::addObjectNameAddressMapping(QStringLiteral(
                                               "com.kdab.GammaRay.PropertySyncer"), ++m_nextAddress);
@@ -86,9 +86,7 @@ Server::Server(QObject *parent)
     registerMessageHandler(m_nextAddress, m_propertySyncer, "handleMessage");
 }
 
-Server::~Server()
-{
-}
+Server::~Server() = default;
 
 bool Server::listen()
 {
@@ -143,6 +141,8 @@ void Server::newConnection()
 
     m_broadcastTimer->stop();
     auto con = m_serverDevice->nextPendingConnection();
+    // FIXME Use proper type for m_serverDevice->nextPendingConnection, instead
+    // of relying on runtime-connect to a slot which doesn't exist in QIODevice
     connect(con, SIGNAL(disconnected()), con, SLOT(deleteLater()));
     setDevice(con);
 
@@ -282,11 +282,7 @@ void Server::forwardSignal(QObject *sender, int signalIndex, const QVector< QVar
     const QMetaMethod signal = sender->metaObject()->method(signalIndex);
     Q_ASSERT(signal.methodType() == QMetaMethod::Signal);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    QByteArray name = signal.signature();
-#else
     QByteArray name = signal.methodSignature();
-#endif
     // get the name of the function to invoke, excluding the parens and function arguments.
     name = name.mid(0, name.indexOf('('));
 
