@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,9 +41,7 @@ ServerDevice::ServerDevice(QObject *parent)
 {
 }
 
-ServerDevice::~ServerDevice()
-{
-}
+ServerDevice::~ServerDevice() = default;
 
 void ServerDevice::setServerAddress(const QUrl &serverAddress)
 {
