@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,26 +27,3 @@
 */
 
 #include "serverproxymodel.h"
-
-#include <QDebug>
-
-using namespace GammaRay;
-
-ServerProxyModel::ServerProxyModel(QObject *parent): QSortFilterProxyModel(parent)
-{
-}
-
-void ServerProxyModel::addRole(int role)
-{
-    m_extraRoles.push_back(role);
-}
-
-QMap< int, QVariant > ServerProxyModel::itemData(const QModelIndex &index) const
-{
-    const QModelIndex sourceIndex = mapToSource(index);
-    auto d = sourceModel()->itemData(sourceIndex);
-    foreach (int role, m_extraRoles) {
-        d.insert(role, sourceIndex.data(role));
-    }
-    return d;
-}
