@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,12 +40,10 @@ TcpServerDevice::TcpServerDevice(QObject *parent)
     , m_broadcastSocket(new QUdpSocket(this))
 {
     m_server = new QTcpServer(this);
-    connect(m_server, SIGNAL(newConnection()), this, SIGNAL(newConnection()));
+    connect(m_server, &QTcpServer::newConnection, this, &ServerDevice::newConnection);
 }
 
-TcpServerDevice::~TcpServerDevice()
-{
-}
+TcpServerDevice::~TcpServerDevice() = default;
 
 bool TcpServerDevice::listen()
 {
@@ -93,11 +91,7 @@ QUrl TcpServerDevice::externalAddress() const
     const QHostAddress address(m_server->serverAddress());
     QString myHost;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    if (address == QHostAddress::LocalHost || address == QHostAddress::LocalHostIPv6) {
-#else
     if (address.isLoopback()) {
-#endif
         myHost = address.toString();
     } else {
         //scan Interfaces for available IPs, use requested address if we can find it.
@@ -108,9 +102,7 @@ QUrl TcpServerDevice::externalAddress() const
     if (myHost.isEmpty()) {
         switch (m_server->serverAddress().protocol()) {
         case QAbstractSocket::IPv4Protocol:
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         case QAbstractSocket::AnyIPProtocol:
-#endif
             myHost = QHostAddress(QHostAddress::LocalHost).toString();
             break;
         case QAbstractSocket::IPv6Protocol:
@@ -134,11 +126,7 @@ void TcpServerDevice::broadcast(const QByteArray &data)
     const QHostAddress address = m_server->serverAddress();
 
     // broadcast announcement only if we are actually listinging to remote connections
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    if (address == QHostAddress::LocalHost || address == QHostAddress::LocalHostIPv6)
-#else
     if (address.isLoopback())
-#endif
         return;
 
     m_broadcastSocket->writeDatagram(data.data(),
