@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,9 +28,7 @@
 
 #include "messagehandler.h"
 #include "messagemodel.h"
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
 #include "loggingcategorymodel.h"
-#endif
 
 #include <core/execution.h>
 #include <core/probeguard.h>
@@ -51,44 +49,31 @@
 
 using namespace GammaRay;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-typedef QtMsgHandler MessageHandlerCallback;
-static MessageHandlerCallback(*const installMessageHandler)(MessageHandlerCallback)
-    = qInstallMsgHandler;
-#else
-typedef QtMessageHandler MessageHandlerCallback;
+using MessageHandlerCallback = QtMessageHandler;
 static MessageHandlerCallback(*const installMessageHandler)(MessageHandlerCallback)
     = qInstallMessageHandler;
-#endif
 
 static MessageModel *s_model = nullptr;
 static MessageHandlerCallback s_handler = nullptr;
 static bool s_handlerDisabled = false;
 static QMutex s_mutex(QMutex::Recursive);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-static void handleMessage(QtMsgType type, const char *rawMsg)
-#else
 static void handleMessage(QtMsgType type, const QMessageLogContext &context, const QString &msg)
-#endif
 {
     ///WARNING: do not trigger *any* kind of debug output here
     ///         this would trigger an infinite loop and hence crash!
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    const QString msg = QString::fromLocal8Bit(rawMsg);
-#endif
+    if (s_handlerDisabled) // recursion detected
+        return;
 
     DebugMessage message;
     message.type = type;
     message.message = msg;
     message.time = QTime::currentTime();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     message.category = QString::fromUtf8(context.category);
     message.file = QString::fromUtf8(context.file);
     message.function = QString::fromUtf8(context.function);
     message.line = context.line;
-#endif
 
     if (type == QtCriticalMsg || type == QtFatalMsg || (type == QtWarningMsg && !ProbeGuard::insideProbe())) {
         // TODO: go even higher until qWarning/qFatal/qDebug/... ?
@@ -121,18 +106,10 @@ static void handleMessage(QtMsgType type, const QMessageLogContext &context, con
     QMutexLocker lock(&s_mutex);
     s_handlerDisabled = true;
     if (s_handler) { // try a direct call to the previous handler first, that avoids triggering the recursion detection in Qt5
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         s_handler(type, context, msg);
-#else
-        s_handler(type, rawMsg);
-#endif
     } else {
         installMessageHandler(s_handler);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         qt_message_output(type, context, msg);
-#else
-        qt_message_output(type, rawMsg);
-#endif
         installMessageHandler(handleMessage);
     }
     s_handlerDisabled = false;
@@ -145,7 +122,7 @@ static void handleMessage(QtMsgType type, const QMessageLogContext &context, con
     }
 }
 
-MessageHandler::MessageHandler(ProbeInterface *probe, QObject *parent)
+MessageHandler::MessageHandler(Probe *probe, QObject *parent)
     : MessageHandlerInterface(parent)
     , m_messageModel(new MessageModel(this))
     , m_stackTraceModel(new StackTraceModel(this))
@@ -161,7 +138,7 @@ MessageHandler::MessageHandler(ProbeInterface *probe, QObject *parent)
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.MessageModel"), proxy);
 
     auto selModel = ObjectBroker::selectionModel(proxy);
-    connect(selModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(messageSelected(QItemSelection)));
+    connect(selModel, &QItemSelectionModel::selectionChanged, this, &MessageHandler::messageSelected);
 
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.MessageStackTraceModel"), m_stackTraceModel);
 
@@ -173,10 +150,8 @@ MessageHandler::MessageHandler(ProbeInterface *probe, QObject *parent)
     // installs a handler after QApp but before .exec()
     QMetaObject::invokeMethod(this, "ensureHandlerInstalled", Qt::QueuedConnection);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     auto catModel = new LoggingCategoryModel(this);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.LoggingCategoryModel"), catModel);
-#endif
 }
 
 MessageHandler::~MessageHandler()
