@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -50,8 +50,8 @@ class MessageHandler : public MessageHandlerInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::MessageHandlerInterface)
 public:
-    explicit MessageHandler(ProbeInterface *probe, QObject *parent = nullptr);
-    ~MessageHandler();
+    explicit MessageHandler(Probe *probe, QObject *parent = nullptr);
+    ~MessageHandler() override;
 
 private slots:
     void ensureHandlerInstalled();
