@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,9 +40,7 @@ MessageModel::MessageModel(QObject *parent)
     qRegisterMetaType<DebugMessage>();
 }
 
-MessageModel::~MessageModel()
-{
-}
+MessageModel::~MessageModel() = default;
 
 void MessageModel::addMessage(const DebugMessage &message)
 {
@@ -57,11 +55,7 @@ void MessageModel::addMessage(const DebugMessage &message)
 int MessageModel::columnCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    return 2;
-#else
     return MessageModelColumn::COUNT;
-#endif
 }
 
 int MessageModel::rowCount(const QModelIndex &parent) const
@@ -85,14 +79,12 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
             return msg.message;
         case MessageModelColumn::Time:
             return msg.time.toString();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         case MessageModelColumn::Category:
             return msg.category;
         case MessageModelColumn::Function:
             return msg.function;
         case MessageModelColumn::File:
             return msg.file;
-#endif
         }
     } else if (role == MessageModelRole::Sort) {
         switch (index.column()) {
@@ -100,21 +92,17 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
             return msg.time;
         case MessageModelColumn::Message:
             return msg.message;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         case MessageModelColumn::Category:
             return msg.category;
         case MessageModelColumn::Function:
             return msg.function;
         case MessageModelColumn::File:
             return QString::fromLatin1("%1:%2").arg(msg.file).arg(msg.line);
-#endif
         }
     } else if (role == MessageModelRole::Type && index.column() == 0) {
         return static_cast<int>(msg.type);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     } else if (role == MessageModelRole::Line && index.column() == MessageModelColumn::File) {
         return msg.line;
-#endif
     } else if (role == MessageModelRole::Backtrace) {
         return QVariant::fromValue(msg.backtrace);
     }
