@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,14 +29,26 @@
 #include "metatypebrowser.h"
 #include "metatypesmodel.h"
 
-#include "common/objectbroker.h"
+#include <core/remote/serverproxymodel.h>
+
+#include <common/objectbroker.h>
+#include <common/tools/metatypebrowser/metatyperoles.h>
+
+#include <QSortFilterProxyModel>
 
 using namespace GammaRay;
 
-MetaTypeBrowser::MetaTypeBrowser(ProbeInterface *probe, QObject *parent)
-  : QObject(parent)
+MetaTypeBrowser::MetaTypeBrowser(Probe *probe, QObject *parent)
+    : MetaTypeBrowserInterface(parent)
+    , m_mtm(new MetaTypesModel(this))
 {
-  MetaTypesModel *mtm = new MetaTypesModel(this);
-  probe->registerModel("com.kdab.GammaRay.MetaTypeModel", mtm);
+    auto proxy = new ServerProxyModel<QSortFilterProxyModel>(this);
+    proxy->setSourceModel(m_mtm);
+    proxy->addRole(MetaTypeRoles::MetaObjectIdRole);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.MetaTypeModel"), proxy);
 }
 
+void MetaTypeBrowser::rescanTypes()
+{
+    m_mtm->scanMetaTypes();
+}
