@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class MetaTypeBrowser : public MetaTypeBrowserInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::MetaTypeBrowserInterface)
 public:
-    explicit MetaTypeBrowser(ProbeInterface *probe, QObject *parent = nullptr);
+    explicit MetaTypeBrowser(Probe *probe, QObject *parent = nullptr);
 
 public slots:
     void rescanTypes() override;
