@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,6 +32,8 @@
 #include "common/tools/objectinspector/connectionsmodelroles.h"
 #include "core/util.h"
 
+#include <compat/qasconst.h>
+
 #include <QMetaMethod>
 #include <QStringList>
 
@@ -42,9 +44,7 @@ AbstractConnectionsModel::AbstractConnectionsModel(QObject *parent)
 {
 }
 
-AbstractConnectionsModel::~AbstractConnectionsModel()
-{
-}
+AbstractConnectionsModel::~AbstractConnectionsModel() = default;
 
 int AbstractConnectionsModel::columnCount(const QModelIndex &parent) const
 {
@@ -157,9 +157,9 @@ QMap< int, QVariant > AbstractConnectionsModel::itemData(const QModelIndex &inde
     return d;
 }
 
-bool AbstractConnectionsModel::isDuplicate(const Connection &conn) const
+bool AbstractConnectionsModel::isDuplicate(const QVector<Connection> &connections, const AbstractConnectionsModel::Connection& conn)
 {
-    foreach (const Connection &c, m_connections) {
+    for (const Connection &c : qAsConst(connections)) {
         if (&c == &conn)
             continue;
         if (c.endpoint == conn.endpoint
@@ -170,13 +170,24 @@ bool AbstractConnectionsModel::isDuplicate(const Connection &conn) const
     return false;
 }
 
-bool AbstractConnectionsModel::isDirectCrossThreadConnection(const Connection &conn) const
+bool AbstractConnectionsModel::isDuplicate(const Connection &conn) const
 {
-    if (!conn.endpoint || !m_object || conn.endpoint->thread() == m_object->thread())
+    return isDuplicate(m_connections, conn);
+}
+
+bool AbstractConnectionsModel::isDirectCrossThreadConnection(QObject *object, const AbstractConnectionsModel::Connection &conn)
+{
+    if (!conn.endpoint || !object || conn.endpoint->thread() == object->thread())
         return false;
     return conn.type == 1; // direct
 }
 
+
+bool AbstractConnectionsModel::isDirectCrossThreadConnection(const Connection &conn) const
+{
+    return isDirectCrossThreadConnection(m_object, conn);
+}
+
 void AbstractConnectionsModel::clear()
 {
     if (m_connections.isEmpty())
