@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,7 +41,7 @@ class AbstractConnectionsModel : public QAbstractTableModel
     Q_OBJECT
 public:
     explicit AbstractConnectionsModel(QObject *parent = nullptr);
-    ~AbstractConnectionsModel();
+    ~AbstractConnectionsModel() override;
 
     virtual void setObject(QObject *object) = 0;
 
@@ -52,7 +52,6 @@ public:
                         int role = Qt::DisplayRole) const override;
     QMap< int, QVariant > itemData(const QModelIndex &index) const override;
 
-protected:
     struct Connection {
         QPointer<QObject> endpoint;
         int signalIndex;
@@ -60,6 +59,7 @@ protected:
         int type;
     };
 
+protected:
     static QString displayString(QObject *object, int methodIndex);
     static QString displayString(QObject *object);
 
@@ -68,6 +68,10 @@ protected:
     void clear();
     void setConnections(const QVector<Connection> &connections);
 
+public:
+    static bool isDuplicate(const QVector<Connection> &connections, const Connection &conn);
+    static bool isDirectCrossThreadConnection(QObject *object, const Connection &conn);
+
 protected:
     QPointer<QObject> m_object;
     QVector<Connection> m_connections;
