@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -51,20 +51,14 @@ ConnectionsExtension::ConnectionsExtension(PropertyController *controller)
     controller->registerModel(m_outboundModel, QStringLiteral("outboundConnections"));
 }
 
-ConnectionsExtension::~ConnectionsExtension()
-{
-}
+ConnectionsExtension::~ConnectionsExtension() = default;
 
 bool ConnectionsExtension::setQObject(QObject *object)
 {
     m_inboundModel->setObject(object);
     m_outboundModel->setObject(object);
 
-#ifdef HAVE_PRIVATE_QT_HEADERS
     return true;
-#else
-    return false; // the above models wont have any content
-#endif
 }
 
 void ConnectionsExtension::navigateToSender(int modelRow)
