@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class ConnectionsExtension : public ConnectionsExtensionInterface,
     Q_INTERFACES(GammaRay::ConnectionsExtensionInterface)
 public:
     explicit ConnectionsExtension(PropertyController *controller);
-    ~ConnectionsExtension();
+    ~ConnectionsExtension() override;
 
     bool setQObject(QObject *object) override;
 
