@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,10 +38,12 @@ class InboundConnectionsModel : public AbstractConnectionsModel
     Q_OBJECT
 public:
     explicit InboundConnectionsModel(QObject *parent = nullptr);
-    ~InboundConnectionsModel();
+    ~InboundConnectionsModel() override;
 
     void setObject(QObject *object) override;
 
+    static QVector<Connection> inboundConnectionsForObject(QObject *object);
+
     QVariant data(const QModelIndex &index, int role) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const override;
