@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -58,9 +58,7 @@ MethodsExtension::MethodsExtension(PropertyController *controller)
     ObjectBroker::selectionModel(m_model); // trigger creation
 }
 
-MethodsExtension::~MethodsExtension()
-{
-}
+MethodsExtension::~MethodsExtension() = default;
 
 bool MethodsExtension::setQObject(QObject *object)
 {
@@ -72,8 +70,8 @@ bool MethodsExtension::setQObject(QObject *object)
 
     delete m_signalMapper;
     m_signalMapper = new MultiSignalMapper(this);
-    connect(m_signalMapper, SIGNAL(signalEmitted(QObject*,int,QVector<QVariant>)),
-            SLOT(signalEmitted(QObject*,int,QVector<QVariant>)));
+    connect(m_signalMapper, &MultiSignalMapper::signalEmitted,
+            this, &MethodsExtension::signalEmitted);
 
     if (m_methodLogModel->rowCount() > 0)
         m_methodLogModel->clear();
@@ -97,17 +95,13 @@ void MethodsExtension::signalEmitted(QObject *sender, int signalIndex,
 
     QStringList prettyArgs;
     prettyArgs.reserve(args.size());
-    foreach (const QVariant &v, args)
+    for (const QVariant &v : args)
         prettyArgs.push_back(VariantHandler::displayString(v));
 
     m_methodLogModel->appendRow(
         new QStandardItem(tr("%1: Signal %2 emitted, arguments: %3").arg(
                               QTime::currentTime().toString(QStringLiteral("HH:mm:ss.zzz")),
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                              sender->metaObject()->method(signalIndex).signature(),
-#else
                               QString(sender->metaObject()->method(signalIndex).methodSignature()),
-#endif
                               prettyArgs.join(QStringLiteral(", ")))));
 }
 
