@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,10 +39,12 @@ class OutboundConnectionsModel : public AbstractConnectionsModel
 
 public:
     explicit OutboundConnectionsModel(QObject *parent = nullptr);
-    ~OutboundConnectionsModel();
+    ~OutboundConnectionsModel() override;
 
     void setObject(QObject *object) override;
 
+    static QVector<Connection> outboundConnectionsForObject(QObject *object);
+
     QVariant data(const QModelIndex &index, int role) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const override;
