@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,9 +46,7 @@ PropertiesExtension::PropertiesExtension(PropertyController *controller)
     controller->registerModel(m_aggregatedPropertyModel, QStringLiteral("properties"));
 }
 
-PropertiesExtension::~PropertiesExtension()
-{
-}
+PropertiesExtension::~PropertiesExtension() = default;
 
 bool PropertiesExtension::setQObject(QObject *object)
 {
