@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -53,22 +53,20 @@ ConnectPage::ConnectPage(QWidget *parent)
     , m_valid(false)
 {
     ui->setupUi(this);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     m_implicitPortWarningSign =
         new QAction(QIcon(":/launcher/warning.png"), tr("No port given, will use 11732"), this);
 
     m_fileIsNotASocketWarning =
         new QAction(qApp->style()->standardIcon(QStyle::SP_MessageBoxCritical),
                     tr("File is not a socket"), this);
-#endif
-    connect(ui->host, SIGNAL(textChanged(QString)), SLOT(validateHostAddress(QString)));
-    connect(ui->host, SIGNAL(textChanged(QString)), SIGNAL(updateButtonState()));
+    connect(ui->host, &QLineEdit::textChanged, this, &ConnectPage::validateHostAddress);
+    connect(ui->host, &QLineEdit::textChanged, this, &ConnectPage::updateButtonState);
 
     auto *model = new NetworkDiscoveryModel(this);
     ui->instanceView->setModel(model);
     connect(ui->instanceView->selectionModel(),
-            SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(instanceSelected()));
-    connect(ui->instanceView, SIGNAL(activated(QModelIndex)), SIGNAL(activate()));
+            &QItemSelectionModel::selectionChanged, this, &ConnectPage::instanceSelected);
+    connect(ui->instanceView, &QAbstractItemView::activated, this, &ConnectPage::activate);
 
     QSettings settings;
     ui->host->setText(settings.value(QStringLiteral("Connect/Url"), QString()).toString());
@@ -147,12 +145,12 @@ void ConnectPage::handleIPAddress(QString &stillToParse, bool &correctSoFar)
         possibleIPv6Address = QHostAddress(stillToParse);
 
     QHostAddress possibleIPv6BracketAddress;
-    QRegExp bracketFormat("^\\[([0-9a-f\\:\\.]*)\\].*$");
+    QRegExp bracketFormat(R"(^\[([0-9a-f\:\.]*)\].*$)");
     if (bracketFormat.exactMatch(stillToParse))
         possibleIPv6BracketAddress = QHostAddress(bracketFormat.cap(1));
 
     QHostAddress possibleIPv6InterfaceAddress;
-    QRegExp interfaceFormat("^([^\\%]*)(\\%[^\\:]+)(:[0-9]+)?$");
+    QRegExp interfaceFormat(R"(^([^\%]*)(\%[^\:]+)(:[0-9]+)?$)");
     if (interfaceFormat.exactMatch(stillToParse))
         possibleIPv6InterfaceAddress = QHostAddress(interfaceFormat.cap(1));
 
@@ -219,10 +217,6 @@ void ConnectPage::hostResponse(const QHostInfo &hostInfo)
 
 void ConnectPage::handleAddressAndPort(QString &stillToParse, bool &correctSoFar, const QString &possibleAddress, bool skipPort)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    // Qt 4 parses Urls into Uppercase representation
-    stillToParse = stillToParse.toUpper();
-#endif
     stillToParse.replace(possibleAddress, QString());
     if (stillToParse.isEmpty()) {
         correctSoFar = true;
@@ -253,24 +247,18 @@ void ConnectPage::handlePortString(QString &stillToParse, bool &correctSoFar)
 
 void ConnectPage::showStandardPortAssumedWarning()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     ui->host->addAction(m_implicitPortWarningSign, QLineEdit::TrailingPosition);
-#endif
 }
 
 void ConnectPage::showFileIsNotSocketWarning()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     ui->host->addAction(m_fileIsNotASocketWarning, QLineEdit::TrailingPosition);
-#endif
 }
 
 void ConnectPage::clearWarnings()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     ui->host->removeAction(m_implicitPortWarningSign);
     ui->host->removeAction(m_fileIsNotASocketWarning);
-#endif
 }
 
 QUrl ConnectPage::currentUrl() const
@@ -278,9 +266,7 @@ QUrl ConnectPage::currentUrl() const
     return m_currentUrl;
 }
 
-ConnectPage::~ConnectPage()
-{
-}
+ConnectPage::~ConnectPage() = default;
 
 bool ConnectPage::isValid() const
 {
