@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,9 +38,7 @@ ProbeABIModel::ProbeABIModel(QObject *parent)
     m_abis = ProbeFinder::listProbeABIs();
 }
 
-ProbeABIModel::~ProbeABIModel()
-{
-}
+ProbeABIModel::~ProbeABIModel() = default;
 
 QVariant ProbeABIModel::data(const QModelIndex &index, int role) const
 {
