@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,8 @@
 #include "processmodel.h"
 #include "probeabimodel.h"
 
+#include <compat/qasconst.h>
+
 #include <launcher/core/probefinder.h>
 
 #include <QDebug>
@@ -60,9 +62,7 @@ ProcessModel::ProcessModel(QObject *parent)
     m_availableABIs = ProbeFinder::listProbeABIs();
 }
 
-ProcessModel::~ProcessModel()
-{
-}
+ProcessModel::~ProcessModel() = default;
 
 void ProcessModel::setProcesses(const ProcDataList &processes)
 {
@@ -82,7 +82,7 @@ void ProcessModel::mergeProcesses(const ProcDataList &processes)
     // iterator over m_data
     int i = 0;
 
-    foreach (const ProcData &newProc, sortedProcesses) {
+    for (const ProcData &newProc : qAsConst(sortedProcesses)) {
         bool shouldInsert = true;
         while (i < m_data.count()) {
             const ProcData &oldProc = m_data.at(i);
@@ -144,7 +144,7 @@ QModelIndex ProcessModel::indexForPid(const QString &pid) const
         if (m_data.at(i).ppid == pid)
             return index(i, 0);
     }
-    return QModelIndex();
+    return {};
 }
 
 QVariant ProcessModel::headerData(int section, Qt::Orientation orientation, int role) const
