@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -57,8 +57,8 @@ void SelfTestPage::run()
 {
     m_resultModel->clear();
     SelfTest selfTest;
-    connect(&selfTest, SIGNAL(information(QString)), this, SLOT(information(QString)));
-    connect(&selfTest, SIGNAL(error(QString)), this, SLOT(error(QString)));
+    connect(&selfTest, &SelfTest::information, this, &SelfTestPage::information);
+    connect(&selfTest, &SelfTest::error, this, &SelfTestPage::error);
     selfTest.checkEverything();
 }
 
