@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class SelfTestPage : public QWidget
     Q_OBJECT
 public:
     explicit SelfTestPage(QWidget *parent = nullptr);
-    ~SelfTestPage();
+    ~SelfTestPage() override;
 
 public slots:
     void run();
