@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,7 +27,6 @@
 #include "actioninspector.h"
 #include "actionmodel.h"
 
-#include <core/probeinterface.h>
 #include <core/metaobject.h>
 #include <core/metaobjectrepository.h>
 #include <core/remote/serverproxymodel.h>
@@ -46,25 +45,19 @@
 using namespace GammaRay;
 using namespace std;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_DECLARE_METATYPE(QAction *)
-Q_DECLARE_METATYPE(QActionGroup *)
-Q_DECLARE_METATYPE(QMenu *)
-#endif
-
-ActionInspector::ActionInspector(ProbeInterface *probe, QObject *parent)
+ActionInspector::ActionInspector(Probe *probe, QObject *parent)
     : QObject(parent)
 {
     registerMetaTypes();
     ObjectBroker::registerObject(QStringLiteral("com.kdab.GammaRay.ActionInspector"), this);
 
     auto *actionModel = new ActionModel(this);
-    connect(probe->probe(), SIGNAL(objectCreated(QObject*)), actionModel,
-            SLOT(objectAdded(QObject*)));
-    connect(probe->probe(), SIGNAL(objectDestroyed(QObject*)), actionModel,
-            SLOT(objectRemoved(QObject*)));
-    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)),
-            SLOT(objectSelected(QObject*)));
+    connect(probe, &Probe::objectCreated, actionModel,
+            &ActionModel::objectAdded);
+    connect(probe, &Probe::objectDestroyed, actionModel,
+            &ActionModel::objectRemoved);
+    connect(probe, &Probe::objectSelected,
+            this, &ActionInspector::objectSelected);
 
     auto proxy = new ServerProxyModel<QSortFilterProxyModel>(this);
     proxy->setSourceModel(actionModel);
@@ -74,9 +67,7 @@ ActionInspector::ActionInspector(ProbeInterface *probe, QObject *parent)
     m_selectionModel = ObjectBroker::selectionModel(proxy);
 }
 
-ActionInspector::~ActionInspector()
-{
-}
+ActionInspector::~ActionInspector() = default;
 
 void ActionInspector::triggerAction(int row)
 {
@@ -124,17 +115,9 @@ void ActionInspector::registerMetaTypes()
     MO_ADD_PROPERTY(QAction, isSeparator, setSeparator);
     MO_ADD_PROPERTY_RO(QAction, menu);
     MO_ADD_PROPERTY_RO(QAction, parentWidget);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     MO_ADD_PROPERTY_RO(QAction, associatedGraphicsWidgets);
     MO_ADD_PROPERTY_RO(QAction, associatedWidgets);
-#endif
 
     MO_ADD_METAOBJECT1(QActionGroup, QObject);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     MO_ADD_PROPERTY_RO(QActionGroup, actions);
-#endif
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(ActionInspectorFactory)
-#endif
