@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -62,19 +62,17 @@ ActionInspectorWidget::ActionInspectorWidget(QWidget *parent)
     ui->actionView->setDeferredResizeMode(4, QHeaderView::ResizeToContents);
     ui->actionView->setModel(actionModel);
     ui->actionView->sortByColumn(ActionModel::ShortcutsPropColumn);
-    connect(ui->actionView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu(QPoint)));
+    connect(ui->actionView, &QWidget::customContextMenuRequested, this, &ActionInspectorWidget::contextMenu);
 
     auto selectionModel = ObjectBroker::selectionModel(actionModel);
     ui->actionView->setSelectionModel(selectionModel);
-    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(selectionChanged(QItemSelection)));
+    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, &ActionInspectorWidget::selectionChanged);
 
     m_stateManager.setDefaultSizes(ui->actionView->header(), UISizeVector() << -1 << 200 << -1 << -1 << -1 << 200);
-    connect(ui->actionView, SIGNAL(doubleClicked(QModelIndex)), SLOT(triggerAction(QModelIndex)));
+    connect(ui->actionView, &QAbstractItemView::doubleClicked, this, &ActionInspectorWidget::triggerAction);
 }
 
-ActionInspectorWidget::~ActionInspectorWidget()
-{
-}
+ActionInspectorWidget::~ActionInspectorWidget() = default;
 
 void ActionInspectorWidget::triggerAction(const QModelIndex &index)
 {
@@ -110,7 +108,3 @@ void ActionInspectorWidget::selectionChanged(const QItemSelection& selection)
     const auto idx = selection.at(0).topLeft();
     ui->actionView->scrollTo(idx);
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(ActionInspectorUiFactory)
-#endif
