@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,6 +33,8 @@
 #include <core/probe.h>
 #include <core/util.h>
 #include <core/varianthandler.h>
+#include <core/problemcollector.h>
+#include <core/objectdataprovider.h>
 
 #include <common/objectid.h>
 
@@ -49,7 +51,7 @@ static QString toString(const QList<QKeySequence> &list)
 {
     QStringList items;
     items.reserve(list.size());
-    Q_FOREACH(const auto &item, list) {
+    for (const auto &item : list) {
         items << item.toString();
     }
     return items.join(QStringLiteral(", "));
@@ -59,11 +61,13 @@ ActionModel::ActionModel(QObject *parent)
     : QAbstractTableModel(parent)
     , m_duplicateFinder(new ActionValidator(this))
 {
+    ProblemCollector::registerProblemChecker("gammaray_actioninspector.ShortcutDuplicates",
+                                          "Shortcut Duplicates",
+                                          "Scans for potential shortcut conflicts in QActions",
+                                          [this]() { scanForShortcutDuplicates(); });
 }
 
-ActionModel::~ActionModel()
-{
-}
+ActionModel::~ActionModel() = default;
 
 void ActionModel::objectAdded(QObject *object)
 {
@@ -85,7 +89,7 @@ void ActionModel::objectAdded(QObject *object)
     m_actions.insert(it, action);
     Q_ASSERT(m_actions.at(row) == action);
     m_duplicateFinder->insert(action);
-    connect(action, SIGNAL(changed()), this, SLOT(actionChanged()));
+    connect(action, &QAction::changed, this, &ActionModel::actionChanged);
     endInsertRows();
 }
 
@@ -209,3 +213,19 @@ void ActionModel::actionChanged()
     auto row = m_actions.indexOf(action);
     emit dataChanged(index(row, 0), index(row, ActionModel::ShortcutsPropColumn));
 }
+
+void ActionModel::scanForShortcutDuplicates() const
+{
+    for (QAction *action : m_actions) {
+        Q_FOREACH (const QKeySequence &sequence, m_duplicateFinder->findAmbiguousShortcuts(action)) {
+            Problem p;
+            p.severity = Problem::Error;
+            p.description = QStringLiteral("Key sequence %1 is ambigous.").arg(sequence.toString(QKeySequence::NativeText));
+            p.problemId = QStringLiteral("gammaray_actioninspector.ShortcutDuplicates:%1").arg(sequence.toString(QKeySequence::PortableText));
+            p.object = ObjectId(action);
+            p.locations.push_back(ObjectDataProvider::creationLocation(action));
+            p.findingCategory = Problem::Scan;
+            ProblemCollector::addProblem(p);
+        }
+    }
+}
