@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -64,7 +64,7 @@ public:
     };
 
     explicit ActionModel(QObject *parent = nullptr);
-    ~ActionModel();
+    ~ActionModel() override;
 
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -80,6 +80,8 @@ private slots:
     void actionChanged();
 
 private:
+    void scanForShortcutDuplicates() const;
+
     // sorted vector of QActions
     QVector<QAction *> m_actions;
 
