@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,11 +46,6 @@ Q_DECLARE_METATYPE(QBluetoothDeviceDiscoveryAgent::Error)
 Q_DECLARE_METATYPE(QBluetoothDeviceDiscoveryAgent::InquiryType)
 Q_DECLARE_METATYPE(QBluetoothServer::Error)
 Q_DECLARE_METATYPE(QBluetoothServiceInfo::Protocol)
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-Q_DECLARE_METATYPE(QBluetoothServiceDiscoveryAgent::Error)
-Q_DECLARE_METATYPE(QBluetoothSocket::SocketError)
-Q_DECLARE_METATYPE(QBluetoothSocket::SocketState)
-#endif
 
 using namespace GammaRay;
 
@@ -66,7 +61,7 @@ static QString bluetoothInquiryTypeToString(QBluetoothDeviceDiscoveryAgent::Inqu
     return QString();
 }
 
-Bluetooth::Bluetooth(ProbeInterface *probe, QObject *parent)
+Bluetooth::Bluetooth(Probe *probe, QObject *parent)
     : QObject(parent)
 {
     Q_UNUSED(probe);
