@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -34,7 +34,7 @@ class Bluetooth : public QObject
 {
     Q_OBJECT
 public:
-    explicit Bluetooth(ProbeInterface *probe, QObject *parent = nullptr);
+    explicit Bluetooth(Probe *probe, QObject *parent = nullptr);
 };
 
 class BluetoothFactory : public QObject, public StandardToolFactory<QObject, Bluetooth>
