@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,7 +37,7 @@
 
 using namespace GammaRay;
 
-CodecBrowser::CodecBrowser(ProbeInterface *probe, QObject *parent)
+CodecBrowser::CodecBrowser(Probe *probe, QObject *parent)
     : QObject(parent)
 {
     ObjectBroker::registerObject(QStringLiteral("com.kdab.GammaRay.CodecBrowser"), this);
@@ -46,8 +46,8 @@ CodecBrowser::CodecBrowser(ProbeInterface *probe, QObject *parent)
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.AllCodecsModel"), model);
 
     m_codecSelectionModel = ObjectBroker::selectionModel(model);
-    connect(m_codecSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(updateCodecs(QItemSelection,QItemSelection)));
+    connect(m_codecSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, &CodecBrowser::updateCodecs);
 
     m_selectedCodecsModel = new SelectedCodecsModel(this);
     probe->registerModel(QStringLiteral(
@@ -67,14 +67,10 @@ void CodecBrowser::updateCodecs(const QItemSelection &selected, const QItemSelec
     const auto rows = m_codecSelectionModel->selectedRows();
     QStringList currentCodecNames;
     currentCodecNames.reserve(rows.size());
-    foreach (const QModelIndex &index, rows) {
+    for (const QModelIndex &index : rows) {
         const QString codecName = index.data().toString();
         currentCodecNames.append(codecName);
     }
 
     m_selectedCodecsModel->setCodecs(currentCodecNames);
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(CodecBrowserFactory)
-#endif
