@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -50,13 +50,13 @@ QVariant AllCodecsModel::data(const QModelIndex &index, int role) const
         if (index.column() == 0)
             return m_codecs.at(index.row());
         if (index.column() == 1) {
-            QList<QByteArray> aliases
+            const QList<QByteArray> aliases
                 = QTextCodec::codecForName(m_codecs.at(index.row()))->aliases();
 
             QString result;
             int size = aliases.size();
             int i = 0;
-            foreach (const QByteArray &ba, aliases) {
+            for (const QByteArray &ba : aliases) {
                 result.append(ba);
 
                 ++i;
