@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -32,23 +32,23 @@
 #include "fontmodel.h"
 #include "fontdatabasemodel.h"
 
+#include <core/probe.h>
 #include <common/objectbroker.h>
-#include <core/probeinterface.h>
 
 #include <QItemSelectionModel>
 #include <QFontDatabase>
 
 using namespace GammaRay;
 
-FontBrowserServer::FontBrowserServer(ProbeInterface *probe, QObject *parent)
+FontBrowserServer::FontBrowserServer(Probe *probe, QObject *parent)
     : FontBrowserInterface(parent)
     , m_selectedFontModel(new FontModel(this))
 {
     auto model = new FontDatabaseModel(this);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.FontModel"), model);
     m_fontSelectionModel = ObjectBroker::selectionModel(model);
-    connect(m_fontSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(updateFonts()));
+    connect(m_fontSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, &FontBrowserServer::updateFonts);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.SelectedFontModel"),
                          m_selectedFontModel);
 }
@@ -58,7 +58,7 @@ void FontBrowserServer::updateFonts()
     const auto rows = m_fontSelectionModel->selectedRows();
     QVector<QFont> currentFonts;
     currentFonts.reserve(rows.size());
-    foreach (const QModelIndex &index, rows)
+    for (const QModelIndex &index : rows)
         currentFonts << index.data(Qt::UserRole + 1).value<QFont>();
     m_selectedFontModel->updateFonts(currentFonts);
 }
