@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -37,15 +37,15 @@ class QItemSelectionModel;
 QT_END_NAMESPACE
 
 namespace GammaRay {
-class ProbeInterface;
 class FontModel;
+class Probe;
 
 class FontBrowserServer : public FontBrowserInterface
 {
     Q_OBJECT
     Q_INTERFACES(GammaRay::FontBrowserInterface)
 public:
-    explicit FontBrowserServer(ProbeInterface *probe, QObject *parent = nullptr);
+    explicit FontBrowserServer(Probe *probe, QObject *parent = nullptr);
 
 private slots:
     void updateFonts();
