@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,7 +39,7 @@ class PaintAnalyzerTab : public PaintAnalyzerWidget
     Q_OBJECT
 public:
     explicit PaintAnalyzerTab(PropertyWidget *parent);
-    ~PaintAnalyzerTab();
+    ~PaintAnalyzerTab() override;
 };
 }
 
