@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,22 +29,18 @@
 #include "kjobtracker.h"
 #include "kjobmodel.h"
 
-#include <core/probeinterface.h>
-
 #include <QDebug>
 #include <QSortFilterProxyModel>
 #include <QtPlugin>
 
 using namespace GammaRay;
 
-KJobTracker::KJobTracker(ProbeInterface *probe, QObject *parent)
+KJobTracker::KJobTracker(Probe *probe, QObject *parent)
     : QObject(parent)
     , m_jobModel(new KJobModel(this))
 {
-    connect(probe->probe(), SIGNAL(objectCreated(QObject*)),
-            m_jobModel, SLOT(objectAdded(QObject*)));
-    connect(probe->probe(), SIGNAL(objectDestroyed(QObject*)),
-            m_jobModel, SLOT(objectRemoved(QObject*)));
+    connect(probe, &Probe::objectCreated, m_jobModel, &KJobModel::objectAdded);
+    connect(probe, &Probe::objectDestroyed, m_jobModel, &KJobModel::objectRemoved);
 
     auto proxy = new QSortFilterProxyModel(this);
     proxy->setSourceModel(m_jobModel);
@@ -52,10 +48,4 @@ KJobTracker::KJobTracker(ProbeInterface *probe, QObject *parent)
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.KJobModel"), proxy);
 }
 
-KJobTracker::~KJobTracker()
-{
-}
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(KJobTrackerFactory)
-#endif
+KJobTracker::~KJobTracker() = default;
