@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,8 +41,8 @@ class KJobTracker : public QObject
 {
     Q_OBJECT
 public:
-    explicit KJobTracker(ProbeInterface *probe, QObject *parent = nullptr);
-    virtual ~KJobTracker();
+    explicit KJobTracker(Probe *probe, QObject *parent = nullptr);
+    ~KJobTracker() override;
 
 private:
     KJobModel *m_jobModel;
