@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,7 @@
 #include "networksupport.h"
 #include "networkinterfacemodel.h"
 #include "networkconfigurationmodel.h"
+#include "networkreplymodel.h"
 #include "cookies/cookieextension.h"
 
 #include <core/enumrepositoryserver.h>
@@ -41,12 +42,16 @@
 
 #include <QAbstractNetworkCache>
 #include <QHostAddress>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+#include <QHstsPolicy>
+#endif
 #include <QLocalSocket>
 #include <QNetworkAccessManager>
 #include <QNetworkConfiguration>
 #include <QNetworkConfigurationManager>
 #include <QNetworkCookieJar>
 #include <QNetworkProxy>
+#include <QNetworkSession>
 #include <QSocketNotifier>
 #include <QSslCertificateExtension>
 #include <QSslCipher>
@@ -60,15 +65,29 @@
 using namespace GammaRay;
 
 Q_DECLARE_METATYPE(QAbstractSocket::PauseModes)
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-Q_DECLARE_METATYPE(QAbstractSocket::NetworkLayerProtocol)
-Q_DECLARE_METATYPE(QAbstractSocket::SocketType)
-#endif
 Q_DECLARE_METATYPE(QHostAddress)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+Q_DECLARE_METATYPE(QHstsPolicy)
+#endif
 Q_DECLARE_METATYPE(QLocalSocket::LocalSocketError)
 Q_DECLARE_METATYPE(QLocalSocket::LocalSocketState)
 Q_DECLARE_METATYPE(QNetworkAccessManager::NetworkAccessibility)
+#if QT_VERSION < QT_VERSION_CHECK(5, 6, 0)
+Q_DECLARE_METATYPE(QNetworkAddressEntry)
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+Q_DECLARE_METATYPE(QNetworkAddressEntry::DnsEligibilityStatus)
+#endif
+Q_DECLARE_METATYPE(QNetworkConfiguration::BearerType)
 Q_DECLARE_METATYPE(QNetworkConfigurationManager::Capabilities)
+#if QT_VERSION < QT_VERSION_CHECK(5, 6, 0)
+Q_DECLARE_METATYPE(QNetworkInterface)
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+Q_DECLARE_METATYPE(QNetworkInterface::InterfaceFlags)
+#endif
+Q_DECLARE_METATYPE(QNetworkProxy::Capabilities)
+Q_DECLARE_METATYPE(QNetworkProxy::ProxyType)
 Q_DECLARE_METATYPE(QSocketNotifier::Type)
 #ifndef QT_NO_SSL
 Q_DECLARE_METATYPE(QSsl::KeyAlgorithm)
@@ -83,7 +102,7 @@ Q_DECLARE_METATYPE(QSslSocket::PeerVerifyMode)
 Q_DECLARE_METATYPE(QSslSocket::SslMode)
 #endif // QT_NO_SSL
 
-NetworkSupport::NetworkSupport(ProbeInterface *probe, QObject *parent)
+NetworkSupport::NetworkSupport(Probe *probe, QObject *parent)
     : QObject(parent)
 {
     registerMetaTypes();
@@ -96,12 +115,14 @@ NetworkSupport::NetworkSupport(ProbeInterface *probe, QObject *parent)
     configProxy->addRole(NetworkConfigurationModelRoles::DefaultConfigRole);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.NetworkConfigurationModel"), configProxy);
 
+    auto replyModel = new NetworkReplyModel(this);
+    connect(probe, &Probe::objectCreated, replyModel, &NetworkReplyModel::objectCreated);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.NetworkReplyModel"), replyModel);
+
     PropertyController::registerExtension<CookieExtension>();
 }
 
-NetworkSupport::~NetworkSupport()
-{
-}
+NetworkSupport::~NetworkSupport() = default;
 
 void NetworkSupport::registerMetaTypes()
 {
@@ -134,6 +155,13 @@ void NetworkSupport::registerMetaTypes()
     MO_ADD_PROPERTY_RO(QHostAddress, protocol);
     MO_ADD_PROPERTY(QHostAddress, scopeId, setScopeId);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+    MO_ADD_METAOBJECT0(QHstsPolicy);
+    MO_ADD_PROPERTY   (QHstsPolicy, expiry, setExpiry);
+    MO_ADD_PROPERTY_LD(QHstsPolicy, host, [](QHstsPolicy *policy) { return policy->host(); });
+    MO_ADD_PROPERTY   (QHstsPolicy, includesSubDomains, setIncludesSubDomains);
+#endif
+
     MO_ADD_METAOBJECT1(QLocalSocket, QIODevice);
     MO_ADD_PROPERTY_RO(QLocalSocket, error);
     MO_ADD_PROPERTY_RO(QLocalSocket, fullServerName);
@@ -143,14 +171,95 @@ void NetworkSupport::registerMetaTypes()
     MO_ADD_PROPERTY_RO(QLocalSocket, state);
 
     MO_ADD_METAOBJECT1(QNetworkAccessManager, QObject);
+    MO_ADD_PROPERTY_RO(QNetworkAccessManager, activeConfiguration);
     MO_ADD_PROPERTY_RO(QNetworkAccessManager, cache);
+    MO_ADD_PROPERTY   (QNetworkAccessManager, configuration, setConfiguration);
     MO_ADD_PROPERTY_RO(QNetworkAccessManager, cookieJar);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+    MO_ADD_PROPERTY   (QNetworkAccessManager, isStrictTransportSecurityEnabled, setStrictTransportSecurityEnabled);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    MO_ADD_PROPERTY_RO(QNetworkAccessManager, isStrictTransportSecurityStoreEnabled);
+#endif
+    MO_ADD_PROPERTY   (QNetworkAccessManager, proxy, setProxy);
+    MO_ADD_PROPERTY   (QNetworkAccessManager, redirectPolicy, setRedirectPolicy);
+    MO_ADD_PROPERTY_RO(QNetworkAccessManager, strictTransportSecurityHosts);
+#endif
     MO_ADD_PROPERTY_RO(QNetworkAccessManager, supportedSchemes);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    MO_ADD_METAOBJECT0(QNetworkAddressEntry);
+    MO_ADD_PROPERTY   (QNetworkAddressEntry, broadcast, setBroadcast);
+    MO_ADD_PROPERTY   (QNetworkAddressEntry, dnsEligibility, setDnsEligibility);
+    MO_ADD_PROPERTY   (QNetworkAddressEntry, ip, setIp);
+    MO_ADD_PROPERTY_RO(QNetworkAddressEntry, isLifetimeKnown);
+    MO_ADD_PROPERTY_RO(QNetworkAddressEntry, isPermanent);
+    MO_ADD_PROPERTY_RO(QNetworkAddressEntry, isTemporary);
+    MO_ADD_PROPERTY   (QNetworkAddressEntry, netmask, setNetmask);
+    //MO_ADD_PROPERTY_RO(QNetworkAddressEntry, preferredLifetime);
+    MO_ADD_PROPERTY   (QNetworkAddressEntry, prefixLength, setPrefixLength);
+    //MO_ADD_PROPERTY_RO(QNetworkAddressEntry, validityLifetime);
+#endif
+
+    MO_ADD_METAOBJECT0(QNetworkConfiguration);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, bearerType);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, bearerTypeFamily);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, bearerTypeName);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, children);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, connectTimeout);
+#endif
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, identifier);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, isRoamingAvailable);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, isValid);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, name);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, purpose);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, state);
+    MO_ADD_PROPERTY_RO(QNetworkConfiguration, type);
+
     MO_ADD_METAOBJECT1(QNetworkConfigurationManager, QObject);
     MO_ADD_PROPERTY_RO(QNetworkConfigurationManager, capabilities);
     MO_ADD_PROPERTY_RO(QNetworkConfigurationManager, isOnline);
 
+    MO_ADD_METAOBJECT0(QNetworkInterface);
+    MO_ADD_PROPERTY_RO(QNetworkInterface, addressEntries);
+    MO_ADD_PROPERTY_ST(QNetworkInterface, allAddresses);
+    MO_ADD_PROPERTY_ST(QNetworkInterface, allInterfaces);
+    MO_ADD_PROPERTY_RO(QNetworkInterface, flags);
+    MO_ADD_PROPERTY_RO(QNetworkInterface, hardwareAddress);
+    MO_ADD_PROPERTY_RO(QNetworkInterface, index);
+    MO_ADD_PROPERTY_RO(QNetworkInterface, isValid);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    MO_ADD_PROPERTY_RO(QNetworkInterface, maximumTransmissionUnit);
+#endif
+    MO_ADD_PROPERTY_RO(QNetworkInterface, name);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    MO_ADD_PROPERTY_RO(QNetworkInterface, type);
+#endif
+
+    MO_ADD_METAOBJECT0(QNetworkProxy);
+    MO_ADD_PROPERTY_ST(QNetworkProxy, applicationProxy);
+    MO_ADD_PROPERTY   (QNetworkProxy, capabilities, setCapabilities);
+    MO_ADD_PROPERTY   (QNetworkProxy, hostName, setHostName);
+    MO_ADD_PROPERTY_RO(QNetworkProxy, isCachingProxy);
+    MO_ADD_PROPERTY_RO(QNetworkProxy, isTransparentProxy);
+    MO_ADD_PROPERTY   (QNetworkProxy, password, setPassword);
+    MO_ADD_PROPERTY   (QNetworkProxy, port, setPort);
+    //MO_ADD_PROPERTY_RO(QNetworkProxy, rawHeaderList);
+    MO_ADD_PROPERTY   (QNetworkProxy, type, setType);
+    MO_ADD_PROPERTY   (QNetworkProxy, user, setUser);
+
+    MO_ADD_METAOBJECT1(QNetworkSession, QObject);
+    MO_ADD_PROPERTY_RO(QNetworkSession, activeTime);
+    MO_ADD_PROPERTY_RO(QNetworkSession, bytesReceived);
+    MO_ADD_PROPERTY_RO(QNetworkSession, bytesWritten);
+    MO_ADD_PROPERTY_RO(QNetworkSession, configuration);
+    MO_ADD_PROPERTY_RO(QNetworkSession, error);
+    MO_ADD_PROPERTY_RO(QNetworkSession, errorString);
+    MO_ADD_PROPERTY_RO(QNetworkSession, interface);
+    MO_ADD_PROPERTY_RO(QNetworkSession, isOpen);
+    MO_ADD_PROPERTY_RO(QNetworkSession, state);
+    MO_ADD_PROPERTY_RO(QNetworkSession, usagePolicies);
+
     MO_ADD_METAOBJECT1(QTcpServer, QObject);
     MO_ADD_PROPERTY_RO(QTcpServer, isListening);
     MO_ADD_PROPERTY(QTcpServer, maxPendingConnections, setMaxPendingConnections);
@@ -173,9 +282,7 @@ void NetworkSupport::registerMetaTypes()
     MO_ADD_PROPERTY_RO(QSslCertificate, extensions);
     MO_ADD_PROPERTY_RO(QSslCertificate, isBlacklisted);
     MO_ADD_PROPERTY_RO(QSslCertificate, isNull);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     MO_ADD_PROPERTY_RO(QSslCertificate, isSelfSigned);
-#endif
     MO_ADD_PROPERTY_RO(QSslCertificate, issuerInfoAttributes);
     MO_ADD_PROPERTY_RO(QSslCertificate, publicKey);
     MO_ADD_PROPERTY_RO(QSslCertificate, serialNumber);
@@ -219,14 +326,10 @@ void NetworkSupport::registerMetaTypes()
     MO_ADD_PROPERTY(QSslConfiguration, privateKey, setPrivateKey);
     MO_ADD_PROPERTY(QSslConfiguration, protocol, setProtocol);
     MO_ADD_PROPERTY_RO(QSslConfiguration, sessionCipher);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     MO_ADD_PROPERTY_RO(QSslConfiguration, sessionProtocol);
-#endif
     MO_ADD_PROPERTY(QSslConfiguration, sessionTicket, setSessionTicket);
     MO_ADD_PROPERTY_RO(QSslConfiguration, sessionTicketLifeTimeHint);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     MO_ADD_PROPERTY_ST(QSslConfiguration, systemCaCertificates);
-#endif
 
     MO_ADD_METAOBJECT0(QSslKey);
     MO_ADD_PROPERTY_RO(QSslKey, algorithm);
@@ -246,9 +349,7 @@ void NetworkSupport::registerMetaTypes()
     MO_ADD_PROPERTY(QSslSocket, peerVerifyName, setPeerVerifyName);
     MO_ADD_PROPERTY(QSslSocket, privateKey, setPrivateKey);
     MO_ADD_PROPERTY_RO(QSslSocket, protocol);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     MO_ADD_PROPERTY_RO(QSslSocket, sessionProtocol);
-#endif
     MO_ADD_PROPERTY_RO(QSslSocket, sessionCipher);
     MO_ADD_PROPERTY(QSslSocket, sslConfiguration, setSslConfiguration);
     MO_ADD_PROPERTY_RO(QSslSocket, sslErrors);
@@ -299,9 +400,7 @@ static const MetaEnum::Value<QSsl::KeyAlgorithm> ssl_key_algorithm_table[] = {
     E(Opaque),
     E(Rsa),
     E(Dsa),
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     E(Ec)
-#endif
 };
 #undef E
 
@@ -322,11 +421,9 @@ static const MetaEnum::Value<QSsl::SslProtocol> ssl_protocol_table[] = {
     E(AnyProtocol),
     E(TlsV1SslV3),
     E(SecureProtocols),
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     E(TlsV1_0OrLater),
     E(TlsV1_1OrLater),
     E(TlsV1_2OrLater),
-#endif
     E(UnknownProtocol)
 };
 #undef E
@@ -341,6 +438,22 @@ static QString sslCertificateToString(const QSslCertificate &cert)
 #endif // QT_NO_SSL
 
 #define E(x) { QNetworkConfiguration:: x, #x }
+static const MetaEnum::Value<QNetworkConfiguration::BearerType> network_config_bearer_type_table[] = {
+    E(BearerUnknown),
+    E(BearerEthernet),
+    E(BearerWLAN),
+    E(Bearer2G),
+    E(Bearer3G),
+    E(Bearer4G),
+    E(BearerCDMA2000),
+    E(BearerWCDMA),
+    E(BearerHSPA),
+    E(BearerBluetooth),
+    E(BearerWiMAX),
+    E(BearerEVDO),
+    E(BearerLTE)
+};
+
 static const MetaEnum::Value<QNetworkConfiguration::Purpose> network_config_purpose_table[] = {
     E(UnknownPurpose),
     E(PublicPurpose),
@@ -363,6 +476,16 @@ static const MetaEnum::Value<QNetworkConfiguration::Type> network_config_type_ta
 };
 #undef E
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+#define E(x) { QNetworkAddressEntry:: x, #x }
+static const MetaEnum::Value<QNetworkAddressEntry::DnsEligibilityStatus> network_address_entry_dns_eligibility_table[] = {
+    E(DnsEligibilityUnknown),
+    E(DnsEligible),
+    E(DnsIneligible)
+};
+#undef E
+#endif
+
 #define E(x) { QNetworkConfigurationManager:: x, #x }
 static const MetaEnum::Value<QNetworkConfigurationManager::Capabilities> network_config_manager_capabilities_table[] = {
     E(CanStartAndStopInterfaces),
@@ -375,6 +498,70 @@ static const MetaEnum::Value<QNetworkConfigurationManager::Capabilities> network
 };
 #undef E
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+#define E(x) { QNetworkRequest:: x, #x }
+static const MetaEnum::Value<QNetworkRequest::RedirectPolicy> network_redirect_policy_table[] = {
+    E(ManualRedirectPolicy),
+    E(NoLessSafeRedirectPolicy),
+    E(SameOriginRedirectPolicy),
+    E(UserVerifiedRedirectPolicy)
+};
+#undef E
+#endif
+
+#define E(x) { QNetworkProxy:: x, #x }
+static const MetaEnum::Value<QNetworkProxy::Capability> network_proxy_capabilitiy_table[] = {
+    E(TunnelingCapability),
+    E(ListeningCapability),
+    E(UdpTunnelingCapability),
+    E(CachingCapability),
+    E(HostNameLookupCapability),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    E(SctpTunnelingCapability),
+    E(SctpListeningCapability)
+#endif
+};
+
+static const MetaEnum::Value<QNetworkProxy::ProxyType> network_proxy_type_table[] = {
+    E(NoProxy),
+    E(DefaultProxy),
+    E(Socks5Proxy),
+    E(HttpProxy),
+    E(HttpCachingProxy),
+    E(FtpCachingProxy)
+};
+#undef E
+
+#define E(x) { QNetworkSession:: x, #x }
+static const MetaEnum::Value<QNetworkSession::SessionError> network_session_error_table[] = {
+    E(UnknownSessionError),
+    E(SessionAbortedError),
+    E(RoamingError),
+    E(OperationNotSupportedError),
+    E(InvalidConfigurationError)
+};
+
+static const MetaEnum::Value<QNetworkSession::State> network_session_state_table[] = {
+    E(Invalid),
+    E(NotAvailable),
+    E(Connecting),
+    E(Connected),
+    E(Closing),
+    E(Disconnected),
+    E(Roaming)
+};
+
+static const MetaEnum::Value<QNetworkSession::UsagePolicies> network_session_usage_policy_table[] = {
+    E(NoPolicy),
+    E(NoBackgroundTrafficPolicy)
+};
+#undef E
+
+static QString proxyToString(const QNetworkProxy &proxy)
+{
+    return VariantHandler::displayString(proxy.type());
+}
+
 void NetworkSupport::registerVariantHandler()
 {
     ER_REGISTER_FLAGS(QAbstractSocket, PauseModes, socket_pause_mode_table);
@@ -392,10 +579,30 @@ void NetworkSupport::registerVariantHandler()
     VariantHandler::registerStringConverter<QSslError>(std::mem_fn(&QSslError::errorString));
 #endif
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    ER_REGISTER_ENUM(QNetworkAddressEntry, DnsEligibilityStatus, network_address_entry_dns_eligibility_table);
+#endif
+
+    ER_REGISTER_ENUM(QNetworkConfiguration, BearerType, network_config_bearer_type_table);
     ER_REGISTER_ENUM(QNetworkConfiguration, Purpose, network_config_purpose_table);
     ER_REGISTER_FLAGS(QNetworkConfiguration, StateFlags, network_config_state_table);
     ER_REGISTER_ENUM(QNetworkConfiguration, Type, network_config_type_table);
+    VariantHandler::registerStringConverter<QNetworkConfiguration>(std::mem_fn(&QNetworkConfiguration::name));
     ER_REGISTER_FLAGS(QNetworkConfigurationManager, Capabilities, network_config_manager_capabilities_table);
+
+    VariantHandler::registerStringConverter<QNetworkInterface>(std::mem_fn(&QNetworkInterface::name));
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+    ER_REGISTER_ENUM(QNetworkRequest, RedirectPolicy, network_redirect_policy_table);
+#endif
+
+    ER_REGISTER_FLAGS(QNetworkProxy, Capabilities, network_proxy_capabilitiy_table);
+    ER_REGISTER_ENUM(QNetworkProxy, ProxyType, network_proxy_type_table);
+    VariantHandler::registerStringConverter<QNetworkProxy>(proxyToString);
+
+    ER_REGISTER_ENUM(QNetworkSession, SessionError, network_session_error_table);
+    ER_REGISTER_ENUM(QNetworkSession, State, network_session_state_table);
+    ER_REGISTER_FLAGS(QNetworkSession, UsagePolicies, network_session_usage_policy_table);
 }
 
 NetworkSupportFactory::NetworkSupportFactory(QObject *parent)
