@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -90,7 +90,7 @@ static vtkGraphLayoutStrategy *layoutStrategyForName(const QString &layoutName)
     } else if (layoutName == "simple2D") {
         return vtkSimple2DLayoutStrategy::New();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
