@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -50,9 +50,7 @@ SGWireframeWidget::SGWireframeWidget(QWidget *parent, Qt::WindowFlags f)
 {
 }
 
-SGWireframeWidget::~SGWireframeWidget()
-{
-}
+SGWireframeWidget::~SGWireframeWidget() = default;
 
 void SGWireframeWidget::paintEvent(QPaintEvent *)
 {
@@ -203,7 +201,7 @@ void SGWireframeWidget::drawWire(QPainter *painter, int vertexIndex1, int vertex
 void SGWireframeWidget::drawHighlightedFace(QPainter *painter, const QVector<int> &vertexIndices)
 {
     QVector<QPointF> vertices;
-    foreach (int index, vertexIndices) {
+    for (int index : vertexIndices) {
         if (!m_highlightedVertices.contains(index))
             return; // There is one vertex that is not highlighted. Don't highlight the face.
         vertices << m_vertices.at(index) * m_zoom + m_offset;
@@ -229,24 +227,24 @@ void SGWireframeWidget::setModel(QAbstractItemModel *vertexModel, QAbstractItemM
     }
     m_vertexModel = vertexModel;
     m_vertexModel->rowCount();
-    connect(m_vertexModel, SIGNAL(modelReset()),
-            this, SLOT(onVertexModelReset()));
-    connect(m_vertexModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(onVertexModelDataChanged(QModelIndex,QModelIndex)));
-    connect(m_vertexModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(onVertexModelRowsInserted(QModelIndex,int,int)));
+    connect(m_vertexModel, &QAbstractItemModel::modelReset,
+            this, &SGWireframeWidget::onVertexModelReset);
+    connect(m_vertexModel, &QAbstractItemModel::dataChanged,
+            this, &SGWireframeWidget::onVertexModelDataChanged);
+    connect(m_vertexModel, &QAbstractItemModel::rowsInserted,
+            this, &SGWireframeWidget::onVertexModelRowsInserted);
 
     if (m_adjacencyModel) {
         disconnect(m_adjacencyModel, nullptr, this, nullptr);
     }
     m_adjacencyModel = adjacencyModel;
     m_adjacencyModel->rowCount();
-    connect(m_adjacencyModel, SIGNAL(modelReset()),
-            this, SLOT(onAdjacencyModelReset()));
-    connect(m_adjacencyModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(onAdjacencyModelDataChanged(QModelIndex,QModelIndex)));
-    connect(m_adjacencyModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(onAdjacencyModelRowsInserted(QModelIndex,int,int)));
+    connect(m_adjacencyModel, &QAbstractItemModel::modelReset,
+            this, &SGWireframeWidget::onAdjacencyModelReset);
+    connect(m_adjacencyModel, &QAbstractItemModel::dataChanged,
+            this, &SGWireframeWidget::onAdjacencyModelDataChanged);
+    connect(m_adjacencyModel, &QAbstractItemModel::rowsInserted,
+            this, &SGWireframeWidget::onAdjacencyModelRowsInserted);
 }
 
 void SGWireframeWidget::setHighlightModel(QItemSelectionModel *selectionModel)
@@ -256,8 +254,8 @@ void SGWireframeWidget::setHighlightModel(QItemSelectionModel *selectionModel)
 
     m_highlightModel = selectionModel;
 
-    connect(m_highlightModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(onHighlightDataChanged(QItemSelection,QItemSelection)));
+    connect(m_highlightModel, &QItemSelectionModel::selectionChanged,
+            this, &SGWireframeWidget::onHighlightDataChanged);
 }
 
 void SGWireframeWidget::onVertexModelReset()
