@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -52,7 +52,7 @@ class MaterialExtension : public MaterialExtensionInterface, public PropertyCont
 
 public:
     explicit MaterialExtension(PropertyController *controller);
-    ~MaterialExtension();
+    ~MaterialExtension() override;
 
     bool setObject(void *object, const QString &typeName) override;
 
