@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,7 +39,7 @@ class MaterialExtensionClient : public MaterialExtensionInterface
 
 public:
     explicit MaterialExtensionClient(const QString &name, QObject *parent = nullptr);
-    virtual ~MaterialExtensionClient();
+    ~MaterialExtensionClient() override;
 
 public slots:
     void getShader(int row) override;
