@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,9 +38,7 @@ MaterialExtensionInterface::MaterialExtensionInterface(const QString &name, QObj
     ObjectBroker::registerObject(name, this);
 }
 
-MaterialExtensionInterface::~MaterialExtensionInterface()
-{
-}
+MaterialExtensionInterface::~MaterialExtensionInterface() = default;
 
 const QString &MaterialExtensionInterface::name() const
 {
