@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class MaterialTab : public QWidget
     Q_OBJECT
 public:
     explicit MaterialTab(PropertyWidget *parent);
-    ~MaterialTab();
+    ~MaterialTab() override;
 
 private:
     void setObjectBaseName(const QString &baseName);
