@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,7 +38,7 @@ class QuickClientItemModel : public ClientDecorationIdentityProxyModel
     Q_OBJECT
 public:
     explicit QuickClientItemModel(QObject *parent = nullptr);
-    ~QuickClientItemModel();
+    ~QuickClientItemModel() override;
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 };
