@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Filipe Azevedo <filipe.azevedo@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,6 +28,8 @@
 
 #include "quickdecorationsdrawer.h"
 
+#include <compat/qasconst.h>
+
 #include <QDebug>
 #include <QPainter>
 #include <QVector2D>
@@ -82,19 +84,21 @@ void QuickDecorationsDrawer::drawDecorations()
     m_painter->save();
 
     // bounding box
-    m_painter->setPen(m_renderInfo->settings.boundingRectColor);
-    m_painter->setBrush(m_renderInfo->settings.boundingRectBrush);
-    m_painter->drawRect(itemGeometry.boundingRect);
+    if (itemGeometry.boundingRect.isValid()) {
+        m_painter->setPen(m_renderInfo->settings.boundingRectColor);
+        m_painter->setBrush(m_renderInfo->settings.boundingRectBrush);
+        m_painter->drawRect(itemGeometry.boundingRect);
+    }
 
     // original geometry
-    if (itemGeometry.itemRect != itemGeometry.boundingRect) {
+    if (itemGeometry.itemRect.isValid() && itemGeometry.itemRect != itemGeometry.boundingRect) {
         m_painter->setPen(m_renderInfo->settings.geometryRectColor);
         m_painter->setBrush(m_renderInfo->settings.geometryRectBrush);
         m_painter->drawRect(itemGeometry.itemRect);
     }
 
     // children rect
-    if (itemGeometry.itemRect != itemGeometry.boundingRect &&
+    if (itemGeometry.childrenRect.isValid() && itemGeometry.itemRect != itemGeometry.boundingRect &&
             itemGeometry.transform.isIdentity()) {
         // If this item is transformed the children rect will be painted wrongly,
         // so for now skip painting it.
@@ -270,7 +274,7 @@ void QuickDecorationsDrawer::drawDecorations()
 
     // Finally draw texts over the traced rectangles and lines
     // This make sure texts are always readable
-    foreach (const auto &t, texts) {
+    for (const auto &t : qAsConst(texts)) {
         if (t.label.isEmpty())
             continue;
 
@@ -290,7 +294,7 @@ void QuickDecorationsDrawer::drawTraces()
 
     m_painter->save();
 
-    foreach (auto itemGeometry, itemsGeometry) {
+    for (auto itemGeometry : itemsGeometry) {
         itemGeometry.scaleTo(m_renderInfo->zoom);
 
         // bounding box
@@ -303,9 +307,10 @@ void QuickDecorationsDrawer::drawTraces()
         m_painter->setBrush(m_painter->pen().color());
 
         const int margin = m_painter->fontMetrics().width(QLatin1Char('X')) / 2;
-        const QRectF classRect = itemGeometry.boundingRect
-                .adjusted(0, 0, 0, -(itemGeometry.boundingRect.height()
-                                     -(m_painter->fontMetrics().height() * 1.6)));
+        const QRectF classRect =
+            itemGeometry.boundingRect.adjusted(
+                0, 0, 0,
+                -(itemGeometry.boundingRect.height() - (m_painter->fontMetrics().height() * 1.6)));
         m_painter->drawRect(classRect);
 
         // type name label
@@ -338,7 +343,7 @@ QuickItemGeometry QuickDecorationsDrawer::itemGeometry() const
 {
     switch (m_type) {
     case QuickDecorationsDrawer::Decorations:
-        return static_cast<const QuickDecorationsRenderInfo *const>(m_renderInfo)->itemGeometry;
+        return static_cast<const QuickDecorationsRenderInfo *>(m_renderInfo)->itemGeometry;
     case QuickDecorationsDrawer::Traces:
         break;
     }
@@ -352,7 +357,7 @@ QVector<QuickItemGeometry> QuickDecorationsDrawer::itemsGeometry() const
     case QuickDecorationsDrawer::Decorations:
         break;
     case QuickDecorationsDrawer::Traces:
-        return static_cast<const QuickDecorationsTracesInfo *const>(m_renderInfo)->itemsGeometry;
+        return static_cast<const QuickDecorationsTracesInfo *>(m_renderInfo)->itemsGeometry;
     }
 
     return QVector<QuickItemGeometry>();
