@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -63,7 +63,7 @@ class QuickSceneGraphModel;
 class RemoteViewServer;
 class ObjectId;
 class PaintAnalyzer;
-typedef QVector<ObjectId> ObjectIds;
+using ObjectIds = QVector<ObjectId>;
 
 class RenderModeRequest : public QObject
 {
@@ -71,7 +71,7 @@ class RenderModeRequest : public QObject
 
 public:
     explicit RenderModeRequest(QObject *parent = nullptr);
-    ~RenderModeRequest();
+    ~RenderModeRequest() override;
 
     void applyOrDelay(QQuickWindow *toWindow, QuickInspectorInterface::RenderMode customRenderMode);
 
@@ -98,8 +98,8 @@ class QuickInspector : public QuickInspectorInterface
     Q_INTERFACES(GammaRay::QuickInspectorInterface)
 
 public:
-    explicit QuickInspector(ProbeInterface *probe, QObject *parent = nullptr);
-    ~QuickInspector();
+    explicit QuickInspector(Probe *probe, QObject *parent = nullptr);
+    ~QuickInspector() override;
 
 signals:
     void elementsAtReceived(const GammaRay::ObjectIds &ids, int bestCandidate);
@@ -134,8 +134,8 @@ private slots:
     void itemSelectionChanged(const QItemSelection &selection);
     void sgSelectionChanged(const QItemSelection &selection);
     void sgNodeDeleted(QSGNode *node);
-    void objectSelected(QObject *object);
-    void objectSelected(void *object, const QString &typeName);
+    void qObjectSelected(QObject *object);
+    void nonQObjectSelected(void *object, const QString &typeName);
     void objectCreated(QObject *object);
     void recreateOverlay();
     void aboutToCleanSceneGraph();
@@ -149,11 +149,12 @@ private:
     void registerVariantHandlers();
     void registerPCExtensions();
     QString findSGNodeType(QSGNode *node) const;
+    static void scanForProblems();
 
     GammaRay::ObjectIds recursiveItemsAt(QQuickItem *parent, const QPointF &pos,
                                          GammaRay::RemoteViewInterface::RequestMode mode, int& bestCandidate) const;
 
-    ProbeInterface *m_probe;
+    Probe *m_probe;
     std::unique_ptr<AbstractScreenGrabber> m_overlay;
     QPointer<QQuickWindow> m_window;
     QPointer<QQuickItem> m_currentItem;
