@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -66,7 +66,7 @@ public:
     Q_DECLARE_FLAGS(State, StateFlag)
 
     explicit QuickInspectorWidget(QWidget *parent = nullptr);
-    ~QuickInspectorWidget();
+    ~QuickInspectorWidget() override;
 
     Q_INVOKABLE void saveTargetState(QSettings *settings) const;
     Q_INVOKABLE void restoreTargetState(QSettings *settings);
