@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,13 +33,14 @@
 
 #include <QHash>
 #include <QPointer>
+#include <QTimer>
 #include <QVector>
 
 #include <array>
 #include <unordered_map>
+#include <vector>
 
 QT_BEGIN_NAMESPACE
-class QSignalMapper;
 class QQuickItem;
 class QQuickWindow;
 QT_END_NAMESPACE
@@ -56,7 +57,7 @@ class QuickItemModel : public ObjectModelBase<QAbstractItemModel>
 
 public:
     explicit QuickItemModel(QObject *parent = nullptr);
-    ~QuickItemModel();
+    ~QuickItemModel() override;
 
     void setWindow(QQuickWindow *window);
 
@@ -83,6 +84,12 @@ private:
     void clear();
     void populateFromItem(QQuickItem *item);
 
+    /**
+     * Reports problems (e.g. visible but out of view) about all items of this
+     * model. Uses the item flags from the model.
+     */
+    void reportProblems();
+
     /// Track all changes to item @p item in this model (parentChanged, windowChanged, ...)
     void connectItem(QQuickItem *item);
 
@@ -113,6 +120,17 @@ private:
     QHash<QQuickItem *, int> m_itemFlags;
     std::unordered_map<QQuickItem *, std::array<QMetaObject::Connection, 8>> m_itemConnections;
 
+    // dataChange signal compression
+    struct PendingDataChange {
+        QQuickItem *item = nullptr;
+        bool eventChange = false;
+        bool flagChange = false;
+        inline bool operator<(QQuickItem *rhs) const { return item < rhs; }
+    };
+    std::vector<PendingDataChange> m_pendingDataChanges;
+    QTimer *m_dataChangeTimer = nullptr;
+    void emitPendingDataChanges();
+
     QuickEventMonitor *m_clickEventFilter;
 };
 
