@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,7 +44,7 @@ class QuickItemTreeWatcher : public QObject
 
 public:
     explicit QuickItemTreeWatcher(QTreeView *itemView, QTreeView *sgView, QObject *parent = nullptr);
-    ~QuickItemTreeWatcher();
+    ~QuickItemTreeWatcher() override;
 
 private slots:
     void itemModelRowsInserted(const QModelIndex &parent, int start, int end);
