@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -50,7 +50,7 @@ class QuickSceneGraphModel : public ObjectModelBase<QAbstractItemModel>
     Q_OBJECT
 public:
     explicit QuickSceneGraphModel(QObject *parent = nullptr);
-    ~QuickSceneGraphModel();
+    ~QuickSceneGraphModel() override;
 
     void setWindow(QQuickWindow *window);
 
