@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -38,7 +38,6 @@
 #include <core/propertycontroller.h>
 #include <core/varianthandler.h>
 #include <core/objecttypefilterproxymodel.h>
-#include <core/probeinterface.h>
 #include <core/singlecolumnobjectproxymodel.h>
 #include <core/remote/server.h>
 #include <core/remote/serverproxymodel.h>
@@ -77,7 +76,7 @@ Q_DECLARE_METATYPE(QGraphicsItem::GraphicsItemFlags)
 Q_DECLARE_METATYPE(QGraphicsItem::PanelModality)
 Q_DECLARE_METATYPE(QGraphicsPixmapItem::ShapeMode)
 
-SceneInspector::SceneInspector(ProbeInterface *probe, QObject *parent)
+SceneInspector::SceneInspector(Probe *probe, QObject *parent)
     : SceneInspectorInterface(parent)
     , m_propertyController(new PropertyController(QStringLiteral("com.kdab.GammaRay.SceneInspector"),
                                                   this))
@@ -91,10 +90,10 @@ SceneInspector::SceneInspector(ProbeInterface *probe, QObject *parent)
     registerGraphicsViewMetaTypes();
     registerVariantHandlers();
 
-    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)),
-            SLOT(objectSelected(QObject*,QPoint)));
-    connect(probe->probe(), SIGNAL(nonQObjectSelected(void*,QString)),
-            this, SLOT(objectSelected(void*,QString)));
+    connect(probe, &Probe::objectSelected,
+            this, &SceneInspector::qObjectSelected);
+    connect(probe, &Probe::nonQObjectSelected,
+            this, &SceneInspector::nonQObjectSelected);
 
     auto *sceneFilterProxy
         = new ObjectTypeFilterProxyModel<QGraphicsScene>(this);
@@ -104,8 +103,8 @@ SceneInspector::SceneInspector(ProbeInterface *probe, QObject *parent)
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.SceneList"), singleColumnProxy);
 
     QItemSelectionModel *sceneSelection = ObjectBroker::selectionModel(singleColumnProxy);
-    connect(sceneSelection, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(sceneSelected(QItemSelection)));
+    connect(sceneSelection, &QItemSelectionModel::selectionChanged,
+            this, &SceneInspector::sceneSelected);
 
     m_sceneModel = new SceneModel(this);
     auto sceneProxy = new ServerProxyModel<KRecursiveFilterProxyModel>(this);
@@ -113,8 +112,8 @@ SceneInspector::SceneInspector(ProbeInterface *probe, QObject *parent)
     sceneProxy->addRole(ObjectModel::ObjectIdRole);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.SceneGraphModel"), sceneProxy);
     m_itemSelectionModel = ObjectBroker::selectionModel(sceneProxy);
-    connect(m_itemSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(sceneItemSelected(QItemSelection)));
+    connect(m_itemSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, &SceneInspector::sceneItemSelectionChanged);
 }
 
 void SceneInspector::sceneSelected(const QItemSelection &selection)
@@ -141,10 +140,10 @@ void SceneInspector::connectToScene()
     if (!scene || !m_clientConnected)
         return;
 
-    connect(scene, SIGNAL(sceneRectChanged(QRectF)),
-            this, SIGNAL(sceneRectChanged(QRectF)));
-    connect(scene, SIGNAL(changed(QList<QRectF>)),
-            this, SIGNAL(sceneChanged()));
+    connect(scene, &QGraphicsScene::sceneRectChanged,
+            this, &SceneInspectorInterface::sceneRectChanged);
+    connect(scene, &QGraphicsScene::changed,
+            this, &SceneInspectorInterface::sceneChanged);
 
     initializeGui();
 }
@@ -203,7 +202,7 @@ void SceneInspector::renderScene(const QTransform &transform, const QSize &size)
     emit sceneRendered(view);
 }
 
-void SceneInspector::sceneItemSelected(const QItemSelection &selection)
+void SceneInspector::sceneItemSelectionChanged(const QItemSelection &selection)
 {
     QModelIndex index;
     if (!selection.isEmpty())
@@ -223,7 +222,7 @@ void SceneInspector::sceneItemSelected(const QItemSelection &selection)
     }
 }
 
-void SceneInspector::objectSelected(QObject *object, const QPoint &pos)
+void SceneInspector::qObjectSelected(QObject *object, const QPoint &pos)
 {
     QWidget *widget = qobject_cast<QWidget *>(object);
     QGraphicsView *qgv = Util::findParentOfType<QGraphicsView>(object);
@@ -238,7 +237,7 @@ void SceneInspector::objectSelected(QObject *object, const QPoint &pos)
         sceneItemSelected(item);
 }
 
-void SceneInspector::objectSelected(void *obj, const QString &typeName)
+void SceneInspector::nonQObjectSelected(void *obj, const QString &typeName)
 {
     if (typeName == QLatin1String("QGraphicsItem*"))   // TODO: can we get sub-classes here?
         sceneItemSelected(reinterpret_cast<QGraphicsItem *>(obj));
@@ -261,7 +260,7 @@ void SceneInspector::sceneItemSelected(QGraphicsItem *item)
 
 void SceneInspector::sceneClicked(const QPointF &pos)
 {
-    QGraphicsItem *item = m_sceneModel->scene()->itemAt(pos);
+    QGraphicsItem *item = m_sceneModel->scene()->itemAt(pos, QTransform());
     if (item)
         sceneItemSelected(item);
 }
@@ -296,9 +295,6 @@ void SceneInspector::registerGraphicsViewMetaTypes()
     MO_ADD_PROPERTY_RO(QGraphicsItem, isActive);
     MO_ADD_PROPERTY_RO(QGraphicsItem, isClipped);
     MO_ADD_PROPERTY(QGraphicsItem, isEnabled, setEnabled);
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    MO_ADD_PROPERTY_RO(QGraphicsItem, isObscured);
-#endif
     MO_ADD_PROPERTY_RO(QGraphicsItem, isPanel);
     MO_ADD_PROPERTY(QGraphicsItem, isSelected, setSelected);
     MO_ADD_PROPERTY_RO(QGraphicsItem, isUnderMouse);
@@ -368,14 +364,10 @@ void SceneInspector::registerGraphicsViewMetaTypes()
 
     MO_ADD_METAOBJECT1(QGraphicsTextItem, QGraphicsObject);
     MO_ADD_PROPERTY(QGraphicsTextItem, defaultTextColor, setDefaultTextColor);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     MO_ADD_PROPERTY(QGraphicsTextItem, document, setDocument);
-#endif
     MO_ADD_PROPERTY(QGraphicsTextItem, font, setFont);
     MO_ADD_PROPERTY(QGraphicsTextItem, tabChangesFocus, setTabChangesFocus);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     MO_ADD_PROPERTY(QGraphicsTextItem, textInteractionFlags, setTextInteractionFlags);
-#endif
     MO_ADD_PROPERTY(QGraphicsTextItem, textWidth, setTextWidth);
 
     MO_ADD_METAOBJECT0(QGraphicsLayoutItem);
@@ -429,9 +421,7 @@ static const MetaEnum::Value<QGraphicsItem::GraphicsItemFlag> graphics_item_flag
     E(ItemSendsScenePositionChanges),
     E(ItemStopsClickFocusPropagation),
     E(ItemStopsFocusHandling),
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     E(ItemContainsChildrenInShape)
-#endif
 };
 
 static QString graphicsItemFlagsToString(QGraphicsItem::GraphicsItemFlags flags)
@@ -470,19 +460,9 @@ void SceneInspector::registerVariantHandlers()
     VariantHandler::registerStringConverter<QGraphicsLayoutItem *>(Util::addressToString);
     VariantHandler::registerStringConverter<QGraphicsLayout *>(Util::addressToString);
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
-    VariantHandler::registerStringConverter<QGraphicsEffect *>(Util::displayString);
-    VariantHandler::registerStringConverter<QGraphicsObject *>(Util::displayString);
-    VariantHandler::registerStringConverter<QGraphicsWidget *>(Util::displayString);
-#endif
-
     VariantHandler::registerStringConverter<QGraphicsItem::GraphicsItemFlags>(
         graphicsItemFlagsToString);
     VariantHandler::registerStringConverter<QGraphicsItem::CacheMode>(graphicsItemCacheModeToString);
     VariantHandler::registerStringConverter<QGraphicsItem::PanelModality>(
         graphicsItemPanelModalityToString);
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(SceneInspectorFactory)
-#endif
