@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -50,17 +50,17 @@ class SceneInspector : public SceneInspectorInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::SceneInspectorInterface)
 public:
-    explicit SceneInspector(ProbeInterface *probe, QObject *parent = nullptr);
+    explicit SceneInspector(Probe *probe, QObject *parent = nullptr);
 
 private slots:
     void initializeGui() override;
     void renderScene(const QTransform &transform, const QSize &size) override;
 
     void sceneSelected(const QItemSelection &selection);
-    void sceneItemSelected(const QItemSelection &selection);
+    void sceneItemSelectionChanged(const QItemSelection &selection);
     void sceneItemSelected(QGraphicsItem *item);
-    void objectSelected(QObject *object, const QPoint &pos);
-    void objectSelected(void *obj, const QString &typeName);
+    void qObjectSelected(QObject *object, const QPoint &pos);
+    void nonQObjectSelected(void *obj, const QString &typeName);
     void sceneClicked(const QPointF &pos) override;
 
     void clientConnectedChanged(bool clientConnected);
