@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,7 +38,7 @@ class SceneInspectorClient : public SceneInspectorInterface
     Q_INTERFACES(GammaRay::SceneInspectorInterface)
 public:
     explicit SceneInspectorClient(QObject *parent = nullptr);
-    ~SceneInspectorClient();
+    ~SceneInspectorClient() override;
 
     void initializeGui() override;
     void renderScene(const QTransform &transform, const QSize &size) override;
