@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,7 +47,7 @@ class SceneInspectorInterface : public QObject
     Q_OBJECT
 public:
     explicit SceneInspectorInterface(QObject *parent = nullptr);
-    virtual ~SceneInspectorInterface();
+    ~SceneInspectorInterface() override;
 
     virtual void initializeGui() = 0;
 
