@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,7 +48,7 @@ class ScriptEngineDebuggerWidget : public QWidget
     Q_OBJECT
 public:
     explicit ScriptEngineDebuggerWidget(QWidget *parent = nullptr);
-    virtual ~ScriptEngineDebuggerWidget();
+    ~ScriptEngineDebuggerWidget() override;
 private slots:
     void scriptEngineSelected(int index);
 
