@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Mathias Hasselmann <mathias.hasselmann@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,11 +47,10 @@ SignalHistoryView::SignalHistoryView(QWidget *parent)
 
     setItemDelegateForColumn(SignalHistoryModel::EventColumn, m_eventDelegate);
 
-    connect(m_eventDelegate, SIGNAL(visibleOffsetChanged(qint64)), this, SLOT(
-                eventDelegateChanged()));
-    connect(m_eventDelegate, SIGNAL(visibleIntervalChanged(qint64)), this,
-            SLOT(eventDelegateChanged()));
-    connect(m_eventDelegate, SIGNAL(totalIntervalChanged()), this, SLOT(eventDelegateChanged()));
+    connect(m_eventDelegate, &SignalHistoryDelegate::visibleOffsetChanged, this, &SignalHistoryView::eventDelegateChanged);
+    connect(m_eventDelegate, &SignalHistoryDelegate::visibleIntervalChanged, this,
+            &SignalHistoryView::eventDelegateChanged);
+    connect(m_eventDelegate, &SignalHistoryDelegate::totalIntervalChanged, this, &SignalHistoryView::eventDelegateChanged);
 }
 
 void SignalHistoryView::eventDelegateChanged()
@@ -85,8 +84,8 @@ void SignalHistoryView::setEventScrollBar(QScrollBar *scrollBar)
         m_eventScrollBar = scrollBar;
 
         if (m_eventScrollBar) {
-            connect(m_eventScrollBar, SIGNAL(sliderMoved(int)),
-                    this, SLOT(eventScrollBarSliderMoved(int)));
+            connect(m_eventScrollBar, &QAbstractSlider::sliderMoved,
+                    this, &SignalHistoryView::eventScrollBarSliderMoved);
         }
     }
 }
