@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,11 +32,10 @@
 
 using namespace GammaRay;
 
-SignalMonitorInterface::SignalMonitorInterface(QObject* parent): QObject(parent)
+SignalMonitorInterface::SignalMonitorInterface(QObject *parent)
+    : QObject(parent)
 {
-    ObjectBroker::registerObject<SignalMonitorInterface*>(this);
+    ObjectBroker::registerObject<SignalMonitorInterface *>(this);
 }
 
-SignalMonitorInterface::~SignalMonitorInterface()
-{
-}
+SignalMonitorInterface::~SignalMonitorInterface() = default;
