@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,7 +37,7 @@ class SignalMonitorInterface : public QObject
     Q_OBJECT
 public:
     explicit SignalMonitorInterface(QObject *parent = nullptr);
-    ~SignalMonitorInterface();
+    ~SignalMonitorInterface() override;
 
 public slots:
     virtual void sendClockUpdates(bool enabled) = 0;
