@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Mathias Hasselmann <mathias.hasselmann@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,7 +48,7 @@ class SignalMonitorWidget : public QWidget
     Q_OBJECT
 public:
     explicit SignalMonitorWidget(QWidget *parent = nullptr);
-    ~SignalMonitorWidget();
+    ~SignalMonitorWidget() override;
 
 private slots:
     void intervalScaleValueChanged(int value);
