@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,6 +43,4 @@ StateMachineViewerInterface::StateMachineViewerInterface(QObject *parent)
     ObjectBroker::registerObject<StateMachineViewerInterface *>(this);
 }
 
-StateMachineViewerInterface::~StateMachineViewerInterface()
-{
-}
+StateMachineViewerInterface::~StateMachineViewerInterface() = default;
