@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -37,10 +37,10 @@
 #include "transitionmodel.h"
 
 #include <core/objecttypefilterproxymodel.h>
-#include <core/probeinterface.h>
 #include <core/singlecolumnobjectproxymodel.h>
 #include <core/remote/serverproxymodel.h>
 #include <common/objectbroker.h>
+#include <compat/qasconst.h>
 
 #include <QStateMachine>
 #include <QItemSelectionModel>
@@ -56,7 +56,7 @@
 using namespace GammaRay;
 using namespace std;
 
-StateMachineViewerServer::StateMachineViewerServer(ProbeInterface *probe, QObject *parent)
+StateMachineViewerServer::StateMachineViewerServer(Probe *probe, QObject *parent)
     : StateMachineViewerInterface(parent)
     , m_stateModel(new StateModel(this))
     , m_transitionModel(new TransitionModel(this))
@@ -66,9 +66,9 @@ StateMachineViewerServer::StateMachineViewerServer(ProbeInterface *probe, QObjec
     proxyModel->addRole(StateModel::StateIdRole);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.StateModel"), proxyModel);
     m_stateSelectionModel = ObjectBroker::selectionModel(proxyModel);
-    connect(m_stateSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(stateSelectionChanged()));
-    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), this, SLOT(objectSelected(QObject*)));
+    connect(m_stateSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, &StateMachineViewerServer::stateSelectionChanged);
+    connect(probe, &Probe::objectSelected, this, &StateMachineViewerServer::objectSelected);
 
 #ifdef HAVE_QT_SCXML
     auto stateMachineFilter = new ObjectTypeFilterProxyModel<QStateMachine, QScxmlStateMachine>(this);
@@ -97,7 +97,7 @@ void StateMachineViewerServer::repopulateGraph()
     if (m_filteredStates.isEmpty()) {
         addState(m_stateModel->stateMachine()->rootState());
     } else {
-        foreach (State state, m_filteredStates)
+        for (State state : qAsConst(m_filteredStates))
             addState(state);
     }
     m_recursionGuard.clear();
@@ -118,7 +118,7 @@ bool StateMachineViewerServer::mayAddState(State state)
     if (m_recursionGuard.contains(state))
         return false;
 
-    foreach (State filter, m_filteredStates) {
+    for (State filter : qAsConst(m_filteredStates)) {
         if (filter == state || selectedStateMachine()->isDescendantOf(filter, state)) {
             return true;
         }
@@ -137,7 +137,7 @@ void StateMachineViewerServer::setFilteredStates(const QVector<State> &states)
     } else {
         QStringList stateNames;
         stateNames.reserve(states.size());
-        foreach (State state, states)
+        for (State state : states)
             stateNames << selectedStateMachine()->stateLabel(state);
         emit message(tr("Setting filter on: %1").arg(stateNames.join(QStringLiteral(", "))));
     }
@@ -165,11 +165,11 @@ void StateMachineViewerServer::setSelectedStateMachine(StateMachineDebugInterfac
     if (machine) {
         machine->setParent(this);
 
-        connect(machine, SIGNAL(runningChanged(bool)), this, SLOT(updateStartStop()));
-        connect(machine, SIGNAL(stateEntered(State)), this, SLOT(stateEntered(State)));
-        connect(machine, SIGNAL(stateExited(State)), this, SLOT(stateExited(State)));
-        connect(machine, SIGNAL(transitionTriggered(Transition)), this, SLOT(handleTransitionTriggered(Transition)));
-        connect(machine, SIGNAL(logMessage(QString,QString)), this, SLOT(handleLogMessage(QString,QString)));
+        connect(machine, &StateMachineDebugInterface::runningChanged, this, &StateMachineViewerServer::updateStartStop);
+        connect(machine, &StateMachineDebugInterface::stateEntered, this, &StateMachineViewerServer::stateEntered);
+        connect(machine, &StateMachineDebugInterface::stateExited, this, &StateMachineViewerServer::stateExited);
+        connect(machine, &StateMachineDebugInterface::transitionTriggered, this, &StateMachineViewerServer::handleTransitionTriggered);
+        connect(machine, &StateMachineDebugInterface::logMessage, this, &StateMachineViewerServer::handleLogMessage);
     }
     updateStartStop();
 
@@ -207,13 +207,13 @@ void StateMachineViewerServer::stateSelectionChanged()
     qDebug() << selection;
     QVector<State> filter;
     filter.reserve(selection.size());
-    foreach (const QModelIndex &index, selection) {
+    for (const QModelIndex &index : selection) {
         State state = index.data(StateModel::StateValueRole).value<State>();
         bool addState = true;
         /// only pick the top-level items of the selection
         // NOTE: this might be slow for large selections, if someone wants to come up with a better
         // algorithm, please - go for it!
-        foreach (State potentialParent, filter) {
+        for (State potentialParent : qAsConst(filter)) {
             if (selectedStateMachine()->isDescendantOf(potentialParent, state)) {
                 addState = false;
                 break;
@@ -255,7 +255,7 @@ void StateMachineViewerServer::stateConfigurationChanged()
 
     StateMachineConfiguration config;
     config.reserve(newConfig.size());
-    foreach (State state, newConfig)
+    for (State state : qAsConst(newConfig))
         config << StateId(state);
 
     emit stateConfigurationChanged(config);
@@ -353,8 +353,3 @@ StateMachineViewerFactory::StateMachineViewerFactory(QObject *parent)
     setSupportedTypes(QVector<QByteArray>() << QByteArrayLiteral("QStateMachine")
                                             << QByteArrayLiteral("QScxmlStateMachine"));
 }
-
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(StateMachineViewerFactory)
-#endif
