@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -131,7 +131,7 @@ KDSME::RuntimeController::Configuration toSmeConfiguration(const StateMachineCon
                                                                        KDSME::State *> &map)
 {
     KDSME::RuntimeController::Configuration result;
-    foreach (const StateId &id, config) {
+    for (const StateId &id : config) {
         if (auto state = map.value(id))
             result << state;
     }
