@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -26,6 +26,8 @@
 
 #include "statemachinewatcher.h"
 
+#include <compat/qasconst.h>
+
 #include <QAbstractTransition>
 #include <QFinalState>
 #include <QState>
@@ -51,9 +53,7 @@ StateMachineWatcher::StateMachineWatcher(QObject *parent)
 {
 }
 
-StateMachineWatcher::~StateMachineWatcher()
-{
-}
+StateMachineWatcher::~StateMachineWatcher() = default;
 
 void StateMachineWatcher::setWatchedStateMachine(QStateMachine *machine)
 {
@@ -80,29 +80,29 @@ void StateMachineWatcher::watchState(QAbstractState *state)
     if (state->machine() != m_watchedStateMachine)
         return;
 
-    connect(state, SIGNAL(entered()),
-            this, SLOT(handleStateEntered()), Qt::UniqueConnection);
-    connect(state, SIGNAL(exited()),
-            this, SLOT(handleStateExited()), Qt::UniqueConnection);
-    connect(state, SIGNAL(destroyed(QObject*)),
-            this, SLOT(handleStateDestroyed()), Qt::UniqueConnection);
+    connect(state, &QAbstractState::entered,
+            this, &StateMachineWatcher::handleStateEntered, Qt::UniqueConnection);
+    connect(state, &QAbstractState::exited,
+            this, &StateMachineWatcher::handleStateExited, Qt::UniqueConnection);
+    connect(state, &QObject::destroyed,
+            this, &StateMachineWatcher::handleStateDestroyed, Qt::UniqueConnection);
 
     Q_FOREACH(QAbstractTransition *transition, state->findChildren<QAbstractTransition *>()) {
-        connect(transition, SIGNAL(triggered()),
-                this, SLOT(handleTransitionTriggered()), Qt::UniqueConnection);
+        connect(transition, &QAbstractTransition::triggered,
+                this, &StateMachineWatcher::handleTransitionTriggered, Qt::UniqueConnection);
     }
     m_watchedStates << state;
 }
 
 void StateMachineWatcher::clearWatchedStates()
 {
-    Q_FOREACH(QAbstractState *state, m_watchedStates) {
-        disconnect(state, SIGNAL(entered()), this, SLOT(handleStateEntered()));
-        disconnect(state, SIGNAL(exited()), this, SLOT(handleStateExited()));
-        disconnect(state, SIGNAL(destroyed(QObject*)), this, SLOT(handleStateDestroyed()));
+    for (QAbstractState *state : qAsConst(m_watchedStates)) {
+        disconnect(state, &QAbstractState::entered, this, &StateMachineWatcher::handleStateEntered);
+        disconnect(state, &QAbstractState::exited, this, &StateMachineWatcher::handleStateExited);
+        disconnect(state, &QObject::destroyed, this, &StateMachineWatcher::handleStateDestroyed);
 
         Q_FOREACH(QAbstractTransition *transition, state->findChildren<QAbstractTransition *>()) {
-            disconnect(transition, SIGNAL(triggered()), this, SLOT(handleTransitionTriggered()));
+            disconnect(transition, &QAbstractTransition::triggered, this, &StateMachineWatcher::handleTransitionTriggered);
         }
     }
     m_watchedStates.clear();
