@@ -9,7 +9,7 @@
 
   Contact info@kdab.com if any conditions of this licensing are not clear to you.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -54,7 +54,7 @@ public:
     };
 
     explicit StateModel(QObject *parent = nullptr);
-    ~StateModel();
+    ~StateModel() override;
 
     void setStateMachine(StateMachineDebugInterface *stateMachine);
     StateMachineDebugInterface *stateMachine() const;
@@ -68,6 +68,7 @@ public:
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const override;
     QMap<int, QVariant> itemData(const QModelIndex &index) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
 protected:
     Q_DECLARE_PRIVATE(StateModel)
