@@ -9,7 +9,7 @@
 
   Contact info@kdab.com if any conditions of this licensing are not clear to you.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -43,7 +43,7 @@ class TransitionModel : public ObjectModelBase<QAbstractItemModel>
     Q_OBJECT
 public:
     explicit TransitionModel(QObject *parent = nullptr);
-    ~TransitionModel();
+    ~TransitionModel() override;
     void setState(QAbstractState *state);
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
