@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -34,6 +34,7 @@
 #include <QPainter>
 #include <QStyleOption>
 #include <QDebug>
+#include <QApplication>
 
 using namespace GammaRay;
 
@@ -41,7 +42,7 @@ AbstractStyleElementStateTable::AbstractStyleElementStateTable(QObject *parent)
     : AbstractStyleElementModel(parent)
     , m_interface(ObjectBroker::object<StyleInspectorInterface *>())
 {
-    connect(m_interface, SIGNAL(cellSizeChanged()), SLOT(cellSizeChanged()));
+    connect(m_interface, &StyleInspectorInterface::cellSizeChanged, this, &AbstractStyleElementStateTable::cellSizeChanged);
 }
 
 void AbstractStyleElementStateTable::cellSizeChanged()
@@ -75,6 +76,6 @@ QVariant AbstractStyleElementStateTable::headerData(int section, Qt::Orientation
 void AbstractStyleElementStateTable::fillStyleOption(QStyleOption *option, int column) const
 {
     option->rect = QRect(0, 0, m_interface->cellWidth(), m_interface->cellHeight());
-    option->palette = m_style->standardPalette();
+    option->palette = qApp->palette();
     option->state = StyleOption::prettyState(column);
 }
