@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -73,9 +73,6 @@ static const control_element_t controlElements[] = {
     MAKE_CE_X(CE_Header, makeHeaderStyleOption),
     MAKE_CE_X(CE_HeaderSection, makeHeaderStyleOption),
     MAKE_CE_X(CE_HeaderLabel, makeHeaderStyleOption),
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    MAKE_CE(CE_Q3DockWindowEmptyArea),
-#endif
     MAKE_CE_X(CE_ToolBoxTab, makeToolBoxStyleOption),
     MAKE_CE(CE_SizeGrip),
     MAKE_CE(CE_Splitter),
