@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -82,10 +82,6 @@ static const pixel_metric_t pixelMetrics[] = {
     MAKE_PM(PM_IndicatorHeight),
     MAKE_PM(PM_ExclusiveIndicatorWidth),
     MAKE_PM(PM_ExclusiveIndicatorHeight),
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    MAKE_PM(PM_CheckListButtonSize),
-    MAKE_PM(PM_CheckListControllerSize),
-#endif
     MAKE_PM(PM_DialogButtonsSeparator),
     MAKE_PM(PM_DialogButtonsButtonWidth),
     MAKE_PM(PM_DialogButtonsButtonHeight),
