@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -96,9 +96,7 @@ QVariant StandardIconModel::doData(int row, int column, int role) const
     MAKE_SP(SP_FileDialogListView);
     MAKE_SP(SP_FileDialogBack);
     MAKE_SP(SP_DirIcon);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     MAKE_SP(SP_DirLinkOpenIcon);
-#endif
     MAKE_SP(SP_DialogOkButton);
     MAKE_SP(SP_DialogCancelButton);
     MAKE_SP(SP_DialogHelpButton);
@@ -130,9 +128,7 @@ QVariant StandardIconModel::doData(int row, int column, int role) const
     MAKE_SP(SP_MediaSeekBackward);
     MAKE_SP(SP_MediaVolume);
     MAKE_SP(SP_MediaVolumeMuted);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     MAKE_SP(SP_LineEditClearButton);
-#endif
 
     return QVariant();
 }
@@ -144,11 +140,7 @@ int StandardIconModel::doColumnCount() const
 
 int StandardIconModel::doRowCount() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 2, 0)
-    return QStyle::SP_MediaVolumeMuted + 1;
-#else
     return QStyle::SP_LineEditClearButton + 1;
-#endif
 }
 
 QVariant StandardIconModel::headerData(int section, Qt::Orientation orientation, int role) const
