@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,9 +40,7 @@ StyleInspectorClient::StyleInspectorClient(QObject *parent)
     setCellZoom(cellZoom());
 }
 
-StyleInspectorClient::~StyleInspectorClient()
-{
-}
+StyleInspectorClient::~StyleInspectorClient() = default;
 
 void StyleInspectorClient::setCellHeight(int height)
 {
