@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,8 @@ StyleInspectorWidget::StyleInspectorWidget(QWidget *parent)
     ui->setupUi(this);
 
     ui->styleSelector->setModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.StyleList")));
-    connect(ui->styleSelector, SIGNAL(currentIndexChanged(int)), SLOT(styleSelected(int)));
+    connect(ui->styleSelector, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+            this, &StyleInspectorWidget::styleSelected);
 
     ui->primitivePage->setModel(ObjectBroker::model(QStringLiteral(
                                                         "com.kdab.GammaRay.StyleInspector.PrimitiveModel")));
@@ -94,7 +95,3 @@ void StyleInspectorWidget::styleSelected(int index)
                                                              0),
                            QItemSelectionModel::ClearAndSelect);
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(StyleInspectorUiFactory)
-#endif
