@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class StyleInspectorWidget : public QWidget
     Q_OBJECT
 public:
     explicit StyleInspectorWidget(QWidget *parent = nullptr);
-    virtual ~StyleInspectorWidget();
+    ~StyleInspectorWidget() override;
 
 private slots:
     void styleSelected(int index);
