@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,13 +35,13 @@ using namespace GammaRay;
 // The following commit in qtbase.git deprecated versioned style class in 5.7.0
 //   95a6dc1 - QStyleOption*V<N>: mark as Q_DECL_DEPRECATED
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
-typedef QStyleOptionFrame QStyleOptionFrameCV;
-typedef QStyleOptionToolBox QStyleOptionToolBoxCV;
-typedef QStyleOptionTab QStyleOptionTabCV;
-typedef QStyleOptionTabBarBase QStyleOptionTabBarBaseCV;
-typedef QStyleOptionTabWidgetFrame QStyleOptionTabWidgetFrameCV;
-typedef QStyleOptionViewItem QStyleOptionViewItemCV;
-typedef QStyleOptionProgressBar QStyleOptionProgressBarCV;
+using QStyleOptionFrameCV = QStyleOptionFrame;
+using QStyleOptionToolBoxCV = QStyleOptionToolBox;
+using QStyleOptionTabCV = QStyleOptionTab;
+using QStyleOptionTabBarBaseCV = QStyleOptionTabBarBase;
+using QStyleOptionTabWidgetFrameCV = QStyleOptionTabWidgetFrame;
+using QStyleOptionViewItemCV = QStyleOptionViewItem;
+using QStyleOptionProgressBarCV = QStyleOptionProgressBar;
 #else
 typedef QStyleOptionFrameV3 QStyleOptionFrameCV;
 typedef QStyleOptionToolBoxV2 QStyleOptionToolBoxCV;
