@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,11 +45,7 @@ uint qHash(const TimerId &id)
 {
     switch (id.m_type) {
     case TimerId::InvalidType:
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         Q_UNREACHABLE();
-#else
-        Q_ASSERT(false);
-#endif
         break;
 
     case TimerId::QQmlTimerType:
@@ -64,17 +60,9 @@ uint qHash(const TimerId &id)
 }
 }
 
-TimerId::TimerId()
-    : m_type(InvalidType)
-    , m_timerAddress(nullptr)
-    , m_timerId(-1)
-{
-}
-
 TimerId::TimerId(QObject *timer)
     : m_type(QQmlTimerType)
     , m_timerAddress(timer)
-    , m_timerId(-1)
 {
     Q_ASSERT(timer);
 
@@ -113,11 +101,7 @@ bool TimerId::operator==(const TimerId &other) const
 
     switch (m_type) {
     case TimerId::InvalidType:
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         Q_UNREACHABLE();
-#else
-        Q_ASSERT(false);
-#endif
         break;
 
     case TimerId::QQmlTimerType:
@@ -136,11 +120,7 @@ bool TimerId::operator<(const TimerId &other) const
     if (m_type == other.m_type) {
         switch (m_type) {
         case TimerId::InvalidType: {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
             Q_UNREACHABLE();
-#else
-            Q_ASSERT(false);
-#endif
             return false;
         }
 
@@ -176,11 +156,7 @@ void TimerIdInfo::update(const TimerId &id, QObject *receiver)
 
     switch (id.type()) {
     case TimerId::InvalidType: {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         Q_UNREACHABLE();
-#else
-        Q_ASSERT(false);
-#endif
         break;
     }
 
@@ -228,19 +204,11 @@ void TimerIdInfo::update(const TimerId &id, QObject *receiver)
         const QAbstractEventDispatcher *dispatcher = QAbstractEventDispatcher::instance(object->thread());
         const QList<QAbstractEventDispatcher::TimerInfo> timers = dispatcher->registeredTimers(object);
         const auto it = std::find_if(timers.constBegin(), timers.constEnd(), [this](const QAbstractEventDispatcher::TimerInfo &timer) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
             return timer.timerId == timerId;
-#else
-            return timer.first == timerId;
-#endif
         });
 
         if (it != timers.constEnd()) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
             interval = (*it).interval;
-#else
-            interval = (*it).second;
-#endif
             state = RepeatState;
         }
 
