@@ -5,7 +5,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -34,6 +34,8 @@
 #include <common/objectid.h>
 #include <common/sourcelocation.h>
 
+#include <compat/qasconst.h>
+
 #include <QElapsedTimer>
 #include <QMutexLocker>
 #include <QTimerEvent>
@@ -70,10 +72,7 @@ struct TimeoutEvent
 
 struct TimerIdData
 {
-    TimerIdData()
-        : totalWakeupsEvents(0)
-        , changed(false)
-    { }
+    TimerIdData() = default;
 
     void update(const TimerId &id, QObject *receiver = nullptr)
     {
@@ -153,8 +152,7 @@ struct TimerIdData
             return 0;
 
         int max = 0;
-        for (int i = 0; i < timeoutEvents.size(); i++) {
-            const TimeoutEvent &event = timeoutEvents.at(i);
+        for (auto event : timeoutEvents) {
             if (event.executionTime > max)
                 max = event.executionTime;
         }
@@ -162,11 +160,11 @@ struct TimerIdData
     }
 
     TimerIdInfo info;
-    int totalWakeupsEvents;
+    int totalWakeupsEvents = 0;
     QElapsedTimer functionCallTimer;
     QList<TimeoutEvent> timeoutEvents;
 
-    bool changed;
+    bool changed = false;
 };
 }
 
@@ -185,7 +183,7 @@ TimerModel::TimerModel(QObject *parent)
 
     m_pushTimer->setSingleShot(true);
     m_pushTimer->setInterval(5000);
-    connect(m_pushTimer, SIGNAL(timeout()), this, SLOT(pushChanges()));
+    connect(m_pushTimer, &QTimer::timeout, this, &TimerModel::pushChanges);
 
     QInternal::registerCallback(QInternal::EventNotifyCallback, eventNotifyCallback);
 }
@@ -282,11 +280,7 @@ void TimerModel::checkDispatcherStatus(QObject *object)
         int remaining = -1;
 
         if (gIt.key().timerId() > -1) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
             remaining = dispatcher->remainingTime(gIt.key().timerId());
-#else
-            remaining = gIt.value().info.lastReceiverObject ? 0 : -1;
-#endif
         }
 
         // Timer inactive or invalid, or free timer
@@ -441,22 +435,22 @@ void TimerModel::setSourceModel(QAbstractItemModel *sourceModel)
     beginResetModel();
     m_sourceModel = sourceModel;
 
-    connect(m_sourceModel, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-            this, SLOT(slotBeginInsertRows(QModelIndex,int,int)));
-    connect(m_sourceModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(slotEndInsertRows()));
-    connect(m_sourceModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-            this, SLOT(slotBeginRemoveRows(QModelIndex,int,int)));
-    connect(m_sourceModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(slotEndRemoveRows()));
-    connect(m_sourceModel, SIGNAL(modelAboutToBeReset()),
-            this, SLOT(slotBeginReset()));
-    connect(m_sourceModel, SIGNAL(modelReset()),
-            this, SLOT(slotEndReset()));
-    connect(m_sourceModel, SIGNAL(layoutAboutToBeChanged()),
-            this, SLOT(slotBeginReset()));
-    connect(m_sourceModel, SIGNAL(layoutChanged()),
-            this, SLOT(slotEndReset()));
+    connect(m_sourceModel, &QAbstractItemModel::rowsAboutToBeInserted,
+            this, &TimerModel::slotBeginInsertRows);
+    connect(m_sourceModel, &QAbstractItemModel::rowsInserted,
+            this, &TimerModel::slotEndInsertRows);
+    connect(m_sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
+            this, &TimerModel::slotBeginRemoveRows);
+    connect(m_sourceModel, &QAbstractItemModel::rowsRemoved,
+            this, &TimerModel::slotEndRemoveRows);
+    connect(m_sourceModel, &QAbstractItemModel::modelAboutToBeReset,
+            this, &TimerModel::slotBeginReset);
+    connect(m_sourceModel, &QAbstractItemModel::modelReset,
+            this, &TimerModel::slotEndReset);
+    connect(m_sourceModel, &QAbstractItemModel::layoutAboutToBeChanged,
+            this, &TimerModel::slotBeginReset);
+    connect(m_sourceModel, &QAbstractItemModel::layoutChanged,
+            this, &TimerModel::slotEndReset);
 
     endResetModel();
 }
@@ -473,7 +467,7 @@ QModelIndex TimerModel::index(int row, int column, const QModelIndex &parent) co
         }
     }
 
-    return QModelIndex();
+    return {};
 }
 
 int TimerModel::columnCount(const QModelIndex &parent) const
@@ -731,7 +725,7 @@ void TimerModel::applyChanges(const TimerIdInfoContainer &changes)
     }
 
     // Inform model about data changes
-    foreach (const auto &range, dataChangedRanges) {
+    for (const auto &range : qAsConst(dataChangedRanges)) {
         emit dataChanged(index(range.first, 0), index(range.second, columnCount() - 1));
     }
 
