@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,7 +29,6 @@
 #include "timertop.h"
 #include "timermodel.h"
 
-#include <core/probeinterface.h>
 #include <core/objecttypefilterproxymodel.h>
 #include <core/signalspycallbackset.h>
 
@@ -98,7 +97,7 @@ static void signal_end_callback(QObject *caller, int method_index)
     TimerModel::instance()->postSignalActivate(caller, method_index);
 }
 
-TimerTop::TimerTop(ProbeInterface *probe, QObject *parent)
+TimerTop::TimerTop(Probe *probe, QObject *parent)
     : TimerTopInterface(parent)
 {
     Q_ASSERT(probe);
@@ -117,7 +116,7 @@ TimerTop::TimerTop(ProbeInterface *probe, QObject *parent)
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.TimerModel"), TimerModel::instance());
     m_selectionModel = ObjectBroker::selectionModel(TimerModel::instance());
 
-    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), this, SLOT(objectSelected(QObject*)));
+    connect(probe, &Probe::objectSelected, this, &TimerTop::objectSelected);
 }
 
 void TimerTop::clearHistory()
@@ -146,7 +145,3 @@ TimerTopFactory::TimerTopFactory(QObject *parent)
     : QObject(parent)
 {
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(TimerTopFactory)
-#endif
