@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -67,8 +67,8 @@ TimerTopWidget::TimerTopWidget(QWidget *parent)
     ui->timerView->setDeferredResizeMode(3, QHeaderView::ResizeToContents);
     ui->timerView->setDeferredResizeMode(4, QHeaderView::ResizeToContents);
     ui->timerView->setDeferredResizeMode(5, QHeaderView::ResizeToContents);
-    connect(ui->timerView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu(QPoint)));
-    connect(ui->clearTimers, SIGNAL(clicked()), m_interface, SLOT(clearHistory()));
+    connect(ui->timerView, &QWidget::customContextMenuRequested, this, &TimerTopWidget::contextMenu);
+    connect(ui->clearTimers, &QAbstractButton::clicked, m_interface, &TimerTopInterface::clearHistory);
 
     auto * const sortModel = new ClientTimerModel(this);
     sortModel->setSourceModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.TimerModel")));
@@ -81,9 +81,7 @@ TimerTopWidget::TimerTopWidget(QWidget *parent)
     ui->timerView->sortByColumn(TimerModel::WakeupsPerSecColumn, Qt::DescendingOrder);
 }
 
-TimerTopWidget::~TimerTopWidget()
-{
-}
+TimerTopWidget::~TimerTopWidget() = default;
 
 void TimerTopWidget::contextMenu(QPoint pos)
 {
@@ -103,8 +101,3 @@ void TimerTopWidget::contextMenu(QPoint pos)
     ext.populateMenu(&menu);
     menu.exec(ui->timerView->viewport()->mapToGlobal(pos));
 }
-
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(TimerTopUiFactory)
-#endif
