@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,7 +32,6 @@
 
 #include <core/metaobject.h>
 #include <core/metaobjectrepository.h>
-#include <core/probeinterface.h>
 #include <core/objecttypefilterproxymodel.h>
 #include <core/remote/serverproxymodel.h>
 
@@ -46,7 +45,7 @@
 
 using namespace GammaRay;
 
-TranslatorInspector::TranslatorInspector(ProbeInterface *probe, QObject *parent)
+TranslatorInspector::TranslatorInspector(Probe *probe, QObject *parent)
     : TranslatorInspectorInterface(QStringLiteral("com.kdab.GammaRay.TranslatorInspector"), parent)
     , m_probe(probe)
 {
@@ -62,8 +61,8 @@ TranslatorInspector::TranslatorInspector(ProbeInterface *probe, QObject *parent)
 
     m_selectionModel = ObjectBroker::selectionModel(m_translatorsModel);
     connect(m_selectionModel,
-            SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(selectionChanged(QItemSelection)));
+            &QItemSelectionModel::selectionChanged,
+            this, &TranslatorInspector::selectionChanged);
 
     m_translationsSelectionModel
         = ObjectBroker::selectionModel(m_translationsModel);
@@ -77,7 +76,7 @@ TranslatorInspector::TranslatorInspector(ProbeInterface *probe, QObject *parent)
     qApp->installEventFilter(this);
     sendLanguageChangeEvent();
 
-    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), SLOT(objectSelected(QObject*)));
+    connect(probe, &Probe::objectSelected, this, &TranslatorInspector::objectSelected);
 }
 
 void TranslatorInspector::sendLanguageChangeEvent()
