@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -53,7 +53,7 @@ class TranslatorInspector : public TranslatorInspectorInterface
     Q_INTERFACES(GammaRay::TranslatorInspectorInterface)
 
 public:
-    explicit TranslatorInspector(GammaRay::ProbeInterface *probe, QObject *parent = nullptr);
+    explicit TranslatorInspector(Probe *probe, QObject *parent = nullptr);
 
 public slots:
     void sendLanguageChangeEvent() override;
@@ -73,7 +73,7 @@ private:
     QItemSelectionModel *m_translationsSelectionModel;
     TranslatorsModel *m_translatorsModel;
     QAbstractProxyModel *m_translationsModel;
-    ProbeInterface *m_probe;
+    Probe *m_probe;
     TranslatorWrapper *m_fallbackWrapper;
 };
 
