@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,7 +38,7 @@ class TranslatorInspectorInterface : public QObject
 
 public:
     explicit TranslatorInspectorInterface(const QString &name, QObject *parent);
-    virtual ~TranslatorInspectorInterface();
+    ~TranslatorInspectorInterface() override;
 
     const QString &name() const { return m_name; }
 
