@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,7 +32,6 @@
 
 #include <common/endpoint.h>
 #include <core/objecttypefilterproxymodel.h>
-#include <core/probeinterface.h>
 #include <core/singlecolumnobjectproxymodel.h>
 
 #include <QDebug>
@@ -41,14 +40,14 @@
 
 using namespace GammaRay;
 
-WebInspector::WebInspector(ProbeInterface *probe, QObject *parent)
+WebInspector::WebInspector(Probe *probe, QObject *parent)
     : QObject(parent)
 {
     auto *webViewModel = new WebViewModel(this);
     webViewModel->setSourceModel(probe->objectListModel());
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.WebPages"), webViewModel);
 
-    connect(probe->probe(), SIGNAL(objectCreated(QObject*)), SLOT(objectAdded(QObject*)));
+    connect(probe, &Probe::objectCreated, this, &WebInspector::objectAdded);
 
     const QUrl serverUrl = Endpoint::instance()->serverAddress();
     QString serverAddress(GAMMARAY_DEFAULT_ANY_ADDRESS);
@@ -91,11 +90,7 @@ QString WebInspectorFactory::id() const
     return WebInspector::staticMetaObject.className();
 }
 
-void WebInspectorFactory::init(ProbeInterface *probe)
+void WebInspectorFactory::init(Probe *probe)
 {
-    new WebInspector(probe, probe->probe());
+    new WebInspector(probe, probe);
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(WebInspectorFactory)
-#endif
