@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,13 +42,12 @@ WebInspectorWidget::WebInspectorWidget(QWidget *parent)
 {
     ui->setupUi(this);
     ui->webPageComboBox->setModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.WebPages")));
-    connect(ui->webPageComboBox, SIGNAL(activated(int)), SLOT(webPageSelected(int)));
+    connect(ui->webPageComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
+            this, &WebInspectorWidget::webPageSelected);
     webPageSelected(0);
 }
 
-WebInspectorWidget::~WebInspectorWidget()
-{
-}
+WebInspectorWidget::~WebInspectorWidget() = default;
 
 void WebInspectorWidget::webPageSelected(int index)
 {
