@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -79,8 +79,10 @@ private slots:
 
         QAction *a1 = new QAction(QStringLiteral("Action 1"), this);
         a1->setShortcut(QKeySequence(QStringLiteral("Ctrl+K")));
+        a1->setShortcutContext(Qt::ApplicationShortcut);
         QAction *a2 = new QAction(QStringLiteral("Action 2"), this);
         a2->setShortcut(QKeySequence(QStringLiteral("Ctrl+K")));
+        a2->setShortcutContext(Qt::WidgetShortcut);
         QTest::qWait(1); // event loop re-entry
 
         auto sourceModel = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.ActionModel"));
