@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -52,8 +52,8 @@ AttachHelper::AttachHelper(const QString &gammaray, const QString &injector,
     , m_injector(injector)
 {
     m_proc->setProcessChannelMode(QProcess::ForwardedChannels);
-    connect(m_proc, SIGNAL(started()), this, SLOT(processStarted()));
-    connect(m_proc, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
+    connect(m_proc, &QProcess::started, this, &AttachHelper::processStarted);
+    connect(m_proc, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, &AttachHelper::processFinished);
     m_proc->start(debuggee, arguments);
 }
 
@@ -64,7 +64,7 @@ void AttachHelper::processStarted()
     const int timeout = qrand() % 1500 + 1;
     qDebug() << "attaching gammaray in" << timeout << "ms";
     m_timer->setSingleShot(true);
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(attach()));
+    connect(m_timer, &QTimer::timeout, this, &AttachHelper::attach);
     m_timer->start(timeout);
 }
 
