@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,13 +31,16 @@
 
 #include <config-gammaray.h>
 #include <core/probe.h>
+#include <core/propertycontroller.h>
 #include <common/paths.h>
 #include <common/objectbroker.h>
 #include <probe/hooks.h>
 #include <probe/probecreator.h>
 
 #include <core/abstractbindingprovider.h>
+#include <core/bindingaggregator.h>
 #include <core/bindingnode.h>
+#include <core/tools/objectinspector/bindingextension.h>
 #include <core/tools/objectinspector/bindingmodel.h>
 #include <plugins/qmlsupport/qmlbindingprovider.h>
 #include <plugins/quickinspector/quickimplicitbindingdependencyprovider.h>
@@ -63,6 +66,7 @@ template<typename CompareFunc>
 {
     std::vector<QModelIndex> childIndices;
     int rowCount = model->rowCount(index);
+    childIndices.reserve(rowCount);
     for (int i = 0; i < rowCount; ++i) {
         childIndices.push_back(model->index(i, 0, index));
     }
@@ -247,13 +251,23 @@ private slots:
 
 private:
     MockBindingProvider *provider;
+    BindingExtension *bindingExtension;
+    std::unique_ptr<ModelTest> modelTest;
+    QAbstractItemModel *bindingModel;
 };
 
 void BindingInspectorTest::initTestCase()
 {
     QQmlEngine engine; // Needed to initialize the Qml support plugin
     provider = new MockBindingProvider;
-    BindingModel::registerBindingProvider(std::unique_ptr<MockBindingProvider>(provider));
+    BindingAggregator::registerBindingProvider(std::unique_ptr<MockBindingProvider>(provider));
+
+    QTest::qWait(1);
+    bindingExtension = ObjectBroker::object<BindingExtension*>("com.kdab.GammaRay.ObjectInspector.bindingsExtension");
+    QVERIFY(bindingExtension);
+    bindingModel = bindingExtension->model();
+    QVERIFY(bindingModel);
+    modelTest.reset(new ModelTest(bindingModel));
 }
 
 void BindingInspectorTest::init()
@@ -286,7 +300,7 @@ void BindingInspectorTest::testMockProvider()
     QVERIFY(bindingNode1->parent() == nullptr);
     QCOMPARE(bindingNode1->object(), &obj1);
     QCOMPARE(bindingNode1->property().name(), "a");
-    QCOMPARE(bindingNode1->isBindingLoop(), false);
+    QCOMPARE(bindingNode1->isPartOfBindingLoop(), false);
     QCOMPARE(bindingNode1->cachedValue().toInt(), 53);
 
     auto dependencies1 = provider->findDependenciesFor(bindingNode1.get());
@@ -299,7 +313,7 @@ void BindingInspectorTest::testMockProvider()
     QVERIFY(bindingNode2->parent() == nullptr);
     QCOMPARE(bindingNode2->object(), &obj1);
     QCOMPARE(bindingNode2->property().name(), "c");
-    QCOMPARE(bindingNode2->isBindingLoop(), false);
+    QCOMPARE(bindingNode2->isPartOfBindingLoop(), false);
     QCOMPARE(bindingNode2->cachedValue().toChar(), QChar('x'));
 
     auto dependencies2 = provider->findDependenciesFor(bindingNode2.get());
@@ -308,13 +322,13 @@ void BindingInspectorTest::testMockProvider()
     QCOMPARE(dependency2->parent(), bindingNode2.get());
     QCOMPARE(dependency2->object(), &obj1);
     QCOMPARE(dependency2->property().name(), "b");
-    QCOMPARE(dependency2->isBindingLoop(), false);
+    QCOMPARE(dependency2->isPartOfBindingLoop(), false);
     QCOMPARE(dependency2->cachedValue().toBool(), true);
     auto &&dependency3 = dependencies2.back();
     QCOMPARE(dependency3->parent(), bindingNode2.get());
     QCOMPARE(dependency3->object(), &obj2);
     QCOMPARE(dependency3->property().name(), "b");
-    QCOMPARE(dependency3->isBindingLoop(), false);
+    QCOMPARE(dependency3->isPartOfBindingLoop(), false);
     QCOMPARE(dependency3->cachedValue().toBool(), false);
 }
 
@@ -400,7 +414,7 @@ void BindingInspectorTest::testQmlBindingProvider()
     QObject *rect = c.create();
     QTest::qWait(10);
     QVERIFY(rect);
-    QObject *text = rect->findChildren<QQuickText *>().front();
+    QObject *text = rect->findChildren<QQuickText *>().at(0);
 
     QObject *referencedObject = rect->objectName() == referencedObjectName ? rect : rect->findChild<QObject *>(referencedObjectName);
     QVERIFY(referencedObject);
@@ -412,7 +426,7 @@ void BindingInspectorTest::testQmlBindingProvider()
     QVERIFY(bindingNode);
     QCOMPARE(bindingNode->object(), text);
     QCOMPARE(bindingNode->property().name(), "text");
-    QCOMPARE(bindingNode->isBindingLoop(), false);
+    QCOMPARE(bindingNode->isPartOfBindingLoop(), false);
     QCOMPARE(bindingNode->cachedValue(), QStringLiteral("Hello world!"));
 
     auto dependencies = provider.findDependenciesFor(bindingNode.get());
@@ -420,7 +434,7 @@ void BindingInspectorTest::testQmlBindingProvider()
     const std::unique_ptr<BindingNode> &dependency = dependencies.front();
     QCOMPARE(dependency->object(), referencedObject);
     QCOMPARE(dependency->property().name(), "labelText");
-    QCOMPARE(dependency->isBindingLoop(), false);
+    QCOMPARE(dependency->isPartOfBindingLoop(), false);
     QCOMPARE(dependency->cachedValue(), QStringLiteral("Hello world!"));
     QCOMPARE(dependency->dependencies().size(), 0);
 
@@ -543,8 +557,6 @@ void BindingInspectorTest::testQtQuickProvider()
 
 void BindingInspectorTest::testModel()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
     MockObject obj2 { 35, false, 'y', 3.5, "Bye, World" };
 
@@ -556,15 +568,15 @@ void BindingInspectorTest::testModel()
         {&obj2, "a", &obj1, "a"},
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 2);
-    auto topLevelIndices = getSortedChildren(QModelIndex(), &bindingModel);
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 2);
+    auto topLevelIndices = getSortedChildren(QModelIndex(), bindingModel);
     QModelIndex obj1cIndex = topLevelIndices[0];
     QVERIFY(obj1cIndex.isValid());
     QCOMPARE(obj1cIndex.data().toString(), QStringLiteral("c"));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::ValueColumn).data().toChar(), QChar('x'));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("3"));
-    QCOMPARE(bindingModel.rowCount(obj1cIndex), 2);
+    QCOMPARE(bindingModel->rowCount(obj1cIndex), 2);
 
     auto obj1cChildIndices = getSortedChildren(obj1cIndex);
     QModelIndex obj1bIndex = obj1cChildIndices[0];
@@ -572,34 +584,32 @@ void BindingInspectorTest::testModel()
     QCOMPARE(obj1bIndex.data().toString(), QStringLiteral("b"));
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::ValueColumn).data().toBool(), true);
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1bIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1bIndex), 0);
 
     QModelIndex obj2bIndex = obj1cChildIndices[1];
     QVERIFY(obj2bIndex.isValid());
     QCOMPARE(obj2bIndex.data().toString(), QStringLiteral("d"));
     QCOMPARE(obj2bIndex.sibling(obj2bIndex.row(), BindingModel::ValueColumn).data().toDouble(), 3.5);
     QCOMPARE(obj2bIndex.sibling(obj2bIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
-    QCOMPARE(bindingModel.rowCount(obj2bIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj2bIndex), 1);
 
-    QModelIndex obj2aIndex = bindingModel.index(0, 0, obj2bIndex);
+    QModelIndex obj2aIndex = bindingModel->index(0, 0, obj2bIndex);
     QVERIFY(obj2aIndex.isValid());
     QCOMPARE(obj2aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj2aIndex.sibling(obj2aIndex.row(), BindingModel::ValueColumn).data().toInt(), 35);
     QCOMPARE(obj2aIndex.sibling(obj2aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj2aIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj2aIndex), 1);
 
-    QModelIndex obj1aIndex = bindingModel.index(0, 0, obj2aIndex);
+    QModelIndex obj1aIndex = bindingModel->index(0, 0, obj2aIndex);
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 0);
 }
 
 void BindingInspectorTest::testModelDataChanged()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
 
     provider->data = {{
@@ -609,15 +619,15 @@ void BindingInspectorTest::testModelDataChanged()
         { &obj1, "b", &obj1, "e" },
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 2);
-    auto topLevelIndices = getSortedChildren(QModelIndex(), &bindingModel);
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 2);
+    auto topLevelIndices = getSortedChildren(QModelIndex(), bindingModel);
     QModelIndex obj1aIndex = topLevelIndices[0];
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 3);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 3);
 
     auto obj1aChildren = getSortedChildren(obj1aIndex);
     QModelIndex obj1dIndex = obj1aChildren[2];
@@ -625,22 +635,22 @@ void BindingInspectorTest::testModelDataChanged()
     QCOMPARE(obj1dIndex.data().toString(), QStringLiteral("d"));
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::ValueColumn).data().toDouble(), 5.3);
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1dIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1dIndex), 0);
 
-    QSignalSpy dataChangedSpy(&bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+    QSignalSpy dataChangedSpy(bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
     QVERIFY(dataChangedSpy.isValid());
 
     obj1.setD(3.1415926535897932);
     obj1.setA(12);
 
-    TestHelpers::waitForSpy(&dataChangedSpy, 500);
+    dataChangedSpy.wait(500);
     QCOMPARE(dataChangedSpy.size(), 2);
     QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn));
     QCOMPARE(dataChangedSpy.at(0).at(1).toModelIndex(), obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn));
     QCOMPARE(dataChangedSpy.at(1).at(0).toModelIndex(), obj1dIndex.sibling(obj1dIndex.row(), BindingModel::ValueColumn));
     QCOMPARE(dataChangedSpy.at(1).at(1).toModelIndex(), obj1dIndex.sibling(obj1dIndex.row(), BindingModel::ValueColumn));
 
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 3);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 3);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 12);
 
@@ -650,40 +660,38 @@ void BindingInspectorTest::testModelDataChanged()
 
 void BindingInspectorTest::testModelAdditions()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
     provider->data = {{
         { &obj1, "a", &obj1, "c" }
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 1);
-    QModelIndex obj1aIndex = bindingModel.index(0, 0, QModelIndex());
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 1);
+    QModelIndex obj1aIndex = bindingModel->index(0, 0, QModelIndex());
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 1);
 
-    QModelIndex obj1cIndex = bindingModel.index(0, 0, obj1aIndex);
+    QModelIndex obj1cIndex = bindingModel->index(0, 0, obj1aIndex);
     QVERIFY(obj1cIndex.isValid());
     QCOMPARE(obj1cIndex.data().toString(), QStringLiteral("c"));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::ValueColumn).data().toChar(), QChar('x'));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1cIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1cIndex), 0);
 
-    QSignalSpy rowAddedSpy(&bindingModel, SIGNAL(rowsInserted(QModelIndex,int,int)));
-    QSignalSpy dataChangedSpy(&bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+    QSignalSpy rowAddedSpy(bindingModel, SIGNAL(rowsInserted(QModelIndex,int,int)));
+    QSignalSpy dataChangedSpy(bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
     QVERIFY(rowAddedSpy.isValid());
     QVERIFY(dataChangedSpy.isValid());
 
-    provider->data.push_back({ &obj1, "c", &obj1, "a" });
-    provider->data.push_back({ &obj1, "c", &obj1, "b" });
-    provider->data.push_back({ &obj1, "b", &obj1, "d" });
+    provider->data.emplace_back( &obj1, "c", &obj1, "a" );
+    provider->data.emplace_back( &obj1, "c", &obj1, "b" );
+    provider->data.emplace_back( &obj1, "b", &obj1, "d" );
     obj1.setA(12);
 
-    TestHelpers::waitForSpy(&rowAddedSpy, 500);
+    rowAddedSpy.wait(500);
     QCOMPARE(rowAddedSpy.size(), 1);
     QCOMPARE(rowAddedSpy.front().at(1).toInt(), 0);
     QCOMPARE(rowAddedSpy.front().at(2).toInt(), 1);
@@ -701,7 +709,7 @@ void BindingInspectorTest::testModelAdditions()
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("∞"));
 
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("∞"));
-    QCOMPARE(bindingModel.rowCount(obj1cIndex), 2);
+    QCOMPARE(bindingModel->rowCount(obj1cIndex), 2);
 
     auto obj1cChildren = getSortedChildren(obj1cIndex);
     QModelIndex node1aIndex = obj1cChildren[0];
@@ -709,27 +717,25 @@ void BindingInspectorTest::testModelAdditions()
     QCOMPARE(node1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(node1aIndex.sibling(node1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 12);
     QCOMPARE(node1aIndex.sibling(node1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("∞"));
-    QCOMPARE(bindingModel.rowCount(node1aIndex), 0);
+    QCOMPARE(bindingModel->rowCount(node1aIndex), 0);
 
     QModelIndex obj1bIndex = obj1cChildren[1];
     QVERIFY(obj1bIndex.isValid());
     QCOMPARE(obj1bIndex.data().toString(), QStringLiteral("b"));
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::ValueColumn).data().toBool(), true);
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj1bIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1bIndex), 1);
 
-    QModelIndex obj1dIndex = bindingModel.index(0, 0, obj1bIndex);
+    QModelIndex obj1dIndex = bindingModel->index(0, 0, obj1bIndex);
     QVERIFY(obj1dIndex.isValid());
     QCOMPARE(obj1dIndex.data().toString(), QStringLiteral("d"));
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::ValueColumn).data().toDouble(), 5.3);
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1dIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1dIndex), 0);
 }
 
 void BindingInspectorTest::testModelInsertions()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
     MockObject obj2 { 35, false, 'y', 3.5, "Bye, World" };
 
@@ -737,24 +743,24 @@ void BindingInspectorTest::testModelInsertions()
         { &obj1, "a", &obj1, "e" }
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 1);
-    QModelIndex obj1aIndex = bindingModel.index(0, 0, QModelIndex());
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 1);
+    QModelIndex obj1aIndex = bindingModel->index(0, 0, QModelIndex());
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 1);
 
-    QModelIndex obj1eIndex = bindingModel.index(0, 0, obj1aIndex);
+    QModelIndex obj1eIndex = bindingModel->index(0, 0, obj1aIndex);
     QVERIFY(obj1eIndex.isValid());
     QCOMPARE(obj1eIndex.data().toString(), QStringLiteral("e"));
     QCOMPARE(obj1eIndex.sibling(obj1eIndex.row(), BindingModel::ValueColumn).data().toString(), QStringLiteral("Hello World"));
     QCOMPARE(obj1eIndex.sibling(obj1eIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1eIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1eIndex), 0);
 
-    QSignalSpy rowAddedSpy(&bindingModel, SIGNAL(rowsInserted(QModelIndex,int,int)));
-    QSignalSpy dataChangedSpy(&bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+    QSignalSpy rowAddedSpy(bindingModel, SIGNAL(rowsInserted(QModelIndex,int,int)));
+    QSignalSpy dataChangedSpy(bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
     QVERIFY(rowAddedSpy.isValid());
     QVERIFY(dataChangedSpy.isValid());
 
@@ -764,14 +770,14 @@ void BindingInspectorTest::testModelInsertions()
     provider->data.emplace(provider->data.end(), &obj1, "e", &obj2, "a");
     obj1.setA(12);
 
-    TestHelpers::waitForSpy(&rowAddedSpy, 500);
+    rowAddedSpy.wait(500);
     QCOMPARE(rowAddedSpy.size(), 2);
     QCOMPARE(rowAddedSpy.front().at(0).toModelIndex(), obj1aIndex);
     QCOMPARE(rowAddedSpy.front().at(1).toInt(), 0);
     QCOMPARE(rowAddedSpy.front().at(2).toInt(), 1);
 
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 3);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 3);
 
     auto obj1aChildren = getSortedChildren(obj1aIndex);
     obj1eIndex = obj1aChildren[2];
@@ -779,39 +785,39 @@ void BindingInspectorTest::testModelInsertions()
     QCOMPARE(obj1eIndex.data().toString(), QStringLiteral("e"));
     QCOMPARE(obj1eIndex.sibling(obj1eIndex.row(), BindingModel::ValueColumn).data().toString(), QStringLiteral("Hello World"));
     QCOMPARE(obj1eIndex.sibling(obj1eIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj1eIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1eIndex), 1);
 
     QModelIndex obj1bIndex = obj1aChildren[0];
     QVERIFY(obj1bIndex.isValid());
     QCOMPARE(obj1bIndex.data().toString(), QStringLiteral("b"));
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::ValueColumn).data().toBool(), true);
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1bIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1bIndex), 0);
 
     QModelIndex obj1cIndex = obj1aChildren[1];
     QVERIFY(obj1cIndex.isValid());
     QCOMPARE(obj1cIndex.data().toString(), QStringLiteral("c"));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::ValueColumn).data().toChar(), QChar('x'));
     QCOMPARE(obj1cIndex.sibling(obj1cIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
-    QCOMPARE(bindingModel.rowCount(obj1cIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1cIndex), 1);
 
-    QModelIndex obj2aIndex = bindingModel.index(0, 0, obj1cIndex);
+    QModelIndex obj2aIndex = bindingModel->index(0, 0, obj1cIndex);
     QVERIFY(obj2aIndex.isValid());
     QCOMPARE(obj2aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj2aIndex.sibling(obj2aIndex.row(), BindingModel::ValueColumn).data().toInt(), 35);
     QCOMPARE(obj2aIndex.sibling(obj2aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj2aIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj2aIndex), 0);
 
     QCOMPARE(rowAddedSpy.back().at(0).toModelIndex(), obj1eIndex);
     QCOMPARE(rowAddedSpy.back().at(1).toInt(), 0);
     QCOMPARE(rowAddedSpy.back().at(2).toInt(), 0);
 
-    QModelIndex obj2aIndex2 = bindingModel.index(0, 0, obj1eIndex);
+    QModelIndex obj2aIndex2 = bindingModel->index(0, 0, obj1eIndex);
     QVERIFY(obj2aIndex2.isValid());
     QCOMPARE(obj2aIndex2.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj2aIndex2.sibling(obj2aIndex2.row(), BindingModel::ValueColumn).data().toInt(), 35);
     QCOMPARE(obj2aIndex2.sibling(obj2aIndex2.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj2aIndex2), 0);
+    QCOMPARE(bindingModel->rowCount(obj2aIndex2), 0);
 
     QCOMPARE(dataChangedSpy.size(), 3);
     QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn)); // Fair enough, we did change the value.
@@ -824,8 +830,6 @@ void BindingInspectorTest::testModelInsertions()
 
 void BindingInspectorTest::testModelRemovalAtEnd()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
 
     provider->data = {{
@@ -835,40 +839,40 @@ void BindingInspectorTest::testModelRemovalAtEnd()
         { &obj1, "d", &obj1, "e" },
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 2);
-    auto topLevelIndices = getSortedChildren(QModelIndex(), &bindingModel);
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 2);
+    auto topLevelIndices = getSortedChildren(QModelIndex(), bindingModel);
     QModelIndex obj1aIndex = topLevelIndices[0];
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 3);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 3);
 
-    QSignalSpy rowRemovedSpy(&bindingModel, SIGNAL(rowsRemoved(QModelIndex,int,int)));
-    QSignalSpy dataChangedSpy(&bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+    QSignalSpy rowRemovedSpy(bindingModel, SIGNAL(rowsRemoved(QModelIndex,int,int)));
+    QSignalSpy dataChangedSpy(bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
     QVERIFY(rowRemovedSpy.isValid());
     QVERIFY(dataChangedSpy.isValid());
 
     provider->data.erase(provider->data.end() - 3, provider->data.end());
     obj1.setA(12);
 
-    TestHelpers::waitForSpy(&rowRemovedSpy, 500);
+    rowRemovedSpy.wait(500);
     QCOMPARE(rowRemovedSpy.size(), 1);
     QCOMPARE(rowRemovedSpy.front().at(1).toInt(), 1);
     QCOMPARE(rowRemovedSpy.front().at(2).toInt(), 2);
     QCOMPARE(rowRemovedSpy.front().front().toModelIndex(), obj1aIndex);
 
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 1);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 12);
 
-    QModelIndex obj1bIndex = bindingModel.index(0, 0, obj1aIndex);
+    QModelIndex obj1bIndex = bindingModel->index(0, 0, obj1aIndex);
     QVERIFY(obj1bIndex.isValid());
     QCOMPARE(obj1bIndex.data().toString(), QStringLiteral("b"));
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::ValueColumn).data().toBool(), true);
     QCOMPARE(obj1bIndex.sibling(obj1bIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1bIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1bIndex), 0);
 
     QCOMPARE(dataChangedSpy.size(), 2);
     QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn)); // Fair enough, we did change the value.
@@ -879,8 +883,6 @@ void BindingInspectorTest::testModelRemovalAtEnd()
 
 void BindingInspectorTest::testModelRemovalInside()
 {
-    BindingModel bindingModel;
-    ModelTest modelTest(&bindingModel);
     MockObject obj1 { 53, true, 'x', 5.3, "Hello World" };
 
     provider->data = {{
@@ -890,40 +892,40 @@ void BindingInspectorTest::testModelRemovalInside()
         { &obj1, "b", &obj1, "e" },
     }};
 
-    bindingModel.setObject(&obj1);
-    QCOMPARE(bindingModel.rowCount(QModelIndex()), 2);
-    auto topLevelIndices = getSortedChildren(QModelIndex(), &bindingModel);
+    bindingExtension->setQObject(&obj1);
+    QCOMPARE(bindingModel->rowCount(QModelIndex()), 2);
+    auto topLevelIndices = getSortedChildren(QModelIndex(), bindingModel);
     QModelIndex obj1aIndex = topLevelIndices[0];
     QVERIFY(obj1aIndex.isValid());
     QCOMPARE(obj1aIndex.data().toString(), QStringLiteral("a"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 53);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("2"));
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 3);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 3);
 
-    QSignalSpy rowRemovedSpy(&bindingModel, SIGNAL(rowsRemoved(QModelIndex,int,int)));
-    QSignalSpy dataChangedSpy(&bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+    QSignalSpy rowRemovedSpy(bindingModel, SIGNAL(rowsRemoved(QModelIndex,int,int)));
+    QSignalSpy dataChangedSpy(bindingModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
     QVERIFY(rowRemovedSpy.isValid());
     QVERIFY(dataChangedSpy.isValid());
 
     provider->data.erase(provider->data.begin(), provider->data.begin() + 2);
     obj1.setA(12);
 
-    TestHelpers::waitForSpy(&rowRemovedSpy, 500);
+    rowRemovedSpy.wait(500);
     QCOMPARE(rowRemovedSpy.size(), 1);
     QCOMPARE(rowRemovedSpy.front().front().toModelIndex(), obj1aIndex);
     QCOMPARE(rowRemovedSpy.front().at(1).toInt(), 0);
     QCOMPARE(rowRemovedSpy.front().at(2).toInt(), 1);
 
-    QCOMPARE(bindingModel.rowCount(obj1aIndex), 1);
+    QCOMPARE(bindingModel->rowCount(obj1aIndex), 1);
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("1"));
     QCOMPARE(obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn).data().toInt(), 12);
 
-    QModelIndex obj1dIndex = bindingModel.index(0, 0, obj1aIndex);
+    QModelIndex obj1dIndex = bindingModel->index(0, 0, obj1aIndex);
     QVERIFY(obj1dIndex.isValid());
     QCOMPARE(obj1dIndex.data().toString(), QStringLiteral("d"));
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::ValueColumn).data().toDouble(), 5.3);
     QCOMPARE(obj1dIndex.sibling(obj1dIndex.row(), BindingModel::DepthColumn).data().toString(), QStringLiteral("0"));
-    QCOMPARE(bindingModel.rowCount(obj1dIndex), 0);
+    QCOMPARE(bindingModel->rowCount(obj1dIndex), 0);
 
     QCOMPARE(dataChangedSpy.size(), 2);
     QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), obj1aIndex.sibling(obj1aIndex.row(), BindingModel::ValueColumn)); // Fair enough, we did change the value.
@@ -959,7 +961,7 @@ void BindingInspectorTest::testIntegration()
     QObject *rect = c.create();
     QTest::qWait(10);
     QVERIFY(rect);
-    QObject *text = rect->findChildren<QQuickText *>().front();
+    QObject *text = rect->findChildren<QQuickText *>().at(0);
 
     QAbstractItemModel *bindingModel = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.ObjectInspector.bindingModel"));
     QVERIFY(bindingModel);
