@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -52,13 +52,10 @@ static void connectObjects(QObject *sender, QObject *receiver)
                          mySlot4()), Qt::BlockingQueuedConnection);
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 static void dummyFunction()
 {
 }
 
-#endif
-
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
@@ -95,15 +92,11 @@ int main(int argc, char **argv)
     connectObjects(&doubleSender, &doubleReceiver);
     connectObjects(&doubleSender, &doubleReceiver);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     MyTestObject lambdaSender, lambdaContext;
     lambdaSender.setObjectName(QStringLiteral("lambdaSender"));
     lambdaContext.setObjectName(QStringLiteral("lambdaContext"));
     QObject::connect(&lambdaSender, &MyTestObject::mySignal1, &dummyFunction);
-#endif
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     QObject::connect(&lambdaSender, &MyTestObject::mySignal2, &lambdaContext, &dummyFunction);
-#endif
 
     return app.exec();
 }
