@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,7 +47,7 @@ private slots:
     void generateDebug();
     void generateWarning();
     void generateCritical();
-    Q_NORETURN void generateFatal();
+    void generateFatal(); //FIXME: Q_RETURN fails on some configurations
 };
 }
 
