@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ public:
 
         auto t = new QTimer(this);
         t->start(10000);
-        connect(t, SIGNAL(timeout()), SLOT(reparent()));
+        connect(t, &QTimer::timeout, this, &MyObject::reparent);
 
         auto gc = new QObject(c);
         new QObject(gc);
