@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -81,7 +81,7 @@ private slots:
 
         QTest::newRow("win1") << "QtCore.dll" << true;
         QTest::newRow("win2") << "Qt5Core.dll" << true;
-        QTest::newRow("win3") << "c:\\path\\to\\Qt6Core.dll" << true;
+        QTest::newRow("win3") << R"(c:\path\to\Qt6Core.dll)" << true;
         QTest::newRow("win debug1") << "QtCored.dll" << true;
         QTest::newRow("win debug2") << "Qt5Cored.dll" << true;
 
