@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,8 +39,7 @@ class MyObject : public QObject
 public:
     explicit MyObject(QObject *parent = nullptr)
         : QObject(parent)
-        , p1(0)
-        , p2(23) {}
+    {}
     int intProp() { return p1; }
     int intProp2() { return p2; }
     void setIntProp(int i)
@@ -64,7 +63,7 @@ signals:
     void intProp2Changed();
 
 private:
-    int p1, p2;
+    int p1 = 0, p2 = 23;
 };
 
 using namespace GammaRay;
