@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -127,7 +127,6 @@ private:
             return false;
         idx.data(); // trigger the request
         Q_ASSERT(spy.isEmpty());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         while (spy.wait()) {
             for (auto it = spy.constBegin(); it != spy.constEnd(); ++it) {
                 if ((*it).contains(idx))
@@ -136,10 +135,6 @@ private:
             spy.clear();
         }
         return false;
-#else
-        QTest::qWait(100);
-        return true;
-#endif
     }
 
 private slots:
@@ -158,10 +153,10 @@ private slots:
         server.modelMonitored(true);
 
         FakeRemoteModel client(QStringLiteral("com.kdab.GammaRay.UnitTest.EmptyModel"), this);
-        connect(&server, SIGNAL(message(GammaRay::Message)), &client,
-                SLOT(newMessage(GammaRay::Message)));
-        connect(&client, SIGNAL(message(GammaRay::Message)), &server,
-                SLOT(newRequest(GammaRay::Message)));
+        connect(&server, &FakeRemoteModelServer::message, &client,
+                &RemoteModel::newMessage);
+        connect(&client, &FakeRemoteModel::message, &server,
+                &RemoteModelServer::newRequest);
 
         ModelTest modelTest(&client);
 
@@ -184,10 +179,10 @@ private slots:
         server.modelMonitored(true);
 
         FakeRemoteModel client(QStringLiteral("com.kdab.GammaRay.UnitTest.ListModel"), this);
-        connect(&server, SIGNAL(message(GammaRay::Message)), &client,
-                SLOT(newMessage(GammaRay::Message)));
-        connect(&client, SIGNAL(message(GammaRay::Message)), &server,
-                SLOT(newRequest(GammaRay::Message)));
+        connect(&server, &FakeRemoteModelServer::message, &client,
+                &RemoteModel::newMessage);
+        connect(&client, &FakeRemoteModel::message, &server,
+                &RemoteModelServer::newRequest);
 
         ModelTest modelTest(&client);
         QTest::qWait(100); // ModelTest is going to fetch stuff for us already
@@ -230,10 +225,10 @@ private slots:
         server.modelMonitored(true);
 
         FakeRemoteModel client(QStringLiteral("com.kdab.GammaRay.UnitTest.TreeModel"), this);
-        connect(&server, SIGNAL(message(GammaRay::Message)), &client,
-                SLOT(newMessage(GammaRay::Message)));
-        connect(&client, SIGNAL(message(GammaRay::Message)), &server,
-                SLOT(newRequest(GammaRay::Message)));
+        connect(&server, &FakeRemoteModelServer::message, &client,
+                &RemoteModel::newMessage);
+        connect(&client, &FakeRemoteModel::message, &server,
+                &RemoteModelServer::newRequest);
 
         ModelTest modelTest(&client);
         QTest::qWait(25); // ModelTest is going to fetch stuff for us already
@@ -288,10 +283,10 @@ private slots:
         server.modelMonitored(true);
 
         FakeRemoteModel client(QStringLiteral("com.kdab.GammaRay.UnitTest.TreeModel2"), this);
-        connect(&server, SIGNAL(message(GammaRay::Message)), &client,
-                SLOT(newMessage(GammaRay::Message)));
-        connect(&client, SIGNAL(message(GammaRay::Message)), &server,
-                SLOT(newRequest(GammaRay::Message)));
+        connect(&server, &FakeRemoteModelServer::message, &client,
+                &RemoteModel::newMessage);
+        connect(&client, &FakeRemoteModel::message, &server,
+                &RemoteModelServer::newRequest);
 
         QSortFilterProxyModel proxy;
         proxy.setDynamicSortFilter(true);
