@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -59,14 +59,14 @@ private slots:
         QPointer<Sender> s2 = new Sender;
         Receiver r;
 
-        connect(s1, SIGNAL(mySignal()), &r, SLOT(senderDeletingSlot()));
+        connect(s1.data(), &Sender::mySignal, &r, &Receiver::senderDeletingSlot);
         s1->emitSignal(); // must not crash
         QVERIFY(s1.isNull());
 
         // give the probe time to process s and r2 (needs one event loop re-entry)
         QTest::qWait(1);
 
-        connect(s2, SIGNAL(mySignal()), &r, SLOT(senderDeletingSlot()));
+        connect(s2.data(), &Sender::mySignal, &r, &Receiver::senderDeletingSlot);
         s2->emitSignal(); // must not crash
         QVERIFY(s2.isNull());
     }
