@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class TestObject : public QObject
     Q_OBJECT
 public:
     explicit TestObject(QObject *parent = nullptr);
-    ~TestObject();
+    ~TestObject() override;
 
 private slots:
     void dummySlot()
@@ -66,7 +66,7 @@ public:
     };
 
     TestConnections(Type type, int timeOuts, int timeoutInterval = -1);
-    ~TestConnections();
+    ~TestConnections() override;
 
 public slots:
     void timeout();
@@ -93,7 +93,7 @@ class TestThread : public QThread
 public:
     TestThread(TestConnections::Type type, int timeOuts, int timeoutInterval = -1,
                QObject *parent = nullptr);
-    ~TestThread();
+    ~TestThread() override;
     void run() override;
 
 private:
