@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,16 +40,14 @@ ClientToolModel::ClientToolModel(ClientToolManager *manager)
     : QAbstractListModel(manager)
     , m_toolManager(manager)
 {
-    connect(m_toolManager, SIGNAL(aboutToReceiveData()), this, SLOT(startReset()));
-    connect(m_toolManager, SIGNAL(toolListAvailable()), this, SLOT(finishReset()));
-    connect(m_toolManager, SIGNAL(aboutToReset()), this, SLOT(startReset()));
-    connect(m_toolManager, SIGNAL(reset()), this, SLOT(finishReset()));
-    connect(m_toolManager, SIGNAL(toolEnabledByIndex(int)), this, SLOT(toolEnabled(int)));
+    connect(m_toolManager, &ClientToolManager::aboutToReceiveData, this, &ClientToolModel::startReset);
+    connect(m_toolManager, &ClientToolManager::toolListAvailable, this, &ClientToolModel::finishReset);
+    connect(m_toolManager, &ClientToolManager::aboutToReset, this, &ClientToolModel::startReset);
+    connect(m_toolManager, &ClientToolManager::reset, this, &ClientToolModel::finishReset);
+    connect(m_toolManager, &ClientToolManager::toolEnabledByIndex, this, &ClientToolModel::toolEnabled);
 }
 
-ClientToolModel::~ClientToolModel()
-{
-}
+ClientToolModel::~ClientToolModel() = default;
 
 QVariant ClientToolModel::data(const QModelIndex &index, int role) const
 {
@@ -88,11 +86,7 @@ QVariant ClientToolModel::data(const QModelIndex &index, int role) const
 void ClientToolModel::toolEnabled(int toolIndex)
 {
     QModelIndex i = index(toolIndex, 0);
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    emit dataChanged(i, i);
-#else
     emit dataChanged(i, i, QVector<int>() << ToolModelRole::ToolEnabled);
-#endif
 }
 
 void ClientToolModel::startReset()
@@ -129,13 +123,11 @@ ClientToolSelectionModel::ClientToolSelectionModel(ClientToolManager *manager)
     : QItemSelectionModel(manager->model())
     , m_toolManager(manager)
 {
-    connect(manager, SIGNAL(toolSelectedByIndex(int)), this, SLOT(selectTool(int)));
-    connect(manager, SIGNAL(toolListAvailable()), this, SLOT(selectDefaultTool()));
+    connect(manager, &ClientToolManager::toolSelectedByIndex, this, &ClientToolSelectionModel::selectTool);
+    connect(manager, &ClientToolManager::toolListAvailable, this, &ClientToolSelectionModel::selectDefaultTool);
 }
 
-ClientToolSelectionModel::~ClientToolSelectionModel()
-{
-}
+ClientToolSelectionModel::~ClientToolSelectionModel() = default;
 
 void ClientToolSelectionModel::selectTool(int index)
 {
