@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class ClientToolModel : public QAbstractListModel
     Q_OBJECT
 public:
     explicit ClientToolModel(ClientToolManager *manager);
-    ~ClientToolModel();
+    ~ClientToolModel() override;
 
     QVariant data(const QModelIndex &index, int role) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
@@ -63,7 +63,7 @@ class ClientToolSelectionModel : public QItemSelectionModel
     Q_OBJECT
 public:
     explicit ClientToolSelectionModel(ClientToolManager *manager);
-    ~ClientToolSelectionModel();
+    ~ClientToolSelectionModel() override;
 
 private slots:
     void selectTool(int index);
