@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -56,7 +56,7 @@ public:
     explicit PropertyBinder(QObject *source, const char *sourceProp, QObject *destination,
                             const char *destProp);
 
-    ~PropertyBinder();
+    ~PropertyBinder() override;
 
     /** Adds another binding between @p sourceProp and @p destProp.
      *  At least the source property must have a change notification signal.
