@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,9 +39,7 @@ PropertyDoublePairEditor::PropertyDoublePairEditor(QWidget *parent)
     ui->setupUi(this);
 }
 
-PropertyDoublePairEditor::~PropertyDoublePairEditor()
-{
-}
+PropertyDoublePairEditor::~PropertyDoublePairEditor() = default;
 
 PropertyPointFEditor::PropertyPointFEditor(QWidget *parent)
     : PropertyDoublePairEditor(parent)
@@ -50,7 +48,7 @@ PropertyPointFEditor::PropertyPointFEditor(QWidget *parent)
 
 QPointF PropertyPointFEditor::pointF() const
 {
-    return QPointF(ui->xBox->value(), ui->yBox->value());
+    return {ui->xBox->value(), ui->yBox->value()};
 }
 
 void PropertyPointFEditor::setPointF(const QPointF &point)
@@ -66,7 +64,7 @@ PropertySizeFEditor::PropertySizeFEditor(QWidget *parent)
 
 QSizeF PropertySizeFEditor::sizeF() const
 {
-    return QSizeF(ui->xBox->value(), ui->yBox->value());
+    return {ui->xBox->value(), ui->yBox->value()};
 }
 
 void PropertySizeFEditor::setSizeF(const QSizeF &size)
