@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,11 +41,7 @@ class GAMMARAY_UI_EXPORT PropertyEditorFactory : public QItemEditorFactory
 public:
     static PropertyEditorFactory *instance();
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    typedef QVariant::Type TypeId;
-#else
     typedef int TypeId;
-#endif
 
     QWidget *createEditor(TypeId type, QWidget *parent) const override;
 
