@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -65,9 +65,7 @@ SidePane::SidePane(QWidget *parent)
     setItemDelegate(new Delegate(this));
 }
 
-SidePane::~SidePane()
-{
-}
+SidePane::~SidePane() = default;
 
 QSize SidePane::sizeHint() const
 {
@@ -79,16 +77,16 @@ QSize SidePane::sizeHint() const
     const int width = sizeHintForColumn(0) + widthMargin;
     const int height = QListView::sizeHint().height();
 
-    return QSize(width, height);
+    return {width, height};
 }
 
 void SidePane::setModel(QAbstractItemModel *model)
 {
     if (model) {
-        connect(model, SIGNAL(rowsInserted(QModelIndex,int,int)), SLOT(updateSizeHint()));
-        connect(model, SIGNAL(rowsRemoved(QModelIndex,int,int)), SLOT(updateSizeHint()));
-        connect(model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(updateSizeHint()));
-        connect(model, SIGNAL(modelReset()), SLOT(updateSizeHint()));
+        connect(model, &QAbstractItemModel::rowsInserted, this, &SidePane::updateSizeHint);
+        connect(model, &QAbstractItemModel::rowsRemoved, this, &SidePane::updateSizeHint);
+        connect(model, &QAbstractItemModel::dataChanged, this, &SidePane::updateSizeHint);
+        connect(model, &QAbstractItemModel::modelReset, this, &SidePane::updateSizeHint);
     }
     QAbstractItemView::setModel(model);
 }
@@ -98,18 +96,14 @@ bool SidePane::eventFilter(QObject *object, QEvent *event)
     if (object == viewport()) {
         if (event->type() == QEvent::Resize)
             updateSizeHint();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
         else if (event->type() == QEvent::ScreenChangeInternal)
             m_background = QPixmap();
-#endif
         else if (event->type() == QEvent::Paint) {
             if (m_background.isNull())
                 m_background = UIResources::themedPixmap(QStringLiteral("kdab-gammaray-logo.png"), this);
 
             qreal dpr = 1.0;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
             dpr = m_background.devicePixelRatio();
-#endif
             QPainter p(viewport());
             p.drawPixmap(viewport()->width() - (m_background.width() / dpr),
                          viewport()->height() - (m_background.height() / dpr), m_background);
