@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,7 +47,7 @@ class MessageHandlerWidget : public QWidget
     Q_OBJECT
 public:
     explicit MessageHandlerWidget(QWidget *parent = nullptr);
-    ~MessageHandlerWidget();
+    ~MessageHandlerWidget() override;
 
 private slots:
     void fatalMessageReceived(const QString &app, const QString &message, const QTime &time,
