@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class MetaTypeBrowserWidget : public QWidget
     Q_OBJECT
 public:
     explicit MetaTypeBrowserWidget(QWidget *parent = nullptr);
-    ~MetaTypeBrowserWidget();
+    ~MetaTypeBrowserWidget() override;
 
 private slots:
     void contextMenu(QPoint pos);
