@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,9 +46,7 @@ ClassInfoTab::ClassInfoTab(PropertyWidget *parent)
     setObjectBaseName(parent->objectBaseName());
 }
 
-ClassInfoTab::~ClassInfoTab()
-{
-}
+ClassInfoTab::~ClassInfoTab() = default;
 
 void ClassInfoTab::setObjectBaseName(const QString &baseName)
 {
@@ -57,6 +55,6 @@ void ClassInfoTab::setObjectBaseName(const QString &baseName)
     proxy->setSourceModel(ObjectBroker::model(baseName + '.' + "classInfo"));
     m_ui->classInfoView->setModel(proxy);
     m_ui->classInfoView->sortByColumn(0, Qt::AscendingOrder);
-    m_ui->classInfoView->header()->setResizeMode(QHeaderView::ResizeToContents);
+    m_ui->classInfoView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     new SearchLineController(m_ui->classInfoSearchLine, proxy);
 }
