@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -68,7 +68,7 @@ class ObjectInspectorWidget : public QWidget
     Q_OBJECT
 public:
     explicit ObjectInspectorWidget(QWidget *parent = nullptr);
-    ~ObjectInspectorWidget();
+    ~ObjectInspectorWidget() override;
 
 private slots:
     void objectSelectionChanged(const QItemSelection &selection);
