@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,6 +31,7 @@
 #include "propertywidget.h"
 #include "editabletypesmodel.h"
 
+#include <ui/clientpropertymodel.h>
 #include <ui/contextmenuextension.h>
 #include <ui/propertyeditor/propertyeditordelegate.h>
 #include <ui/propertyeditor/propertyeditorfactory.h>
@@ -61,46 +62,47 @@ PropertiesTab::PropertiesTab(PropertyWidget *parent)
     setObjectBaseName(parent->objectBaseName());
 }
 
-PropertiesTab::~PropertiesTab()
-{
-}
+PropertiesTab::~PropertiesTab() = default;
 
 void PropertiesTab::setObjectBaseName(const QString &baseName)
 {
-    auto *proxy = new QSortFilterProxyModel(this);
+    auto model = ObjectBroker::model(baseName + '.' + "properties");
+    auto clientModel = new ClientPropertyModel(this);
+    clientModel->setSourceModel(model);
+
+    auto proxy = new QSortFilterProxyModel(this);
     proxy->setDynamicSortFilter(true);
     proxy->setSortCaseSensitivity(Qt::CaseInsensitive);
-    QAbstractItemModel *model = ObjectBroker::model(baseName + '.' + "properties");
-    proxy->setSourceModel(model);
+    proxy->setSourceModel(clientModel);
     m_ui->propertyView->setModel(proxy);
     m_ui->propertyView->sortByColumn(0, Qt::AscendingOrder);
     m_ui->propertyView->setDeferredResizeMode(0, QHeaderView::ResizeToContents);
     new SearchLineController(m_ui->propertySearchLine, proxy);
     m_ui->propertyView->setItemDelegate(new PropertyEditorDelegate(this));
-    connect(m_ui->propertyView, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(propertyContextMenu(QPoint)));
+    connect(m_ui->propertyView, &QWidget::customContextMenuRequested,
+            this, &PropertiesTab::propertyContextMenu);
 
-    auto *typesModel = new EditableTypesModel(this);
+    auto typesModel = new EditableTypesModel(this);
     proxy = new QSortFilterProxyModel(this);
     proxy->setSortCaseSensitivity(Qt::CaseInsensitive);
     proxy->setSourceModel(typesModel);
     proxy->sort(0);
     m_ui->newPropertyType->setModel(proxy);
-    connect(m_ui->newPropertyType, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(updateNewPropertyValueEditor()));
+    connect(m_ui->newPropertyType, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+            this, &PropertiesTab::updateNewPropertyValueEditor);
     updateNewPropertyValueEditor();
-    connect(m_ui->newPropertyName, SIGNAL(textChanged(QString)),
-            this, SLOT(validateNewProperty()));
+    connect(m_ui->newPropertyName, &QLineEdit::textChanged,
+            this, &PropertiesTab::validateNewProperty);
     validateNewProperty();
-    connect(m_ui->newPropertyButton, SIGNAL(clicked()),
-            this, SLOT(addNewProperty()));
+    connect(m_ui->newPropertyButton, &QAbstractButton::clicked,
+            this, &PropertiesTab::addNewProperty);
 
     m_interface = ObjectBroker::object<PropertiesExtensionInterface *>(
         baseName + ".propertiesExtension");
     new PropertyBinder(m_interface, "canAddProperty", m_ui->newPropertyBar, "visible");
     m_ui->propertyView->setDeferredHidden(1, !m_interface->hasPropertyValues());
     m_ui->propertyView->setRootIsDecorated(m_interface->hasPropertyValues());
-    connect(m_interface, SIGNAL(hasPropertyValuesChanged()), this, SLOT(hasValuesChanged()));
+    connect(m_interface, &PropertiesExtensionInterface::hasPropertyValuesChanged, this, &PropertiesTab::hasValuesChanged);
 }
 
 static PropertyEditorFactory::TypeId selectedTypeId(QComboBox *box)
