@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,9 +37,7 @@ ClientResourceModel::ClientResourceModel(QObject *parent)
 {
 }
 
-ClientResourceModel::~ClientResourceModel()
-{
-}
+ClientResourceModel::~ClientResourceModel() = default;
 
 QVariant ClientResourceModel::data(const QModelIndex &index, int role) const
 {
@@ -49,10 +47,9 @@ QVariant ClientResourceModel::data(const QModelIndex &index, int role) const
         if (hasChildren(index))
             return m_iconProvider.icon(QFileIconProvider::Folder);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-        QList<QMimeType> types = m_mimeDb.mimeTypesForFileName(index.data(
+        const QList<QMimeType> types = m_mimeDb.mimeTypesForFileName(index.data(
                                                                    Qt::DisplayRole).toString());
-        foreach (const QMimeType &mt, types) {
+        for (const QMimeType &mt : types) {
             QIcon icon = QIcon::fromTheme(mt.iconName());
             if (!icon.isNull())
                 return icon;
@@ -60,7 +57,6 @@ QVariant ClientResourceModel::data(const QModelIndex &index, int role) const
             if (!icon.isNull())
                 return icon;
         }
-#endif
         return m_iconProvider.icon(QFileIconProvider::File);
     }
     return QIdentityProxyModel::data(index, role);
