@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,13 +30,9 @@
 
 using namespace GammaRay;
 
-ToolUiFactory::ToolUiFactory()
-{
-}
+ToolUiFactory::ToolUiFactory() = default;
 
-ToolUiFactory::~ToolUiFactory()
-{
-}
+ToolUiFactory::~ToolUiFactory() = default;
 
 QString ToolUiFactory::name() const
 {
