@@ -2,7 +2,7 @@
  * This file is part of GammaRay, the Qt application inspection and
  * manipulation tool.
  *
- * Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+ * Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  * Author: Filipe Azevedo <filipe.azevedo@kdab.com>
  *
  * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,6 +40,7 @@
 #include <QEvent>
 #include <QTimer>
 #include <QDebug>
+#include <vector>
 
 #define WIDGET_CUSTOMIZED "customized"
 
@@ -58,26 +59,26 @@ QAbstractItemView *headerView(QHeaderView *header)
 
 void distributeSpace(QList<int> &sizes, int size, int handleSize)
 {
-    QList<QList<int>::Iterator> its;
+    std::vector<QList<int>::Iterator> its;
     int usedSpace = 0;
 
     for (auto it = sizes.begin(), end = sizes.end(); it != end; ++it) {
         if ((*it) == -1)
-            its << it;
+            its.push_back(it);
         else
             usedSpace += (*it);
     }
 
-    if (!its.isEmpty()) {
+    if (!its.empty()) {
         const int freeSpace = size - usedSpace - (sizes.count() * handleSize) - handleSize;
-        const int space = freeSpace / its.count();
-        for (auto it = its.begin(), end = its.end(); it != end; ++it)
-            (*(*it)) = space;
+        const int space = freeSpace / its.size();
+        for (auto & it : its)
+            (*it) = space;
     }
 }
 
-typedef QList<QSplitter *> QSplitterList;
-typedef QList<QHeaderView *> QHeaderViewList;
+using QSplitterList = QList<QSplitter *>;
+using QHeaderViewList = QList<QHeaderView *>;
 }
 
 UIStateManager::UIStateManager(QWidget *widget)
@@ -96,9 +97,7 @@ UIStateManager::UIStateManager(QWidget *widget)
     m_widget->installEventFilter(this);
 }
 
-UIStateManager::~UIStateManager()
-{
-}
+UIStateManager::~UIStateManager() = default;
 
 QWidget *UIStateManager::widget() const
 {
@@ -151,8 +150,7 @@ void UIStateManager::setup()
 
         knownNames << name;
 
-        connect(splitter, SIGNAL(splitterMoved(int,int)), this, SLOT(
-                    widgetCustomized()), Qt::UniqueConnection);
+        connect(splitter, &QSplitter::splitterMoved, this, &UIStateManager::widgetCustomized, Qt::UniqueConnection);
     }
 
     foreach (QHeaderView *header, headers()) {
@@ -168,10 +166,9 @@ void UIStateManager::setup()
 
         knownNames << name;
 
-        connect(header, SIGNAL(sectionResized(int,int,int)), this, SLOT(
-                    widgetCustomized()), Qt::UniqueConnection);
-        connect(header, SIGNAL(sectionCountChanged(int,int)), this,
-                SLOT(headerSectionCountChanged()), Qt::UniqueConnection);
+        connect(header, &QHeaderView::sectionResized, this, &UIStateManager::widgetCustomized, Qt::UniqueConnection);
+        connect(header, &QHeaderView::sectionCountChanged, this,
+                &UIStateManager::headerSectionCountChanged, Qt::UniqueConnection);
 
         QAbstractItemView *view = headerView(header);
         view->removeEventFilter(this);
@@ -414,7 +411,7 @@ void UIStateManager::saveWindowState()
 void UIStateManager::restoreSplitterState(QSplitter *splitter)
 {
     const QSplitterList splitters = splitter ? (QSplitterList() << splitter) : this->splitters();
-    foreach (QSplitter *splitter, splitters) {
+    for (QSplitter *splitter : splitters) {
         if (!checkWidget(splitter))
             continue;
 
@@ -429,7 +426,7 @@ void UIStateManager::restoreSplitterState(QSplitter *splitter)
                 QList<int> sizes;
                 sizes.reserve(defaultSizes.count());
 
-                foreach (const QVariant &size, defaultSizes) {
+                for (const QVariant &size : defaultSizes) {
                     switch (size.type()) {
                     case QVariant::Int: // Pixels
                         sizes << size.toInt();
@@ -469,7 +466,7 @@ void UIStateManager::restoreSplitterState(QSplitter *splitter)
 void UIStateManager::saveSplitterState(QSplitter *splitter)
 {
     const QSplitterList splitters = splitter ? (QSplitterList() << splitter) : this->splitters();
-    foreach (QSplitter *splitter, splitters) {
+    for (QSplitter *splitter : splitters) {
         if (!checkWidget(splitter) || !splitter->property(WIDGET_CUSTOMIZED).toBool())
             continue;
 
@@ -480,7 +477,7 @@ void UIStateManager::saveSplitterState(QSplitter *splitter)
 void UIStateManager::restoreHeaderState(QHeaderView *header)
 {
     const QHeaderViewList headers = header ? (QHeaderViewList() << header) : this->headers();
-    foreach (QHeaderView *header, headers) {
+    for (QHeaderView *header : headers) {
         if (header->orientation() == Qt::Vertical || !checkWidget(header) || header->count() == 0)
             continue;
 
@@ -520,11 +517,7 @@ void UIStateManager::restoreHeaderState(QHeaderView *header)
                         Q_ASSERT(false);
                     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
                     switch (header->sectionResizeMode(i)) {
-#else
-                    switch (header->resizeMode(i)) {
-#endif
                     case QHeaderView::Interactive:
                     case QHeaderView::Fixed:
                         header->resizeSection(i, size == -1 ? header->sectionSizeHint(i) : size);
@@ -558,7 +551,7 @@ void UIStateManager::restoreHeaderState(QHeaderView *header)
 void UIStateManager::saveHeaderState(QHeaderView *header)
 {
     const QHeaderViewList headers = header ? (QHeaderViewList() << header) : this->headers();
-    foreach (QHeaderView *header, headers) {
+    for (QHeaderView *header : headers) {
         if (header->orientation() == Qt::Vertical || !checkWidget(header) || header->count() == 0
             || !header->property(WIDGET_CUSTOMIZED).toBool())
             continue;
